@@ -39,11 +39,11 @@ NONE_2_KEY = "uid=NONE_2_KEY,{}".format(AUTHMETHOD_OU_KEY)
 
 
 NONE_ACI_KEY = f'(target = "ldap:///{AUTHMETHOD_OU_KEY}")' \
-               f'(targetattr=*)(version 3.0; aci "Authmethod aci"; ' \
+               f'(targetattr="*")(version 3.0; aci "Authmethod aci"; ' \
                f'allow(all) userdn = "ldap:///{NONE_1_KEY}" and authmethod = "none" ;)'
 
 SIMPLE_ACI_KEY = f'(target = "ldap:///{AUTHMETHOD_OU_KEY}")' \
-                 f'(targetattr=*)(version 3.0; aci "Authmethod aci"; ' \
+                 f'(targetattr="*")(version 3.0; aci "Authmethod aci"; ' \
                  f'allow(all) userdn = "ldap:///{SIMPLE_1_KEY}" and authmethod = "simple" ;)'
 
 
@@ -55,8 +55,7 @@ def _add_aci(topo, name):
 
 
 def test_user_binds_with_a_password_and_can_access_the_data(topo, add_user, aci_of_user):
-    """
-    User binds with a password and can access the data as per the ACI.
+    """User binds with a password and can access the data as per the ACI.
 
     :id: f6c4b6f0-7ac4-11e8-a517-8c16451d917b
     :setup: Standalone Server
@@ -78,8 +77,7 @@ def test_user_binds_with_a_password_and_can_access_the_data(topo, add_user, aci_
 
 
 def test_user_binds_with_a_bad_password_and_cannot_access_the_data(topo, add_user, aci_of_user):
-    """
-    User binds with a BAD password and cannot access the data .
+    """User binds with a BAD password and cannot access the data .
 
     :id: 0397744e-7ac5-11e8-bfb1-8c16451d917b
     :setup: Standalone Server
@@ -98,8 +96,7 @@ def test_user_binds_with_a_bad_password_and_cannot_access_the_data(topo, add_use
 
 
 def test_anonymous_user_cannot_access_the_data(topo, add_user, aci_of_user):
-    """
-    Anonymous user cannot access the data
+    """Anonymous user cannot access the data
 
     :id: 0821a55c-7ac5-11e8-b214-8c16451d917b
     :setup: Standalone Server
@@ -124,8 +121,7 @@ def test_anonymous_user_cannot_access_the_data(topo, add_user, aci_of_user):
 
 
 def test_authenticated_but_has_no_rigth_on_the_data(topo, add_user, aci_of_user):
-    """
-    User has a password. He is authenticated but has no rigth on the data.
+    """User has a password. He is authenticated but has no rigth on the data.
 
     :id: 11be7ebe-7ac5-11e8-b754-8c16451d917b
     :setup: Standalone Server
@@ -150,10 +146,9 @@ def test_authenticated_but_has_no_rigth_on_the_data(topo, add_user, aci_of_user)
 
 
 def test_the_bind_client_is_accessing_the_directory(topo, add_user, aci_of_user):
-    """
-     The bind rule is evaluated to be true if the client is accessing the directory as per the ACI.
+    """The bind rule is evaluated to be true if the client is accessing the directory as per the ACI.
 
-     :id: 1715bfb2-7ac5-11e8-8f2c-8c16451d917b
+    :id: 1715bfb2-7ac5-11e8-8f2c-8c16451d917b
     :setup: Standalone Server
     :steps:
         1. Add test entry
@@ -175,8 +170,7 @@ def test_the_bind_client_is_accessing_the_directory(topo, add_user, aci_of_user)
 
 def test_users_binds_with_a_password_and_can_access_the_data(
         topo, add_user, aci_of_user):
-    """
-    User binds with a password and can access the data as per the ACI.
+    """User binds with a password and can access the data as per the ACI.
 
     :id: 1bd01cb4-7ac5-11e8-a2f1-8c16451d917b
     :setup: Standalone Server
@@ -199,8 +193,7 @@ def test_users_binds_with_a_password_and_can_access_the_data(
 
 
 def test_user_binds_without_any_password_and_cannot_access_the_data(topo, add_user, aci_of_user):
-    """
-    User binds without any password and cannot access the data
+    """User binds without any password and cannot access the data
 
     :id: 205777fa-7ac5-11e8-ba2f-8c16451d917b
     :setup: Standalone Server
@@ -227,8 +220,7 @@ def test_user_binds_without_any_password_and_cannot_access_the_data(topo, add_us
 def test_user_can_access_the_data_when_connecting_from_any_machine(
         topo, add_user, aci_of_user
 ):
-    """
-    User can access the data when connecting from any machine as per the ACI.
+    """User can access the data when connecting from any machine as per the ACI.
 
     :id: 28cbc008-7ac5-11e8-934e-8c16451d917b
     :setup: Standalone Server
@@ -244,7 +236,7 @@ def test_user_can_access_the_data_when_connecting_from_any_machine(
     # Add ACI
     Domain(topo.standalone, DEFAULT_SUFFIX)\
         .add("aci", f'(target ="ldap:///{DNS_OU_KEY}")'
-                    f'(targetattr=*)(version 3.0; aci "DNS aci"; allow(all) '
+                    f'(targetattr="*")(version 3.0; aci "DNS aci"; allow(all) '
                     f'userdn = "ldap:///{FULLDNS_KEY}" and dns = "*" ;)')
 
     # Create a new connection for this test.
@@ -256,8 +248,8 @@ def test_user_can_access_the_data_when_connecting_from_any_machine(
 def test_user_can_access_the_data_when_connecting_from_internal_ds_network_only(
         topo, add_user, aci_of_user
 ):
-    """
-    User can access the data when connecting from internal ICNC network only as per the ACI.
+    """User can access the data when connecting from internal ICNC network only as per the ACI.
+
     :id: 2cac2136-7ac5-11e8-8328-8c16451d917b
     :setup: Standalone Server
     :steps:
@@ -273,9 +265,9 @@ def test_user_can_access_the_data_when_connecting_from_internal_ds_network_only(
     # Add ACI
     Domain(topo.standalone, DEFAULT_SUFFIX).\
         add("aci", [f'(target = "ldap:///{DNS_OU_KEY}")'
-                    f'(targetattr=*)(version 3.0; aci "DNS aci"; '
+                    f'(targetattr="*")(version 3.0; aci "DNS aci"; '
                     f'allow(all) userdn = "ldap:///{SUNDNS_KEY}" and dns = "*redhat.com" ;)',
-                    f'(target = "ldap:///{DNS_OU_KEY}")(targetattr=*)'
+                    f'(target = "ldap:///{DNS_OU_KEY}")(targetattr="*")'
                     f'(version 3.0; aci "DNS aci"; allow(all) '
                     f'userdn = "ldap:///{SUNDNS_KEY}" and dns = "{dns_name}" ;)'])
 
@@ -288,8 +280,7 @@ def test_user_can_access_the_data_when_connecting_from_internal_ds_network_only(
 def test_user_can_access_the_data_when_connecting_from_some_network_only(
         topo, add_user, aci_of_user
 ):
-    """
-    User can access the data when connecting from some network only as per the ACI.
+    """User can access the data when connecting from some network only as per the ACI.
 
     :id: 3098512a-7ac5-11e8-af85-8c16451d917b
     :setup: Standalone Server
@@ -306,7 +297,7 @@ def test_user_can_access_the_data_when_connecting_from_some_network_only(
     # Add ACI
     Domain(topo.standalone, DEFAULT_SUFFIX)\
         .add("aci", f'(target = "ldap:///{DNS_OU_KEY}")'
-                    f'(targetattr=*)(version 3.0; aci "DNS aci"; allow(all) '
+                    f'(targetattr="*")(version 3.0; aci "DNS aci"; allow(all) '
                     f'userdn = "ldap:///{NETSCAPEDNS_KEY}" '
                     f'and dns = "{dns_name}" ;)')
 
@@ -317,8 +308,7 @@ def test_user_can_access_the_data_when_connecting_from_some_network_only(
 
 
 def test_from_an_unauthorized_network(topo, add_user, aci_of_user):
-    """
-    User cannot access the data when connecting from an unauthorized network as per the ACI.
+    """User cannot access the data when connecting from an unauthorized network as per the ACI.
 
     :id: 34cf9726-7ac5-11e8-bc12-8c16451d917b
     :setup: Standalone Server
@@ -334,7 +324,7 @@ def test_from_an_unauthorized_network(topo, add_user, aci_of_user):
     # Add ACI
     Domain(topo.standalone, DEFAULT_SUFFIX).\
         add("aci", f'(target = "ldap:///{DNS_OU_KEY}")'
-                   f'(targetattr=*)(version 3.0; aci "DNS aci"; allow(all) '
+                   f'(targetattr="*")(version 3.0; aci "DNS aci"; allow(all) '
                    f'userdn = "ldap:///{NETSCAPEDNS_KEY}" and dns != "red.iplanet.com" ;)')
 
     # Create a new connection for this test.
@@ -345,8 +335,7 @@ def test_from_an_unauthorized_network(topo, add_user, aci_of_user):
 
 def test_user_cannot_access_the_data_when_connecting_from_an_unauthorized_network_2(
         topo, add_user, aci_of_user):
-    """
-    User cannot access the data when connecting from an unauthorized network as per the ACI.
+    """User cannot access the data when connecting from an unauthorized network as per the ACI.
 
     :id: 396bdd44-7ac5-11e8-8014-8c16451d917b
     :setup: Standalone Server
@@ -362,7 +351,7 @@ def test_user_cannot_access_the_data_when_connecting_from_an_unauthorized_networ
     # Add ACI
     Domain(topo.standalone, DEFAULT_SUFFIX).\
         add("aci", f'(target = "ldap:///{DNS_OU_KEY}")'
-                   f'(targetattr=*)(version 3.0; aci "DNS aci"; allow(all) '
+                   f'(targetattr="*")(version 3.0; aci "DNS aci"; allow(all) '
                    f'userdn = "ldap:///{NETSCAPEDNS_KEY}" '
                    f'and dnsalias != "www.redhat.com" ;)')
 
@@ -373,8 +362,8 @@ def test_user_cannot_access_the_data_when_connecting_from_an_unauthorized_networ
 
 
 def test_user_cannot_access_the_data_if_not_from_a_certain_domain(topo, add_user, aci_of_user):
-    """
-    User cannot access the data if not from a certain domain as per the ACI.
+    """User cannot access the data if not from a certain domain as per the ACI.
+
     :id: 3d658972-7ac5-11e8-930f-8c16451d917b
     :setup: Standalone Server
     :steps:
@@ -388,7 +377,7 @@ def test_user_cannot_access_the_data_if_not_from_a_certain_domain(topo, add_user
     """
     # Add ACI
     Domain(topo.standalone, DEFAULT_SUFFIX).\
-        add("aci", f'(target = "ldap:///{DNS_OU_KEY}")(targetattr=*)'
+        add("aci", f'(target = "ldap:///{DNS_OU_KEY}")(targetattr="*")'
                    f'(version 3.0; aci "DNS aci"; allow(all) '
                    f'userdn = "ldap:///{NODNS_KEY}" '
                    f'and dns = "RAP.rock.SALSA.house.COM" ;)')
@@ -402,8 +391,7 @@ def test_user_cannot_access_the_data_if_not_from_a_certain_domain(topo, add_user
 
 
 def test_dnsalias_keyword_test_nodns_cannot(topo, add_user, aci_of_user):
-    """
-    Dnsalias Keyword NODNS_KEY cannot assess data as per the ACI.
+    """Dnsalias Keyword NODNS_KEY cannot assess data as per the ACI.
 
     :id: 41b467be-7ac5-11e8-89a3-8c16451d917b
     :setup: Standalone Server
@@ -418,7 +406,7 @@ def test_dnsalias_keyword_test_nodns_cannot(topo, add_user, aci_of_user):
     """
     # Add ACI
     Domain(topo.standalone, DEFAULT_SUFFIX).\
-        add("aci", f'(target = "ldap:///{DNS_OU_KEY}")(targetattr=*)'
+        add("aci", f'(target = "ldap:///{DNS_OU_KEY}")(targetattr="*")'
                    f'(version 3.0; aci "DNS aci"; allow(all) '
                    f'userdn = "ldap:///{NODNS_KEY}" and '
                    f'dnsalias = "RAP.rock.SALSA.house.COM" ;)')
@@ -434,8 +422,7 @@ def test_dnsalias_keyword_test_nodns_cannot(topo, add_user, aci_of_user):
 @pytest.mark.bz1710848
 @pytest.mark.parametrize("ip_addr", ['127.0.0.1', "[::1]"])
 def test_user_can_access_from_ipv4_or_ipv6_address(topo, add_user, aci_of_user, ip_addr):
-    """
-    User can modify the data when accessing the server from the allowed IPv4 and IPv6 addresses
+    """User can modify the data when accessing the server from the allowed IPv4 and IPv6 addresses
 
     :id: 461e761e-7ac5-11e8-9ae4-8c16451d917b
     :parametrized: yes
@@ -451,7 +438,7 @@ def test_user_can_access_from_ipv4_or_ipv6_address(topo, add_user, aci_of_user,
     """
     # Add ACI that contains both IPv4 and IPv6
     Domain(topo.standalone, DEFAULT_SUFFIX).\
-        add("aci", f'(target ="ldap:///{IP_OU_KEY}")(targetattr=*) '
+        add("aci", f'(target ="ldap:///{IP_OU_KEY}")(targetattr="*") '
                    f'(version 3.0; aci "IP aci"; allow(all) '
                    f'userdn = "ldap:///{FULLIP_KEY}" and (ip = "127.0.0.1" or ip = "::1");)')
 
