@@ -1,6 +1,6 @@
 """
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2019 RED Hat, Inc.
+# Copyright (C) 2020 RED Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -8,6 +8,7 @@
 # --- END COPYRIGHT BLOCK ----
 """
 
+import ldap
 import os
 import pytest
 
@@ -21,8 +22,6 @@ from lib389.topologies import topology_st as topo
 from lib389.idm.domain import Domain
 from lib389.plugins import ACLPlugin
 
-import ldap
-
 pytestmark = pytest.mark.tier1
 
 PEOPLE = "ou=PEOPLE,{}".format(DEFAULT_SUFFIX)
@@ -37,7 +36,19 @@ def aci_of_user(request, topo):
     :param request:
     :param topo:
     """
-    aci_list = Domain(topo.standalone, DEFAULT_SUFFIX).get_attr_vals('aci')
+
+    # Add anonymous access aci
+    ACI_TARGET = "(targetattr != \"userpassword\")(target = \"ldap:///%s\")" % (DEFAULT_SUFFIX)
+    ACI_ALLOW = "(version 3.0; acl \"Anonymous Read access\"; allow (read,search,compare)"
+    ACI_SUBJECT = "(userdn=\"ldap:///anyone\");)"
+    ANON_ACI = ACI_TARGET + ACI_ALLOW + ACI_SUBJECT
+    suffix = Domain(topo.standalone, DEFAULT_SUFFIX)
+    try:
+        suffix.add('aci', ANON_ACI)
+    except ldap.TYPE_OR_VALUE_EXISTS:
+        pass
+
+    aci_list = suffix.get_attr_vals('aci')
 
     def finofaci():
         """
@@ -78,8 +89,8 @@ def clean(request, topo):
 
 
 def test_accept_aci_in_addition_to_acl(topo, clean, aci_of_user):
-    """
-    Misc Test 2 accept aci in addition to acl
+    """Misc Test 2 accept aci in addition to acl
+
     :id: 8e9408fa-7db8-11e8-adaa-8c16451d917b
     :setup: Standalone Instance
     :steps:
@@ -96,7 +107,7 @@ def test_accept_aci_in_addition_to_acl(topo, clean, aci_of_user):
     for i in [('mail', 'anujborah@okok.com'), ('givenname', 'Anuj'), ('userPassword', PW_DM)]:
         user.set(i[0], i[1])
 
-    aci_target = "(targetattr=givenname)"
+    aci_target = '(targetattr="givenname")'
     aci_allow = ('(version 3.0; acl "Name of the ACI"; deny (read, search, compare, write)')
     aci_subject = 'userdn="ldap:///anyone";)'
     Domain(topo.standalone, CONTAINER_1_DELADD).add("aci", aci_target + aci_allow + aci_subject)
@@ -115,9 +126,9 @@ def test_accept_aci_in_addition_to_acl(topo, clean, aci_of_user):
 
 @pytest.mark.bz334451
 def test_more_then_40_acl_will_crash_slapd(topo, clean, aci_of_user):
-    """
-    bug 334451 : more then 40 acl will crash slapd
+    """bug 334451 : more then 40 acl will crash slapd
     superseded by Bug 772778 - acl cache overflown problem with > 200 acis
+
     :id: 93a44c60-7db8-11e8-9439-8c16451d917b
     :setup: Standalone Instance
     :steps:
@@ -132,7 +143,7 @@ def test_more_then_40_acl_will_crash_slapd(topo, clean, aci_of_user):
     uas = UserAccounts(topo.standalone, DEFAULT_SUFFIX, rdn='ou=Accounting')
     user = uas.create_test_user()
 
-    aci_target = '(target ="ldap:///{}")(targetattr !="userPassword")'.format(CONTAINER_1_DELADD)
+    aci_target = '(target ="ldap:///{}")(targetattr!="userPassword")'.format(CONTAINER_1_DELADD)
     # more_then_40_acl_will not crash_slapd
     for i in range(40):
         aci_allow = '(version 3.0;acl "ACI_{}";allow (read, search, compare)'.format(i)
@@ -147,9 +158,9 @@ def test_more_then_40_acl_will_crash_slapd(topo, clean, aci_of_user):
 
 @pytest.mark.bz345643
 def test_search_access_should_not_include_read_access(topo, clean, aci_of_user):
-    """
-    bug 345643
+    """bug 345643
     Misc Test 4 search access should not include read access
+
     :id: 98ab173e-7db8-11e8-a309-8c16451d917b
     :setup: Standalone Instance
     :steps:
@@ -163,7 +174,7 @@ def test_search_access_should_not_include_read_access(topo, clean, aci_of_user):
     """
     assert Domain(topo.standalone, DEFAULT_SUFFIX).present('aci')
     Domain(topo.standalone, DEFAULT_SUFFIX)\
-        .add("aci", [f'(target ="ldap:///{DEFAULT_SUFFIX}")(targetattr !="userPassword")'
+        .replace("aci", [f'(target ="ldap:///{DEFAULT_SUFFIX}")(targetattr != "userPassword")'
                      '(version 3.0;acl "anonymous access";allow (search)'
                      '(userdn = "ldap:///anyone");)',
                      f'(target="ldap:///{DEFAULT_SUFFIX}") (targetattr = "*")(version 3.0; '
@@ -176,13 +187,13 @@ def test_search_access_should_not_include_read_access(topo, clean, aci_of_user):
     conn = Anonymous(topo.standalone).bind()
     # search_access_should_not_include_read_access
     suffix = Domain(conn, DEFAULT_SUFFIX)
-    with pytest.raises(AssertionError):
+    with pytest.raises(Exception):
         assert suffix.present('aci')
 
 
 def test_only_allow_some_targetattr(topo, clean, aci_of_user):
-    """
-    Misc Test 5 only allow some targetattr (1/2)
+    """Misc Test 5 only allow some targetattr (1/2)
+
     :id: 9d27f048-7db8-11e8-a71c-8c16451d917b
     :setup: Standalone Instance
     :steps:
@@ -211,17 +222,17 @@ def test_only_allow_some_targetattr(topo, clean, aci_of_user):
     # aci will allow only mail targetattr
     assert len(accounts.filter('(mail=*)')) == 2
     # aci will allow only mail targetattr
-    assert not accounts.filter('(cn=*)')
+    assert not accounts.filter('(cn=*)', scope=1)
     # with root no , blockage
-    assert len(Accounts(topo.standalone, DEFAULT_SUFFIX).filter('(uid=*)')) == 2
+    assert len(Accounts(topo.standalone, DEFAULT_SUFFIX).filter('(uid=*)', scope=1)) == 2
 
     for i in uas.list():
         i.delete()
 
 
-def test_only_allow_some_targetattr_two(topo, clean, aci_of_user):
-    """
-    Misc Test 6 only allow some targetattr (2/2)"
+def test_only_allow_some_targetattr_two(topo, clean, aci_of_user, request):
+    """Misc Test 6 only allow some targetattr (2/2)"
+
     :id: a188239c-7db8-11e8-903e-8c16451d917b
     :setup: Standalone Instance
     :steps:
@@ -244,15 +255,15 @@ def test_only_allow_some_targetattr_two(topo, clean, aci_of_user):
 
     Domain(topo.standalone, DEFAULT_SUFFIX).\
         replace("aci", '(target="ldap:///{}") (targetattr="mail||objectClass")'
-                       '(targetfilter="cn=Anuj") (version 3.0; acl "$tet_thistest"; '
+                       '(targetfilter="cn=Anuj") (version 3.0; acl "{}"; '
                        'allow (compare,read,search) '
-                       '(userdn = "ldap:///anyone"); )'.format(DEFAULT_SUFFIX))
+                       '(userdn = "ldap:///anyone"); )'.format(DEFAULT_SUFFIX, request.node.name))
 
     conn = UserAccount(topo.standalone, user.dn).bind(PW_DM)
     # aci will allow only mail targetattr but only for cn=Anuj
     account = Accounts(conn, DEFAULT_SUFFIX)
-    assert len(account.filter('(mail=*)')) == 5
-    assert not account.filter('(cn=*)')
+    assert len(account.filter('(mail=*)', scope=1)) == 5
+    assert not account.filter('(cn=*)', scope=1)
 
     for i in account.filter('(mail=*)'):
         assert i.get_attr_val_utf8('mail') == 'anujborah@anujborah.com'
@@ -261,8 +272,8 @@ def test_only_allow_some_targetattr_two(topo, clean, aci_of_user):
     conn = Anonymous(topo.standalone).bind()
     # aci will allow only mail targetattr but only for cn=Anuj
     account = Accounts(conn, DEFAULT_SUFFIX)
-    assert len(account.filter('(mail=*)')) == 5
-    assert not account.filter('(cn=*)')
+    assert len(account.filter('(mail=*)', scope=1)) == 5
+    assert not account.filter('(cn=*)', scope=1)
 
     for i in account.filter('(mail=*)'):
         assert i.get_attr_val_utf8('mail') == 'anujborah@anujborah.com'
@@ -274,11 +285,10 @@ def test_only_allow_some_targetattr_two(topo, clean, aci_of_user):
         i.delete()
 
 
-
 @pytest.mark.bz326000
 def test_memberurl_needs_to_be_normalized(topo, clean, aci_of_user):
-    """
-    Non-regression test for BUG 326000: MemberURL needs to be normalized
+    """Non-regression test for BUG 326000: MemberURL needs to be normalized
+
     :id: a5d172e6-7db8-11e8-aca7-8c16451d917b
     :setup: Standalone Instance
     :steps:
@@ -291,7 +301,7 @@ def test_memberurl_needs_to_be_normalized(topo, clean, aci_of_user):
         3. Operation should  succeed
     """
     ou_ou = OrganizationalUnit(topo.standalone, "ou=PEOPLE,{}".format(DEFAULT_SUFFIX))
-    ou_ou.set('aci', '(targetattr= *)'
+    ou_ou.set('aci', '(targetattr="*")'
                      '(version 3.0; acl "tester"; allow(all) '
                      'groupdn = "ldap:///cn =DYNGROUP,ou=PEOPLE, {}";)'.format(DEFAULT_SUFFIX))
 
@@ -323,8 +333,8 @@ def test_memberurl_needs_to_be_normalized(topo, clean, aci_of_user):
 
 @pytest.mark.bz624370
 def test_greater_than_200_acls_can_be_created(topo, clean, aci_of_user):
-    """
-    Misc 10, check that greater than 200 ACLs can be created. Bug 624370
+    """Misc 10, check that greater than 200 ACLs can be created. Bug 624370
+
     :id: ac020252-7db8-11e8-8652-8c16451d917b
     :setup: Standalone Instance
     :steps:
@@ -355,8 +365,8 @@ def test_greater_than_200_acls_can_be_created(topo, clean, aci_of_user):
 
 @pytest.mark.bz624453
 def test_server_bahaves_properly_with_very_long_attribute_names(topo, clean, aci_of_user):
-    """
-    Make sure the server bahaves properly with very long attribute names. Bug 624453.
+    """Make sure the server bahaves properly with very long attribute names. Bug 624453.
+
     :id: b0d31942-7db8-11e8-a833-8c16451d917b
     :setup: Standalone Instance
     :steps:
@@ -378,24 +388,23 @@ def test_server_bahaves_properly_with_very_long_attribute_names(topo, clean, aci
 
 
 def test_do_bind_as_201_distinct_users(topo, clean, aci_of_user):
-    """
-    Do bind as 201 distinct users
-    Increase the nsslapd-aclpb-max-selected-acls in cn=ACL Plugin,cn=plugins,cn=config
-    Restart the server
-    Do bind as 201 distinct users
+    """Test bind as 201 distinct users
+
     :id: c0060532-7db8-11e8-a124-8c16451d917b
     :setup: Standalone Instance
     :steps:
-        1. Add test entry
-        2. Add ACI
-        3. User should follow ACI role
+        1. Add test entries
+        2. Increase the nsslapd-aclpb-max-selected-acls in cn=ACL Plugin,cn=plugins,cn=config
+        3. Restart the server
+        4. Do bind as 201 distinct users
     :expectedresults:
-        1. Entry should be added
-        2. Operation should  succeed
-        3. Operation should  succeed
+        1. Entries should be added
+        2. Operation should succeed
+        3. Operation should succeed
+        4. Operation should succeed
     """
     uas = UserAccounts(topo.standalone, DEFAULT_SUFFIX)
-    for i in range(50):
+    for i in range(201):
         user = uas.create_test_user(uid=i, gid=i)
         user.set('userPassword', PW_DM)
 
@@ -408,7 +417,6 @@ def test_do_bind_as_201_distinct_users(topo, clean, aci_of_user):
     for i in range(len(uas.list())):
         uas.list()[i].bind(PW_DM)
 
-
 if __name__ == "__main__":
     CURRENT_FILE = os.path.realpath(__file__)
     pytest.main("-s -v %s" % CURRENT_FILE)
