@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2016 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -47,7 +47,7 @@ def enable_user_attr_encryption(topo, request):
     users = UserAccounts(topo.standalone, DEFAULT_SUFFIX)
     test_user = users.create(properties=TEST_USER_PROPERTIES)
     test_user.replace('employeeNumber', '1000')
-    test_user.replace('telephonenumber', '1234567890')
+    test_user.replace('telephoneNumber', '1234567890')
 
     def fin():
         log.info("Remove attribute encryption for various attributes")
@@ -60,6 +60,7 @@ def enable_user_attr_encryption(topo, request):
 
 def test_basic(topo, enable_user_attr_encryption):
     """Tests encrypted attributes with a test user entry
+
     :id: d767d5c8-b934-4b14-9774-bd13480d81b3
     :setup: Standalone instance
             Enable AES encryption config on employeenumber
@@ -69,8 +70,8 @@ def test_basic(topo, enable_user_attr_encryption):
          1. Restart the server
          2. Check employeenumber encryption enabled
          3. Check telephoneNumber encryption enabled
-         4. Check that encrypted attribute is present for user i.e. telephonenumber
-     :expectedresults:
+         4. Check that encrypted attribute is present for user i.e. telephoneNumber
+    :expectedresults:
          1. This should be successful
          2. This should be successful
          3. This should be successful
@@ -95,12 +96,13 @@ def test_basic(topo, enable_user_attr_encryption):
     log.info("Check telephoneNumber encryption is enabled")
     assert "telephoneNumber" in enc_attrs_cns
 
-    log.info("Check that encrypted attribute is present for user i.e. telephonenumber")
+    log.info("Check that encrypted attribute is present for user i.e. telephoneNumber")
     assert enable_user_attr_encryption.present('telephoneNumber')
 
 
 def test_export_import_ciphertext(topo, enable_user_attr_encryption):
     """Configure attribute encryption, store some data, check that we can export the ciphertext
+
     :id: b433e215-2926-48a5-818f-c21abc40fc2d
     :setup: Standalone instance
             Enable AES encryption config on employeenumber
@@ -137,8 +139,8 @@ def test_export_import_ciphertext(topo, enable_user_attr_encryption):
     log.info("Check that the encrypted value of attribute is not present in the exported file")
     with open(export_ldif, 'r') as ldif_file:
         ldif = ldif_file.read()
-        assert 'telephonenumber' in ldif
-        assert 'telephonenumber: 1234567890' not in ldif
+        assert 'telephoneNumber' in ldif
+        assert 'telephoneNumber: 1234567890' not in ldif
 
     log.info("Delete the test user entry with encrypted data")
     enable_user_attr_encryption.delete()
@@ -162,6 +164,7 @@ def test_export_import_ciphertext(topo, enable_user_attr_encryption):
 
 def test_export_import_plaintext(topo, enable_user_attr_encryption):
     """Configure attribute encryption, store some data, check that we can export the plain text
+
      :id: b171e215-0456-48a5-245f-c21abc40fc2d
      :setup: Standalone instance
              Enable AES encryption config on employeenumber
@@ -221,6 +224,7 @@ def test_export_import_plaintext(topo, enable_user_attr_encryption):
 
 def test_attr_encryption_unindexed(topo, enable_user_attr_encryption):
     """Configure attribute encryption for an un-indexed attribute, check that we can export encrypted data
+
     :id: d3ef38e1-bb5a-44d8-a3a4-4a25a57e3454
     :setup: Standalone instance
             Enable AES encryption config on employeenumber
@@ -257,12 +261,13 @@ def test_attr_encryption_unindexed(topo, enable_user_attr_encryption):
 def test_attr_encryption_multiple_backends(topo, enable_user_attr_encryption):
     """Tests Configuration of attribute encryption for multiple backends
        Where both the backends have attribute encryption
-    :id: f3ef40e1-17d6-44d8-a3a4-4a25a57e9064
+
+    :id: 9ece3e6c-96b7-4dd5-b092-d76dda23472d
     :setup: Standalone instance
             SSL Enabled
     :steps:
          1. Add two test backends
-         2. Configure attribute encryption for telephonenumber in one test backend
+         2. Configure attribute encryption for telephoneNumber in one test backend
          3. Configure attribute encryption for employeenumber in another test backend
          4. Add a test user in both backends with encrypted attributes
          5. Export data as ciphertext from both backends
@@ -357,6 +362,7 @@ def test_attr_encryption_multiple_backends(topo, enable_user_attr_encryption):
 def test_attr_encryption_backends(topo, enable_user_attr_encryption):
     """Tests Configuration of attribute encryption for single backend
        where more backends are present
+
     :id: f3ef40e1-17d6-44d8-a3a4-4a25a57e9064
     :setup: Standalone instance
             SSL Enabled
@@ -365,8 +371,8 @@ def test_attr_encryption_backends(topo, enable_user_attr_encryption):
          2. Configure attribute encryption for telephoneNumber in one test backend
          3. Add a test user in both backends with telephoneNumber
          4. Export ldif from both test backends
-         5. Check that telephonenumber is encrypted in the ldif file of db1
-         6. Check that telephonenumber is not encrypted in the ldif file of db2
+         5. Check that telephoneNumber is encrypted in the ldif file of db1
+         6. Check that telephoneNumber is not encrypted in the ldif file of db2
          7. Delete both test backends
     :expectedresults:
          1. This should be successful
