@@ -108,8 +108,8 @@ def reset_logs(topo):
 
 @disk_monitoring_ack
 def test_verify_operation_when_disk_monitoring_is_off(topo, setup, reset_logs):
-    """
-    Verify operation when Disk monitoring is off
+    """Verify operation when Disk monitoring is off
+
     :id: 73a97536-fe9e-11e8-ba9f-8c16451d917b
     :setup: Standalone
     :steps:
@@ -138,9 +138,43 @@ def test_verify_operation_when_disk_monitoring_is_off(topo, setup, reset_logs):
 
 
 @disk_monitoring_ack
-def test_free_up_the_disk_space_and_change_ds_config(topo, setup, reset_logs):
+def test_enable_external_libs_debug_log(topo, setup, reset_logs):
+    """Check that OpenLDAP logs are successfully enabled and disabled when
+    disk threshold is reached
+
+    :id: 121b2b24-ecba-48e2-9ee2-312d929dc8c6
+    :setup: Standalone instance
+    :steps: 1. Set nsslapd-external-libs-debug-enabled to "on"
+            2. Go straight below 1/2 of the threshold
+            3. Verify that the external libs debug setting is disabled
+            4. Go back above 1/2 of the threshold
+            5. Verify that the external libs debug setting is enabled back
+    :expectedresults: 1. Success
+                      2. Success
+                      3. Success
+                      4. Success
+                      5. Success
     """
-    Free up the disk space and change DS config
+    try:
+        # Verify that verbose logging was set to default level
+        assert topo.standalone.config.set('nsslapd-disk-monitoring', 'on')
+        assert topo.standalone.config.set('nsslapd-disk-monitoring-logging-critical', 'off')
+        assert topo.standalone.config.set('nsslapd-external-libs-debug-enabled', 'on')
+        assert topo.standalone.config.set('nsslapd-errorlog-level', '8')
+        topo.standalone.restart()
+        subprocess.call(['dd', 'if=/dev/zero', 'of={}/foo'.format(topo.standalone.ds_paths.log_dir), 'bs=1M', 'count={}'.format(HALF_THR_FILL_SIZE)])
+        # Verify that logging is disabled
+        _withouterrorlog(topo, "topo.standalone.config.get_attr_val_utf8('nsslapd-external-libs-debug-enabled') != 'off'", 31)
+    finally:
+        os.remove('{}/foo'.format(topo.standalone.ds_paths.log_dir))
+        _withouterrorlog(topo, "topo.standalone.config.get_attr_val_utf8('nsslapd-external-libs-debug-enabled') != 'on'", 31)
+        assert topo.standalone.config.set('nsslapd-external-libs-debug-enabled', 'off')
+
+
+@disk_monitoring_ack
+def test_free_up_the_disk_space_and_change_ds_config(topo, setup, reset_logs):
+    """Free up the disk space and change DS config
+
     :id: 7be4d560-fe9e-11e8-a307-8c16451d917b
     :setup: Standalone
     :steps:
@@ -170,8 +204,8 @@ def test_free_up_the_disk_space_and_change_ds_config(topo, setup, reset_logs):
 
 @disk_monitoring_ack
 def test_verify_operation_with_nsslapd_disk_monitoring_logging_critical_off(topo, setup, reset_logs):
-    """
-    Verify operation with "nsslapd-disk-monitoring-logging-critical: off
+    """Verify operation with "nsslapd-disk-monitoring-logging-critical: off
+
     :id: 82363bca-fe9e-11e8-9ae7-8c16451d917b
     :setup: Standalone
     :steps:
@@ -210,9 +244,9 @@ def test_verify_operation_with_nsslapd_disk_monitoring_logging_critical_off(topo
 
 @disk_monitoring_ack
 def test_operation_with_nsslapd_disk_monitoring_logging_critical_on_below_half_of_the_threshold(topo, setup, reset_logs):
-    """
-    Verify operation with \"nsslapd-disk-monitoring-logging-critical: on\" below 1/2 of the threshold
+    """Verify operation with \"nsslapd-disk-monitoring-logging-critical: on\" below 1/2 of the threshold
     Verify recovery
+
     :id: 8940c502-fe9e-11e8-bcc0-8c16451d917b
     :setup: Standalone
     :steps:
@@ -239,12 +273,12 @@ def test_operation_with_nsslapd_disk_monitoring_logging_critical_on_below_half_o
 
 @disk_monitoring_ack
 def test_setting_nsslapd_disk_monitoring_logging_critical_to_off(topo, setup, reset_logs):
-    """
-    Setting nsslapd-disk-monitoring-logging-critical to \"off\
+    """Setting nsslapd-disk-monitoring-logging-critical to "off"
+
     :id: 93265ec4-fe9e-11e8-af93-8c16451d917b
     :setup: Standalone
     :steps:
-        1. Setting nsslapd-disk-monitoring-logging-critical to \"off\
+        1. Setting nsslapd-disk-monitoring-logging-critical to "off"
     :expectedresults:
         1. Should Success
     """
@@ -257,8 +291,8 @@ def test_setting_nsslapd_disk_monitoring_logging_critical_to_off(topo, setup, re
 
 @disk_monitoring_ack
 def test_operation_with_nsslapd_disk_monitoring_logging_critical_off(topo, setup, reset_logs):
-    """
-    Verify operation with \"nsslapd-disk-monitoring-logging-critical: off
+    """Verify operation with nsslapd-disk-monitoring-logging-critical: off
+
     :id: 97985a52-fe9e-11e8-9914-8c16451d917b
     :setup: Standalone
     :steps:
@@ -325,10 +359,10 @@ def test_operation_with_nsslapd_disk_monitoring_logging_critical_off(topo, setup
 
 @disk_monitoring_ack
 def test_operation_with_nsslapd_disk_monitoring_logging_critical_off_below_half_of_the_threshold(topo, setup, reset_logs):
-    """
-    Verify operation with \"nsslapd-disk-monitoring-logging-critical: off\" below 1/2 of the threshold
+    """Verify operation with nsslapd-disk-monitoring-logging-critical: off below 1/2 of the threshold
     Verify shutdown
     Recovery and setup
+
     :id: 9d4c7d48-fe9e-11e8-b5d6-8c16451d917b
     :setup: Standalone
     :steps:
@@ -401,9 +435,9 @@ def test_operation_with_nsslapd_disk_monitoring_logging_critical_off_below_half_
 
 @disk_monitoring_ack
 def test_go_straight_below_half_of_the_threshold(topo, setup, reset_logs):
-    """
-    Go straight below 1/2 of the threshold
+    """Go straight below 1/2 of the threshold
     Recovery and setup
+
     :id: a2a0664c-fe9e-11e8-b220-8c16451d917b
     :setup: Standalone
     :steps:
@@ -558,7 +592,7 @@ def test_below_half_of_the_threshold_not_starting_after_shutdown(topo, setup, re
         1. Go straight below 1/2 of the threshold
         2. Try to start the instance
         3. Go back above the threshold
-        2. Try to start the instance
+        4. Try to start the instance
     :expectedresults:
         1. Should Success
         2. Should Fail
@@ -591,8 +625,8 @@ def test_below_half_of_the_threshold_not_starting_after_shutdown(topo, setup, re
 
 @disk_monitoring_ack
 def test_go_straight_below_4kb(topo, setup, reset_logs):
-    """
-    Go straight below 4KB
+    """Go straight below 4KB
+
     :id: a855115a-fe9e-11e8-8e91-8c16451d917b
     :setup: Standalone
     :steps:
@@ -616,8 +650,8 @@ def test_go_straight_below_4kb(topo, setup, reset_logs):
 @disk_monitoring_ack
 @pytest.mark.bz982325
 def test_threshold_to_overflow_value(topo, setup, reset_logs):
-    """
-    Overflow in nsslapd-disk-monitoring-threshold
+    """Overflow in nsslapd-disk-monitoring-threshold
+
     :id: ad60ab3c-fe9e-11e8-88dc-8c16451d917b
     :setup: Standalone
     :steps:
@@ -636,8 +670,8 @@ def test_threshold_to_overflow_value(topo, setup, reset_logs):
 @disk_monitoring_ack
 @pytest.mark.bz970995
 def test_threshold_is_reached_to_half(topo, setup, reset_logs):
-    """
-    RHDS not shutting down when disk monitoring threshold is reached to half.
+    """RHDS not shutting down when disk monitoring threshold is reached to half.
+
     :id: b2d3665e-fe9e-11e8-b9c0-8c16451d917b
     :setup: Standalone
     :steps: Standalone
@@ -677,8 +711,7 @@ def test_threshold_is_reached_to_half(topo, setup, reset_logs):
     ("nsslapd-disk-monitoring-grace-period", '0'),
 ])
 def test_negagtive_parameterize(topo, setup, reset_logs, test_input, expected):
-    """
-    Verify that invalid operations are not permitted
+    """Verify that invalid operations are not permitted
 
     :id: b88efbf8-fe9e-11e8-8499-8c16451d917b
     :parametrized: yes
@@ -694,8 +727,8 @@ def test_negagtive_parameterize(topo, setup, reset_logs, test_input, expected):
 
 @disk_monitoring_ack
 def test_valid_operations_are_permitted(topo, setup, reset_logs):
-    """
-    Verify that valid operations are  permitted
+    """Verify that valid operations are  permitted
+
     :id: bd4f83f6-fe9e-11e8-88f4-8c16451d917b
     :setup: Standalone
     :steps:
@@ -735,3 +768,4 @@ def test_valid_operations_are_permitted(topo, setup, reset_logs):
 if __name__ == '__main__':
     CURRENT_FILE = os.path.realpath(__file__)
     pytest.main("-s -v %s" % CURRENT_FILE)
+
