@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2015 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -10,15 +10,14 @@ from decimal import *
 import os
 import logging
 import pytest
-import subprocess
 from lib389._mapped_object import DSLdapObject
 from lib389.topologies import topology_st
 from lib389.plugins import AutoMembershipPlugin, ReferentialIntegrityPlugin, AutoMembershipDefinitions
 from lib389.idm.user import UserAccounts
 from lib389.idm.group import Groups
 from lib389.idm.organizationalunit import OrganizationalUnits
-from lib389._constants import DEFAULT_SUFFIX, LOG_ACCESS_LEVEL, DN_CONFIG, HOST_STANDALONE, PORT_STANDALONE, DN_DM, PASSWORD
-from lib389.utils import ds_is_older
+from lib389._constants import DEFAULT_SUFFIX, LOG_ACCESS_LEVEL, PASSWORD
+from lib389.utils import ds_is_older, ds_is_newer
 import ldap
 import glob
 
@@ -195,7 +194,17 @@ def set_audit_log_config_values(topology_st, request, enabled, logsize):
 def set_audit_log_config_values_to_rotate(topology_st, request):
     set_audit_log_config_values(topology_st, request, 'on', '1')
 
+@pytest.fixture(scope="function")
+def disable_access_log_buffering(topology_st, request):
+    log.info('Disable access log buffering')
+    topology_st.standalone.config.set('nsslapd-accesslog-logbuffering', 'off')
+    def fin():
+        log.info('Enable access log buffering')
+        topology_st.standalone.config.set('nsslapd-accesslog-logbuffering', 'on')
 
+    request.addfinalizer(fin)
+
+    return disable_access_log_buffering
 
 @pytest.mark.bz1273549
 def test_check_default(topology_st):
@@ -241,7 +250,7 @@ def test_plugin_set_invalid(topology_st):
 
     log.info('test_plugin_set_invalid - Expect to fail with junk value')
     with pytest.raises(ldap.OPERATIONS_ERROR):
-        result = topology_st.standalone.config.set(PLUGIN_TIMESTAMP, 'JUNK')
+        topology_st.standalone.config.set(PLUGIN_TIMESTAMP, 'JUNK')
 
 
 @pytest.mark.bz1273549
@@ -278,7 +287,7 @@ def test_log_plugin_on(topology_st, remove_users):
     access_log_lines = topology_st.standalone.ds_access_log.readlines()
     assert len(access_log_lines) > 0
     assert topology_st.standalone.ds_access_log.match(r'^\[.+\d{9}.+\].+')
- 
+
 
 @pytest.mark.bz1273549
 def test_log_plugin_off(topology_st, remove_users):
@@ -333,8 +342,9 @@ def test_log_plugin_off(topology_st, remove_users):
 @pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 @pytest.mark.bz1358706
 @pytest.mark.ds49029
-def test_internal_log_server_level_0(topology_st, clean_access_logs):
+def test_internal_log_server_level_0(topology_st, clean_access_logs, disable_access_log_buffering):
     """Tests server-initiated internal operations
+
     :id: 798d06fe-92e8-4648-af66-21349c20638e
     :setup: Standalone instance
     :steps:
@@ -378,22 +388,23 @@ def test_internal_log_server_level_0(topology_st, clean_access_logs):
 @pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 @pytest.mark.bz1358706
 @pytest.mark.ds49029
-def test_internal_log_server_level_4(topology_st, clean_access_logs):
+def test_internal_log_server_level_4(topology_st, clean_access_logs, disable_access_log_buffering):
     """Tests server-initiated internal operations
+
     :id: a3500e47-d941-4575-b399-e3f4b49bc4b6
     :setup: Standalone instance
     :steps:
         1. Set nsslapd-plugin-logging to on
         2. Configure access log level to only 4
         3. Check the access logs, it should contain info about MOD operation of cn=config and other
-        internal operations should have the conn field set to Internal
-        and all values inside parenthesis set to 0.
+           internal operations should have the conn field set to Internal
+           and all values inside parenthesis set to 0.
     :expectedresults:
         1. Operation should be successful
         2. Operation should be successful
         3. Access log should contain correct internal log formats with cn=config modification:
-        "(Internal) op=2(1)(1)"
-        "conn=Internal(0)"
+           "(Internal) op=2(1)(1)"
+           "conn=Internal(0)"
     """
 
     topo = topology_st.standalone
@@ -414,8 +425,8 @@ def test_internal_log_server_level_4(topology_st, clean_access_logs):
         log.info("Check if access log contains internal MOD operation in correct format")
         # (Internal) op=2(2)(1) SRCH base="cn=config
         assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="cn=config.*')
-        # (Internal) op=2(2)(1) RESULT err=0 tag=48 nentries=1
-        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=1.*')
+        # (Internal) op=2(2)(1) RESULT err=0 tag=48 nentries=
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=.*')
 
         log.info("Check if the other internal operations have the correct format")
         # conn=Internal(0) op=0
@@ -427,8 +438,9 @@ def test_internal_log_server_level_4(topology_st, clean_access_logs):
 @pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 @pytest.mark.bz1358706
 @pytest.mark.ds49029
-def test_internal_log_level_260(topology_st, add_user_log_level_260):
+def test_internal_log_level_260(topology_st, add_user_log_level_260, disable_access_log_buffering):
     """Tests client initiated operations when automember plugin is enabled
+
     :id: e68a303e-c037-42b2-a5a0-fbea27c338a9
     :setup: Standalone instance with internal operation
             logging on and nsslapd-plugin-logging to on
@@ -481,9 +493,10 @@ def test_internal_log_level_260(topology_st, add_user_log_level_260):
     #      'newrdn="uid=new_test_user_777" newsuperior="dc=example,dc=com"
     assert topo.ds_access_log.match(r'.*op=[0-9]+ MODRDN dn="uid=test_user_777,ou=branch1,dc=example,dc=com" '
                                     'newrdn="uid=new_test_user_777" newsuperior="dc=example,dc=com".*')
-    # (Internal) op=12(1)(1) SRCH base="uid=test_user_777, ou=branch1,dc=example,dc=com"
-    assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=test_user_777,'
-                                    'ou=branch1,dc=example,dc=com".*')
+    if ds_is_older(('1.4.3.9', '1.4.4.3')):
+        # (Internal) op=12(1)(1) SRCH base="uid=test_user_777, ou=branch1,dc=example,dc=com"
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=test_user_777,'
+                                        'ou=branch1,dc=example,dc=com".*')
     # (Internal) op=12(1)(1) RESULT err=0 tag=48 nentries=1
     assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=1.*')
     # op=12 RESULT err=0 tag=109
@@ -492,9 +505,10 @@ def test_internal_log_level_260(topology_st, add_user_log_level_260):
     log.info("Check the access logs for DEL operation of the user")
     # op=15 DEL dn="uid=new_test_user_777,dc=example,dc=com"
     assert topo.ds_access_log.match(r'.*op=[0-9]+ DEL dn="uid=new_test_user_777,dc=example,dc=com".*')
-    # (Internal) op=15(1)(1) SRCH base="uid=new_test_user_777, dc=example,dc=com"
-    assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=new_test_user_777,'
-                                    'dc=example,dc=com".*')
+    if ds_is_older(('1.4.3.9', '1.4.4.3')):
+        # (Internal) op=15(1)(1) SRCH base="uid=new_test_user_777, dc=example,dc=com"
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=new_test_user_777,'
+                                        'dc=example,dc=com".*')
     # (Internal) op=15(1)(1) RESULT err=0 tag=48 nentries=1
     assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=1.*')
     # op=15 RESULT err=0 tag=107
@@ -508,8 +522,9 @@ def test_internal_log_level_260(topology_st, add_user_log_level_260):
 @pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 @pytest.mark.bz1358706
 @pytest.mark.ds49029
-def test_internal_log_level_131076(topology_st, add_user_log_level_131076):
+def test_internal_log_level_131076(topology_st, add_user_log_level_131076, disable_access_log_buffering):
     """Tests client-initiated operations while referential integrity plugin is enabled
+
     :id: 44836ac9-dabd-4a8c-abd5-ecd7c2509739
     :setup: Standalone instance
             Configure access log level to - 131072 + 4
@@ -563,9 +578,10 @@ def test_internal_log_level_131076(topology_st, add_user_log_level_131076):
     #      'newrdn="uid=new_test_user_777" newsuperior="dc=example,dc=com"
     assert not topo.ds_access_log.match(r'.*op=[0-9]+ MODRDN dn="uid=test_user_777,ou=branch1,dc=example,dc=com" '
                                         'newrdn="uid=new_test_user_777" newsuperior="dc=example,dc=com".*')
-    # (Internal) op=12(1)(1) SRCH base="uid=test_user_777, ou=branch1,dc=example,dc=com"
-    assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=test_user_777,'
-                                    'ou=branch1,dc=example,dc=com".*')
+    if ds_is_older(('1.4.3.9', '1.4.4.3')):
+        # (Internal) op=12(1)(1) SRCH base="uid=test_user_777, ou=branch1,dc=example,dc=com"
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=test_user_777,'
+                                        'ou=branch1,dc=example,dc=com".*')
     # (Internal) op=12(1)(1) RESULT err=0 tag=48 nentries=1
     assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=1.*')
     # op=12 RESULT err=0 tag=109
@@ -574,9 +590,10 @@ def test_internal_log_level_131076(topology_st, add_user_log_level_131076):
     log.info("Check the access logs for DEL operation of the user")
     # op=15 DEL dn="uid=new_test_user_777,dc=example,dc=com"
     assert not topo.ds_access_log.match(r'.*op=[0-9]+ DEL dn="uid=new_test_user_777,dc=example,dc=com".*')
-    # (Internal) op=15(1)(1) SRCH base="uid=new_test_user_777, dc=example,dc=com"
-    assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=new_test_user_777,'
-                                    'dc=example,dc=com".*')
+    if ds_is_older(('1.4.3.9', '1.4.4.3')):
+        # (Internal) op=15(1)(1) SRCH base="uid=new_test_user_777, dc=example,dc=com"
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=new_test_user_777,'
+                                        'dc=example,dc=com".*')
     # (Internal) op=15(1)(1) RESULT err=0 tag=48 nentries=1
     assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=1.*')
     # op=15 RESULT err=0 tag=107
@@ -590,8 +607,9 @@ def test_internal_log_level_131076(topology_st, add_user_log_level_131076):
 @pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 @pytest.mark.bz1358706
 @pytest.mark.ds49029
-def test_internal_log_level_516(topology_st, add_user_log_level_516):
+def test_internal_log_level_516(topology_st, add_user_log_level_516, disable_access_log_buffering):
     """Tests client initiated operations when referential integrity plugin is enabled
+
     :id: bee1d681-763d-4fa5-aca2-569cf93f8b71
     :setup: Standalone instance
             Configure access log level to - 512+4
@@ -635,39 +653,39 @@ def test_internal_log_level_516(topology_st, add_user_log_level_516):
                                     r'SRCH base="cn=group,ou=Groups,dc=example,dc=com".*')
     # (Internal) op=10(1)(2) ENTRY dn="cn=group,ou=Groups,dc=example,dc=com"
     assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) '
-                                    r'ENTRY dn="cn=group,ou=Groups,dc=example,dc=com".*')
+                                    r'ENTRY dn="cn=group,ou=groups,dc=example,dc=com".*')
     # (Internal) op=10(1)(2) RESULT err=0 tag=48 nentries=1*')
     assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=1*')
     # (Internal) op=10(1)(1) RESULT err=0 tag=48
     assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48.*')
-    # op=10 RESULT err=0 tag=105
-    assert not topo.ds_access_log.match(r'.*op=[0-9]+ RESULT err=0 tag=105.*')
 
     log.info("Check the access logs for MOD operation of the user")
     # op=12 MODRDN dn="uid=test_user_777,ou=branch1,dc=example,dc=com" '
     #      'newrdn="uid=new_test_user_777" newsuperior="dc=example,dc=com"
     assert not topo.ds_access_log.match(r'.*op=[0-9]+ MODRDN dn="uid=test_user_777,ou=branch1,dc=example,dc=com" '
                                         'newrdn="uid=new_test_user_777" newsuperior="dc=example,dc=com".*')
-    # Internal) op=12(1)(1) SRCH base="uid=test_user_777, ou=branch1,dc=example,dc=com"
-    assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=test_user_777,'
-                                    'ou=branch1,dc=example,dc=com".*')
-    # (Internal) op=12(1)(1) ENTRY dn="uid=test_user_777, ou=branch1,dc=example,dc=com"
-    assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) ENTRY dn="uid=test_user_777,'
-                                    'ou=branch1,dc=example,dc=com".*')
+    if ds_is_older(('1.4.3.9', '1.4.4.3')):
+        # Internal) op=12(1)(1) SRCH base="uid=test_user_777, ou=branch1,dc=example,dc=com"
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=test_user_777,'
+                                        'ou=branch1,dc=example,dc=com".*')
+        # (Internal) op=12(1)(1) ENTRY dn="uid=test_user_777, ou=branch1,dc=example,dc=com"
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) ENTRY dn="uid=test_user_777,'
+                                        'ou=branch1,dc=example,dc=com".*')
     # (Internal) op=12(1)(1) RESULT err=0 tag=48 nentries=1
     assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=1.*')
-    # op=12 RESULT err=0 tag=109
-    assert not topo.ds_access_log.match(r'.*op=[0-9]+ RESULT err=0 tag=109.*')
+    # op=12 RESULT err=0 tag=48
+    assert not topo.ds_access_log.match(r'.*op=[0-9]+ RESULT err=0 tag=48.*')
 
     log.info("Check the access logs for DEL operation of the user")
     # op=15 DEL dn="uid=new_test_user_777,dc=example,dc=com"
     assert not topo.ds_access_log.match(r'.*op=[0-9]+ DEL dn="uid=new_test_user_777,dc=example,dc=com".*')
-    # (Internal) op=15(1)(1) SRCH base="uid=new_test_user_777, dc=example,dc=com"
-    assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=new_test_user_777,'
-                                    'dc=example,dc=com".*')
-    # (Internal) op=15(1)(1) ENTRY dn="uid=new_test_user_777, dc=example,dc=com"
-    assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) ENTRY dn="uid=new_test_user_777,'
-                                    'dc=example,dc=com".*')
+    if ds_is_older(('1.4.3.9', '1.4.4.3')):
+        # (Internal) op=15(1)(1) SRCH base="uid=new_test_user_777, dc=example,dc=com"
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="uid=new_test_user_777,'
+                                        'dc=example,dc=com".*')
+        # (Internal) op=15(1)(1) ENTRY dn="uid=new_test_user_777, dc=example,dc=com"
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) ENTRY dn="uid=new_test_user_777,'
+                                        'dc=example,dc=com".*')
     # (Internal) op=15(1)(1) RESULT err=0 tag=48 nentries=1
     assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=1.*')
     # op=15 RESULT err=0 tag=107
@@ -714,14 +732,13 @@ def test_access_log_truncated_search_message(topology_st, clean_access_logs):
     assert not topo.ds_access_log.match(r'.*cn500.*')
 
 
-
+@pytest.mark.skipif(ds_is_newer("1.4.3"), reason="rsearch was removed")
 @pytest.mark.xfail(ds_is_older('1.4.2.0'), reason="May fail because of bug 1732053")
 @pytest.mark.bz1732053
 @pytest.mark.ds50510
 def test_etime_at_border_of_second(topology_st, clean_access_logs):
     topo = topology_st.standalone
 
-
     prog = os.path.join(topo.ds_paths.bin_dir, 'rsearch')
 
     cmd = [prog]
@@ -759,7 +776,7 @@ def test_etime_at_border_of_second(topology_st, clean_access_logs):
 
 @pytest.mark.skipif(ds_is_older('1.3.10.1'), reason="Fail because of bug 1749236")
 @pytest.mark.bz1749236
-def test_etime_order_of_magnitude(topology_st, clean_access_logs, remove_users):
+def test_etime_order_of_magnitude(topology_st, clean_access_logs, remove_users, disable_access_log_buffering):
     """Test that the etime reported in the access log has a correct order of magnitude
 
     :id: e815cfa0-8136-4932-b50f-c3dfac34b0e6
@@ -773,25 +790,22 @@ def test_etime_order_of_magnitude(topology_st, clean_access_logs, remove_users):
          6. Parse the access log looking for the SRCH operation log
          7. From the SRCH string get the start time and op number of the operation
          8. From the op num find the associated RESULT string in the access log
-         9. From the RESULT string get the end time and the etime for the operation 
-        10. Calculate the ratio between the calculated elapsed time (end time - start time) and the logged etime
+         9. From the RESULT string get the end time and the etime for the operation
+         10. Calculate the ratio between the calculated elapsed time (end time - start time) and the logged etime
     :expectedresults:
          1. access log buffering is off
          2. Previously existing access logs are deleted
          3. Users are successfully added
          4. Search operation is successful
-         5. Server is restarted and logs are flushed 
+         5. Server is restarted and logs are flushed
          6. SRCH operation log string is catched
          7. start time and op number are collected
          8. RESULT string is catched from the access log
          9. end time and etime are collected
-        10. ratio between calculated elapsed time and logged etime is less or equal to 1
+         10. ratio between calculated elapsed time and logged etime is less or equal to 1
     """
 
-    entry = DSLdapObject(topology_st.standalone, DEFAULT_SUFFIX)
-
-    log.info('Set accesslog logbuffering to off to get the log in real time')
-    topology_st.standalone.config.set('nsslapd-accesslog-logbuffering', 'off')
+    DSLdapObject(topology_st.standalone, DEFAULT_SUFFIX)
 
     log.info('add_users')
     add_users(topology_st.standalone, 30)
@@ -822,7 +836,7 @@ def test_etime_order_of_magnitude(topology_st, clean_access_logs, remove_users):
 
     # The result_str returned looks like :
     # [23/Apr/2020:06:06:14.366429900 -0400] conn=1 op=93 RESULT err=0 tag=101 nentries=30 etime=0.005723017
-    
+
     log.info('get the operation end time from the RESULT string')
     # Here we are getting the sec.nanosec part of the date, '14.366429900' in the above example
     end_time = (result_str.split()[0]).split(':')[3]
@@ -840,7 +854,7 @@ def test_etime_order_of_magnitude(topology_st, clean_access_logs, remove_users):
 @pytest.mark.bz1662461
 @pytest.mark.ds50428
 @pytest.mark.ds49969
-def test_log_base_dn_when_invalid_attr_request(topology_st):
+def test_log_base_dn_when_invalid_attr_request(topology_st, disable_access_log_buffering):
     """Test that DS correctly logs the base dn when a search with invalid attribute request is performed
 
     :id: 859de962-c261-4ffb-8705-97bceab1ba2c
@@ -848,7 +862,7 @@ def test_log_base_dn_when_invalid_attr_request(topology_st):
     :steps:
          1. Disable the accesslog-logbuffering config parameter
          2. Delete the previous access log
-         3. Perform a base search on the DEFAULT_SUFFIX, using invalid "" "" attribute request
+         3. Perform a base search on the DEFAULT_SUFFIX, using ten empty attribute requests
          4. Check the access log file for 'invalid attribute request'
          5. Check the access log file for 'SRCH base="\(null\)"'
          6. Check the access log file for 'SRCH base="DEFAULT_SUFFIX"'
@@ -863,17 +877,14 @@ def test_log_base_dn_when_invalid_attr_request(topology_st):
 
     entry = DSLdapObject(topology_st.standalone, DEFAULT_SUFFIX)
 
-    log.info('Set accesslog logbuffering to off to get the log in real time')
-    topology_st.standalone.config.set('nsslapd-accesslog-logbuffering', 'off')
-
     log.info('delete the previous access logs to get a fresh new one')
     topology_st.standalone.deleteAccessLogs()
 
     log.info("Search the default suffix, with invalid '\"\" \"\"' attribute request")
-    log.info("A Protocol error exception should be raised, see https://pagure.io/389-ds-base/issue/49969")
-    # A ldap.PROTOCOL_ERROR exception is expected
+    log.info("A Protocol error exception should be raised, see https://github.com/389ds/389-ds-base/issues/3028")
+    # A ldap.PROTOCOL_ERROR exception is expected after 10 empty values
     with pytest.raises(ldap.PROTOCOL_ERROR):
-        assert entry.get_attrs_vals_utf8(['', ''])
+        assert entry.get_attrs_vals_utf8(['', '', '', '', '', '', '', '', '', '', ''])
 
     # Search for appropriate messages in the access log
     log.info('Check the access logs for correct messages')
@@ -945,6 +956,80 @@ def test_audit_log_rotate_and_check_string(topology_st, clean_access_logs, set_a
         assert count == 1
 
 
+def test_enable_external_libs_debug_log(topology_st):
+    """Check that OpenLDAP logs are successfully enabled and disabled
+
+    :id: b04646e3-9a5e-45ae-ad81-2882c1daf23e
+    :setup: Standalone instance
+    :steps: 1. Create a user to bind on
+            2. Set nsslapd-external-libs-debug-enabled to "on"
+            3. Clean the error log
+            4. Bind as the user to generate OpenLDAP output
+            5. Restart the servers to flush the logs
+            6. Check the error log for OpenLDAP debug log
+            7. Set nsslapd-external-libs-debug-enabled to "on"
+            8. Clean the error log
+            9. Bind as the user to generate OpenLDAP output
+            10. Restart the servers to flush the logs
+            11. Check the error log for OpenLDAP debug log
+    :expectedresults: 1. Success
+                      2. Success
+                      3. Success
+                      4. Success
+                      5. Success
+                      6. Logs are present
+                      7. Success
+                      8. Success
+                      9. Success
+                      10. Success
+                      11. No logs are present
+    """
+
+    standalone = topology_st.standalone
+
+    log.info('Create a user to bind on')
+    users = UserAccounts(standalone, DEFAULT_SUFFIX)
+    user = users.ensure_state(properties={
+            'uid': 'test_audit_log',
+            'cn': 'test',
+            'sn': 'user',
+            'uidNumber': '1000',
+            'gidNumber': '1000',
+            'homeDirectory': '/home/test',
+            'userPassword': PASSWORD
+        })
+
+    log.info('Set nsslapd-external-libs-debug-enabled to "on"')
+    standalone.config.set('nsslapd-external-libs-debug-enabled', 'on')
+
+    log.info('Clean the error log')
+    standalone.deleteErrorLogs()
+
+    log.info('Bind as the user to generate OpenLDAP output')
+    user.bind(PASSWORD)
+
+    log.info('Restart the servers to flush the logs')
+    standalone.restart()
+
+    log.info('Check the error log for OpenLDAP debug log')
+    assert standalone.ds_error_log.match('.*libldap/libber.*')
+
+    log.info('Set nsslapd-external-libs-debug-enabled to "off"')
+    standalone.config.set('nsslapd-external-libs-debug-enabled', 'off')
+
+    log.info('Clean the error log')
+    standalone.deleteErrorLogs()
+
+    log.info('Bind as the user to generate OpenLDAP output')
+    user.bind(PASSWORD)
+
+    log.info('Restart the servers to flush the logs')
+    standalone.restart()
+
+    log.info('Check the error log for OpenLDAP debug log')
+    assert not standalone.ds_error_log.match('.*libldap/libber.*')
+
+
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
