@@ -11,6 +11,7 @@ from lib389.tasks import *
 from lib389.utils import *
 from lib389.topologies import topology_st
 from lib389.idm.user import UserAccounts
+from lib389.idm.domain import Domain
 
 from lib389._constants import DN_DM, DEFAULT_SUFFIX, DN_CONFIG, PASSWORD
 
@@ -30,7 +31,7 @@ TEST_PARAMS = [(DN_ROOT, False, [
                 'supportedControl', 'supportedExtension',
                 'supportedFeatures', 'supportedLDAPVersion',
                 'supportedSASLMechanisms', 'vendorName', 'vendorVersion'
-]),
+               ]),
                (DN_ROOT, True, [
                 'createTimestamp', 'creatorsName',
                 'modifiersName', 'modifyTimestamp', 'namingContexts',
@@ -52,14 +53,15 @@ TEST_PARAMS = [(DN_ROOT, False, [
                (TEST_USER_DN, False, [
                 'createTimestamp', 'creatorsName', 'entrydn',
                 'entryid', 'modifiersName', 'modifyTimestamp',
-                'nsUniqueId', 'parentid'
+                'nsUniqueId', 'parentid', 'entryUUID'
                ]),
                (TEST_USER_DN, True, [
                 'createTimestamp', 'creatorsName', 'entrydn',
-                'entryid', 'modifyTimestamp', 'nsUniqueId', 'parentid'
+                'entryid', 'modifyTimestamp', 'nsUniqueId', 'parentid', 'entryUUID'
                ]),
                (DN_CONFIG, False, [
-                'numSubordinates', 'passwordHistory'
+                'numSubordinates', 'passwordHistory',  'modifyTimestamp',
+                'modifiersName'
                ])
             ]
 
@@ -80,6 +82,18 @@ def create_user(topology_st):
         'homeDirectory': '/home/test'
     })
 
+    # Add anonymous access aci
+    ACI_TARGET = "(targetattr != \"userpassword || aci\")(target = \"ldap:///%s\")" % (DEFAULT_SUFFIX)
+    ACI_ALLOW = "(version 3.0; acl \"Anonymous Read access\"; allow (read,search,compare)"
+    ACI_SUBJECT = "(userdn=\"ldap:///anyone\");)"
+    ANON_ACI = ACI_TARGET + ACI_ALLOW + ACI_SUBJECT
+    suffix = Domain(topology_st.standalone, DEFAULT_SUFFIX)
+    try:
+        suffix.add('aci', ANON_ACI)
+    except ldap.TYPE_OR_VALUE_EXISTS:
+        pass
+
+
 @pytest.fixture(scope="module")
 def user_aci(topology_st):
     """Don't allow modifiersName attribute for the test user
