@@ -19,7 +19,7 @@ from lib389.idm.organizationalunit import OrganizationalUnits
 from lib389.idm.account import Accounts
 from lib389.idm.user import UserAccount, UserAccounts
 from lib389.schema import Schema
-from lib389.idm.role import ManagedRoles, FilterRoles
+from lib389.idm.role import ManagedRoles, FilteredRoles
 
 pytestmark = pytest.mark.tier1
 
@@ -496,7 +496,7 @@ def _create_test_entries(topo):
         'cn': 'new managed role'})
 
     # Creating filter role
-    filters = FilterRoles(topo.standalone, DEFAULT_SUFFIX)
+    filters = FilteredRoles(topo.standalone, DEFAULT_SUFFIX)
     filters.create(properties={
         'nsRoleFilter': '(uid=*wal*)',
         'description': 'this is the new filtered role',
@@ -517,7 +517,9 @@ def _create_test_entries(topo):
 def test_param_positive(topo, _create_test_entries, real_value):
     """
     Will test Filters with positive output.
-    :id:71de14a4-9f22-11e8-b5cc-8c16451d917b
+
+    :id: 71de14a4-9f22-11e8-b5cc-8c16451d917b
+    :parametrized: yes
     :setup: Standalone Server
     :steps:
         1. Create Filter rules.
@@ -533,7 +535,9 @@ def test_param_positive(topo, _create_test_entries, real_value):
 def test_param_negative(topo, _create_test_entries, real_value):
     """
     Will test Filetrs with 0 outputs
-    :id:81054e7a-9f22-11e8-a461-8c16451d917b
+
+    :id: 81054e7a-9f22-11e8-a461-8c16451d917b
+    :parametrized: yes
     :setup: Standalone Server
     :steps:
         1. Create Filter rules.
