@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2016 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -14,8 +14,7 @@ from lib389.utils import *
 from lib389.topologies import topology_st
 from lib389.idm.user import UserAccounts
 from lib389.idm.organizationalunit import OrganizationalUnits
-from lib389._constants import (DEFAULT_SUFFIX, DN_CONFIG, PASSWORD, DN_DM,
-                               HOST_STANDALONE, PORT_STANDALONE, SERVERID_STANDALONE)
+from lib389._constants import (DEFAULT_SUFFIX, DN_CONFIG, PASSWORD, DN_DM)
 from dateutil.parser import parse as dt_parse
 from lib389.config import Config
 import datetime
@@ -97,7 +96,6 @@ def global_policy_default(topology_st, request):
 
     def fin():
         """Resets the defaults"""
-
         log.info('Reset the defaults')
         topology_st.standalone.simple_bind_s(DN_DM, PASSWORD)
         for key in attrs.keys():
@@ -142,11 +140,11 @@ def local_policy(topology_st, add_user):
 
     log.info("Setting fine grained policy for user ({})".format(USER_DN))
 
-    subprocess.call(['%s/ns-newpwpolicy.pl' % topology_st.standalone.get_sbin_dir(),
-                     '-D', DN_DM,
-                     '-w', PASSWORD, '-h', HOST_STANDALONE,
-                     '-p', str(PORT_STANDALONE), '-U', USER_DN,
-                     '-Z', SERVERID_STANDALONE])
+    subprocess.call(['%s/dsconf' % topology_st.standalone.get_sbin_dir(),
+                     'slapd-standalone1',
+                     'localpwp',
+                     'adduser',
+                     USER_DN])
     # A short sleep is required after modifying password policy
     time.sleep(0.5)
 
@@ -236,10 +234,10 @@ def test_expiry_time(topology_st, global_policy, add_user):
     :id: 7adfd395-9b25-4cc0-9b71-14710dc1a28c
     :setup: Standalone instance, a user entry,
             Global password policy configured as below:
-                passwordExp: on
-                passwordMaxAge: 172800
-                passwordWarning: 86400
-                passwordSendExpiringTime: on
+            passwordExp: on
+            passwordMaxAge: 172800
+            passwordWarning: 86400
+            passwordSendExpiringTime: on
     :steps:
         1. Bind as the normal user
         2. Request password policy control for the user
@@ -281,10 +279,10 @@ def test_password_warning(topology_st, global_policy, add_user, attr, val):
     :parametrized: yes
     :setup: Standalone instance, a test user,
             Global password policy configured as below:
-                passwordExp: on
-                passwordMaxAge: 172800
-                passwordWarning: 86400
-                passwordSendExpiringTime: on
+            passwordExp: on
+            passwordMaxAge: 172800
+            passwordWarning: 86400
+            passwordSendExpiringTime: on
     :steps:
         1. Set passwordSendExpiringTime attribute to off or
            to on and passwordWarning to a small value (3600)
@@ -324,10 +322,10 @@ def test_with_different_password_states(topology_st, global_policy, add_user):
     :id: d297fb1a-661f-4d52-bb43-2a2a340b8b0e
     :setup: Standalone instance, a user entry,
             Global password policy configured as below:
-                passwordExp: on
-                passwordMaxAge: 172800
-                passwordWarning: 86400
-                passwordSendExpiringTime: on
+            passwordExp: on
+            passwordMaxAge: 172800
+            passwordWarning: 86400
+            passwordSendExpiringTime: on
     :steps:
         1. Expire user's password by changing
            passwordExpirationTime timestamp
@@ -389,10 +387,10 @@ def test_default_behavior(topology_st, global_policy_default, add_user):
     :id: c47fa824-ee08-4b78-885f-bca4c42bb655
     :setup: Standalone instance, a user entry,
             Global password policy configured as below:
-                passwordExp: on
-                passwordMaxAge: 8640000
-                passwordWarning: 86400
-                passwordSendExpiringTime: off
+            passwordExp: on
+            passwordMaxAge: 8640000
+            passwordWarning: 86400
+            passwordSendExpiringTime: off
     :steps:
         1. Bind as the normal user
         2. Request the control for the user
@@ -423,10 +421,10 @@ def test_when_maxage_and_warning_are_the_same(topology_st, global_policy_default
     :id: e57a1b1c-96fc-11e7-a91b-28d244694824
     :setup: Standalone instance, a user entry,
             Global password policy configured as below:
-                passwordExp: on
-                passwordMaxAge: 86400
-                passwordWarning: 86400
-                passwordSendExpiringTime: off
+            passwordExp: on
+            passwordMaxAge: 86400
+            passwordWarning: 86400
+            passwordSendExpiringTime: off
     :steps:
         1. Bind as the normal user
         2. Change user's password to reset its password expiration time
@@ -472,11 +470,11 @@ def test_with_local_policy(topology_st, global_policy, local_policy):
     :id: ab7d9f86-8cfe-48c3-8baa-739e599f006a
     :setup: Standalone instance, a user entry,
             Global password policy configured as below:
-                passwordExp: on
-                passwordMaxAge: 172800
-                passwordWarning: 86400
-                passwordSendExpiringTime: on
-            Fine grained password policy for the user using ns-newpwpolicy.pl
+            passwordExp: on
+            passwordMaxAge: 172800
+            passwordWarning: 86400
+            passwordSendExpiringTime: on
+            Fine grained password policy for the user using: dsconf INST localpwp
     :steps:
         1. Bind as the normal user
         2. Request the control for the user
@@ -581,17 +579,20 @@ def test_password_expire_works(topology_st):
                         ('passwordExp', 'on'))
     user = UserAccounts(topology_st.standalone, DEFAULT_SUFFIX, rdn=None).create_test_user()
     user.set('userPassword', 'anuj')
+    time.sleep(0.5)
     expire_time = user.get_attr_val_utf8('passwordExpirationTime')
     config.replace('passwordMaxAge', '172800')
     user.set('userPassword', 'borah')
+    time.sleep(0.5)
     expire_time2 = user.get_attr_val_utf8('passwordExpirationTime')
     config.replace('passwordMaxAge', '604800')
     user.set('userPassword', 'anujagaiin')
+    time.sleep(0.5)
     expire_time3 = user.get_attr_val_utf8('passwordExpirationTime')
     assert expire_time != expire_time2 != expire_time3
     config.replace('passwordExp', 'off')
 
-    
+
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
