@@ -15,11 +15,16 @@ from lib389.idm.user import UserAccounts, UserAccount
 from lib389._constants import DEFAULT_SUFFIX
 from lib389.config import Config
 from lib389.idm.group import Group
+from lib389.utils import ds_is_older
 import ldap
 import time
 
 pytestmark = pytest.mark.tier1
 
+if ds_is_older('1.4'):
+    DEFAULT_PASSWORD_STORAGE_SCHEME = 'SSHA512'
+else:
+    DEFAULT_PASSWORD_STORAGE_SCHEME = 'PBKDF2_SHA256'
 
 def _create_user(topo, uid, cn, uidNumber, userpassword):
     """
@@ -400,7 +405,7 @@ def test_expiration_date(topo, _fix_password):
     # Modify password Once
     user.replace('userPassword', 'secreter')
     time.sleep(1)
-    assert 'PBKDF2_SHA256' in user.get_attr_val_utf8('userPassword')
+    assert DEFAULT_PASSWORD_STORAGE_SCHEME in user.get_attr_val_utf8('userPassword')
     # Try to change the password with same one
     for _ in range(3):
         with pytest.raises(ldap.CONSTRAINT_VIOLATION):
@@ -426,14 +431,14 @@ def test_passwordlockout(topo, _fix_password):
         10. Try to bind with valid pw, should give lockout error
         11. Reset password using admin login
         12. Try to login as the user to check the unlocking of account. Will also change
-        the password back to original
+            the password back to original
         13. Change to account lockout forever until reset
         14. Reset password retry count (to 0)
         15. Try to bind with invalid credentials(3 times)
         16. Try to bind with valid pw, should give lockout error
         17. Reset password using admin login
         18. Try to login as the user to check the unlocking of account. Will also change the
-        password back to original
+            password back to original
     :expected results:
         1. Success
         2. Success
@@ -460,7 +465,7 @@ def test_passwordlockout(topo, _fix_password):
     user.replace('userpassword', 'dby3rs2')
     admin = _create_user(topo, 'diradmin', 'Anuj Borah', '1002', 'diradmin')
     # Adding admin user diradmin to Directory Administrator group
-    Group(topo.standalone, f'cn=Directory Administrators,{DEFAULT_SUFFIX}').add('uniquemember', admin.dn)
+    Group(topo.standalone, f'cn=user_passwd_reset,ou=permissions,{DEFAULT_SUFFIX}').add('member', admin.dn)
     # Turn on passwordlockout
     # Sets lockout duration to 30 seconds
     # Sets failure count reset duration to 30 sec
@@ -508,4 +513,4 @@ def test_passwordlockout(topo, _fix_password):
 
 if __name__ == "__main__":
     CURRENT_FILE = os.path.realpath(__file__)
-    pytest.main("-s -v %s" % CURRENT_FILE)
\ No newline at end of file
+    pytest.main("-s -v %s" % CURRENT_FILE)
