@@ -12,6 +12,9 @@ Created on Dec 09, 2014
 @author: mreynolds
 '''
 import logging
+import threading
+from ldap.syncrepl import SyncreplConsumer
+from ldap.ldapobject import ReconnectLDAPObject
 import subprocess
 import pytest
 from lib389.utils import *
@@ -365,6 +368,7 @@ def test_automember(topo, args=None):
         2. Success
         3. Success
         4. Success
+        5. Success
         6. Success
         7. Success
         8. Success
@@ -529,6 +533,7 @@ def test_dna(topo, args=None):
         8. Success
         9. Success
         10. Success
+        11. Success
         12. Success
     """
 
@@ -1546,7 +1551,6 @@ def test_referint(topo, args=None):
     log.info('test_referint: PASS\n')
     return
 
-
 def test_retrocl(topo, args=None):
     """Test Retro Changelog basic functionality
 
