@@ -22,12 +22,16 @@ from lib389.plugins import RetroChangelogPlugin
 from lib389.dseldif import DSEldif
 from lib389.tasks import *
 from lib389.utils import *
+from lib389.utils import ensure_bytes, ds_supports_new_changelog
 
 pytestmark = pytest.mark.tier1
 
 TEST_ENTRY_NAME = 'replusr'
 NEW_RDN_NAME = 'cl5usr'
-CHANGELOG = 'cn=changelog5,cn=config'
+if ds_supports_new_changelog():
+    CHANGELOG = 'cn=changelog,{}'.format(DN_USERROOT_LDBM)
+else:
+    CHANGELOG = 'cn=changelog5,cn=config'
 RETROCHANGELOG = 'cn=Retro Changelog Plugin,cn=plugins,cn=config'
 MAXAGE = 'nsslapd-changelogmaxage'
 TRIMINTERVAL = 'nsslapd-changelogtrim-interval'
@@ -73,12 +77,17 @@ def _create_changelog_dump(topo):
     """Dump changelog using nss5task and check if ldap operations are logged"""
 
     log.info('Dump changelog using nss5task and check if ldap operations are logged')
-    changelog_dir = topo.ms['master1'].get_changelog_dir()
+    if ds_supports_new_changelog():
+        changelog_dir = topo.ms['master1'].get_ldif_dir()
+        changelog_end = '_cl.ldif'
+    else:
+        changelog_dir = topo.ms['master1'].get_changelog_dir()
+        changelog_end = '.ldif'
     replicas = Replicas(topo.ms["master1"])
     replica = replicas.get(DEFAULT_SUFFIX)
     log.info('Remove ldif files, if present in: {}'.format(changelog_dir))
     for files in os.listdir(changelog_dir):
-        if files.endswith('.ldif'):
+        if files.endswith(changelog_end):
             changelog_file = os.path.join(changelog_dir, files)
             try:
                 os.remove(changelog_file)
@@ -94,7 +103,7 @@ def _create_changelog_dump(topo):
 
     log.info('Check if changelog ldif file exist in: {}'.format(changelog_dir))
     for files in os.listdir(changelog_dir):
-        if files.endswith('.ldif'):
+        if files.endswith(changelog_end):
             changelog_ldif = os.path.join(changelog_dir, files)
             log.info('Changelog ldif file exist: {}'.format(changelog_ldif))
             return changelog_ldif
@@ -129,22 +138,23 @@ def get_ldap_error_msg(e, type):
 
 @pytest.fixture(scope="module")
 def changelog_init(topo):
-    """Initialize the test environment by changing log dir and
-    enabling cn=Retro Changelog Plugin,cn=plugins,cn=config
-     """
+    """ changlog dir is not configuarable, just
+    enable cn=Retro Changelog Plugin,cn=plugins,cn=config
+    """
     log.info('Testing Ticket 47669 - Test duration syntax in the changelogs')
 
     # bind as directory manager
     topo.ms["master1"].log.info("Bind as %s" % DN_DM)
     topo.ms["master1"].simple_bind_s(DN_DM, PASSWORD)
 
-    try:
-        changelogdir = os.path.join(os.path.dirname(topo.ms["master1"].dbdir), 'changelog')
-        topo.ms["master1"].modify_s(CHANGELOG, [(ldap.MOD_REPLACE, 'nsslapd-changelogdir',
-                                                                    ensure_bytes(changelogdir))])
-    except ldap.LDAPError as e:
-        log.error('Failed to modify ' + CHANGELOG + ': error {}'.format(get_ldap_error_msg(e,'desc')))
-        assert False
+    if not ds_supports_new_changelog():
+        try:
+            changelogdir = os.path.join(os.path.dirname(topo.ms["master1"].dbdir), 'changelog')
+            topo.ms["master1"].modify_s(CHANGELOG, [(ldap.MOD_REPLACE, 'nsslapd-changelogdir',
+                                                                       ensure_bytes(changelogdir))])
+        except ldap.LDAPError as e:
+            log.error('Failed to modify ' + CHANGELOG + ': error {}'.format(get_ldap_error_msg(e,'desc')))
+            assert False
 
     try:
         topo.ms["master1"].modify_s(RETROCHANGELOG, [(ldap.MOD_REPLACE, 'nsslapd-pluginEnabled', b'on')])
@@ -204,7 +214,10 @@ def remove_ldif_files_from_changelogdir(topo, extension):
     """
     Remove existing ldif files from changelog dir
     """
-    changelog_dir = topo.ms['master1'].get_changelog_dir()
+    if ds_supports_new_changelog():
+        changelog_dir = topo.ms['master1'].get_ldif_dir()
+    else:
+        changelog_dir = topo.ms['master1'].get_changelog_dir()
 
     log.info('Remove %s files, if present in: %s' % (extension, changelog_dir))
     for files in os.listdir(changelog_dir):
@@ -218,8 +231,9 @@ def remove_ldif_files_from_changelogdir(topo, extension):
             else:
                 log.info('Existing changelog %s file: %s removed' % (extension,changelog_file))
 
-                
+
 @pytest.mark.xfail(ds_is_older('1.3.10.1', '1.4.3'), reason="bug bz1685059")
+@pytest.mark.skip(reason="does not work for prefix builds")
 @pytest.mark.bz1685059
 @pytest.mark.ds50498
 @pytest.mark.bz1769296
@@ -228,7 +242,7 @@ def test_cldump_files_removed(topo):
 
     :id: fbb2f2a3-167b-4bc6-b513-9e0318b09edc
     :setup: Replication with two master, nsslapd-changelogdir is '/var/lib/dirsrv/slapd-master1/changelog'
-    retrochangelog plugin disabled
+            retrochangelog plugin disabled
     :steps:
         1. Clean the changelog directory, removing .ldif files present, if any
         2. Clean the changelog directory, removing .done files present, if any
@@ -244,7 +258,7 @@ def test_cldump_files_removed(topo):
     :expectedresults:
         1. No remaining .ldif file in the changelog directory
         2. No remaining .ldif.done file in the changelog directory
-        3. ldap operations are replicated and recorded in changelog 
+        3. ldap operations are replicated and recorded in changelog
         4. A result code different from 0 is raised
         5. cl-dump is successfully executed
         6. cl-dump process has finished
@@ -261,7 +275,7 @@ def test_cldump_files_removed(topo):
 
     # Remove existing .ldif.done files in changelog dir
     remove_ldif_files_from_changelogdir(topo, '.done')
-                
+
     _perform_ldap_operations(topo)
 
     # This part to make sure that an error in the cl-dump script execution will be detected,
@@ -276,7 +290,7 @@ def test_cldump_files_removed(topo):
     msg = proc.communicate()
     log.info('output message : %s' % msg[0])
     assert proc.returncode != 0
-    
+
     # Now the core goal of the test case
     # Using cl-dump without -l option
     log.info("Use cl-dump perl script without -l option : no generated ldif files should remain in %s " % changelog_dir)
@@ -325,87 +339,92 @@ def test_dsconf_dump_changelog_files_removed(topo):
 
     :id: e41dcf90-098a-4386-acb5-789384579bf7
     :setup: Replication with two master, nsslapd-changelogdir is '/var/lib/dirsrv/slapd-master1/changelog'
-    retrochangelog plugin disabled
+            retrochangelog plugin disabled
     :steps:
         1. Clean the changelog directory, removing .ldif files present, if any
         2. Clean the changelog directory, removing .ldif.done files present, if any
         3. Perform ldap operations to record replication changes
         4. Try a dsconf call with invalid arguments to secure the next steps
-        5. Launch dsconf dump-changelog cli without -l option
+        5. Launch dsconf export-changelog cli without -l option
         6. Wait so that all dsconf tasks be finished
         7. Check that all .ldif.done generated files have been removed from the changelog dir
-        8. Launch dsconf dump-changelog cli with -l option
+        8. Launch dsconf export-changelog cli with -l option
         9. Wait so that all dsconf tasks be finished
         10. Check that the generated .ldif.done files are present in the changelog dir
 
     :expectedresults:
         1. No remaining .ldif file in the changelog directory
         2. No remaining .ldif.done file in the changelog directory
-        3. ldap operations are replicated and recorded in changelog 
+        3. ldap operations are replicated and recorded in changelog
         4. A result code different from 0 is raised
-        5. dsconf dump-changelog is successfully executed
+        5. dsconf export-changelog is successfully executed
         6. dsconf process has finished
         7. No .ldif.done files in the changelog dir
-        8. dsconf dump-changelog is successfully executed
+        8. dsconf export-changelog is successfully executed
         9. dsconf process has finished
         10. .ldif.done generated files are present in the changelog dir
      """
 
-    changelog_dir = topo.ms['master1'].get_changelog_dir()
+    if ds_supports_new_changelog():
+        changelog_dir = topo.ms['master1'].get_ldif_dir()
+    else:
+        changelog_dir = topo.ms['master1'].get_changelog_dir()
     instance = topo.ms['master1']
     instance_url = 'ldap://%s:%s' % (HOST_MASTER_1, PORT_MASTER_1)
 
     # Remove existing .ldif files in changelog dir
     remove_ldif_files_from_changelogdir(topo, '.ldif')
-      
+
     # Remove existing .ldif.done files from changelog dir
     remove_ldif_files_from_changelogdir(topo, '.done')
-                
+
     _perform_ldap_operations(topo)
 
-    # This part to make sure that an error in the python dsconf dump-changelog execution will be detected,
+    # This part to make sure that an error in the python dsconf export-changelog execution will be detected,
     # primary condition before executing the core goal of this case : management of generated files.
 
-    log.info("Use dsconf dump-changelog with invalid parameters")
-    cmdline=['/usr/sbin/dsconf', instance_url, '-D', DN_DM, '-w', 'badpasswd', 'replication', 'dump-changelog']
+    log.info("Use dsconf export-changelog with invalid parameters")
+    cmdline=['/usr/sbin/dsconf', instance_url, '-D', DN_DM, '-w', 'badpasswd', 'replication', 'export-changelog']
     log.info('Command used : %s' % cmdline)
     proc = subprocess.Popen(cmdline, stdout=subprocess.PIPE)
     msg = proc.communicate()
     log.info('output message : %s' % msg[0])
     assert proc.returncode != 0
-    
+
     # Now the core goal of the test case
     # Using dsconf replication changelog  without -l option
     log.info('Use dsconf replication changelog without -l option: no generated ldif files should be present in %s ' % changelog_dir)
-    cmdline=['/usr/sbin/dsconf', instance_url, '-D', DN_DM, '-w', PASSWORD, 'replication', 'dump-changelog']
+    cmdline=['/usr/sbin/dsconf', instance_url, '-D', DN_DM, '-w', PASSWORD, 'replication', 'export-changelog',
+             'default', '-r', DEFAULT_SUFFIX]
     log.info('Command used : %s' % cmdline)
     proc = subprocess.Popen(cmdline, stdout=subprocess.PIPE)
     proc.communicate()
     assert proc.returncode == 0
 
-    log.info('Wait for all dsconf dump-changelog files to be generated')
+    log.info('Wait for all dsconf export-changelog files to be generated')
     time.sleep(1)
 
-    log.info('Check if dsconf dump-changelog generated .ldif.done files are present - should not')
+    log.info('Check if dsconf export-changelog generated .ldif.done files are present - should not')
     for files in os.listdir(changelog_dir):
         if files.endswith('.done'):
-            log.fatal('dump-changelog generated .ldif.done files are present in %s - they should not' % changelog_dir)
+            log.fatal('export-changelog generated .ldif.done files are present in %s - they should not' % changelog_dir)
             assert False
     else:
-        log.info('All dsconf dump-changelog generated .ldif files have been successfully removed from %s ' % changelog_dir)
+        log.info('All dsconf export-changelog generated .ldif files have been successfully removed from %s ' % changelog_dir)
 
     # Using dsconf replication changelog  without -l option
     log.info('Use dsconf replication changelog with -l option: generated ldif files should be kept in %s ' % changelog_dir)
-    cmdline=['/usr/sbin/dsconf', instance_url, '-D', DN_DM, '-w', PASSWORD, 'replication', 'dump-changelog', '-l']
+    cmdline=['/usr/sbin/dsconf', instance_url, '-D', DN_DM, '-w', PASSWORD, 'replication', 'export-changelog',
+             'to-ldif', '-o', changelog_dir + '/test.ldif', '-r', DEFAULT_SUFFIX, '-l']
     log.info('Command used : %s' % cmdline)
     proc = subprocess.Popen(cmdline, stdout=subprocess.PIPE)
     proc.communicate()
     assert proc.returncode == 0
 
-    log.info('Wait for all dsconf dump-changelog files to be generated')
+    log.info('Wait for all dsconf export-changelog files to be generated')
     time.sleep(1)
 
-    log.info('Check if dsconf dump-changelog generated .ldif.done files are present - should be')
+    log.info('Check if dsconf export-changelog generated .ldif.done files are present - should be')
     for files in os.listdir(changelog_dir):
         if files.endswith('.done'):
             cldump_file = os.path.join(changelog_dir, files)
@@ -466,7 +485,10 @@ def test_verify_changelog_online_backup(topo):
         log.fatal('test_changelog5: Online backup failed')
         assert False
 
-    backup_checkdir = os.path.join(backup_dir, '.repl_changelog_backup', DEFAULT_CHANGELOG_DB)
+    if ds_supports_new_changelog():
+        backup_checkdir = os.path.join(backup_dir, DEFAULT_BENAME, BDB_CL_FILENAME)
+    else:
+        backup_checkdir = os.path.join(backup_dir, '.repl_changelog_backup', DEFAULT_CHANGELOG_DB)
     if os.path.exists(backup_checkdir):
         log.info('Database backup is created successfully')
     else:
@@ -524,7 +546,10 @@ def test_verify_changelog_offline_backup(topo):
         assert False
     topo.ms['master1'].start()
 
-    backup_checkdir = os.path.join(backup_dir, '.repl_changelog_backup', DEFAULT_CHANGELOG_DB)
+    if ds_supports_new_changelog():
+        backup_checkdir = os.path.join(backup_dir, DEFAULT_BENAME, BDB_CL_FILENAME)
+    else:
+        backup_checkdir = os.path.join(backup_dir, '.repl_changelog_backup', DEFAULT_CHANGELOG_DB)
     if os.path.exists(backup_checkdir):
         log.info('Database backup is created successfully')
     else:
@@ -543,8 +568,8 @@ def test_changelog_maxage(topo, changelog_init):
 
     :id: d284ff27-03b2-412c-ac74-ac4f2d2fae3b
     :setup: Replication with two master, change nsslapd-changelogdir to
-    '/var/lib/dirsrv/slapd-master1/changelog' and
-    set cn=Retro Changelog Plugin,cn=plugins,cn=config to 'on'
+            '/var/lib/dirsrv/slapd-master1/changelog' and
+            set cn=Retro Changelog Plugin,cn=plugins,cn=config to 'on'
     :steps:
         1. Set nsslapd-changelogmaxage in cn=changelog5,cn=config to values - '12345','10s','30M','12h','2D','4w'
         2. Set nsslapd-changelogmaxage in cn=changelog5,cn=config to values - '-123','xyz'
@@ -575,8 +600,8 @@ def test_ticket47669_changelog_triminterval(topo, changelog_init):
 
     :id: 8f850c37-7e7c-49dd-a4e0-9344638616d6
     :setup: Replication with two master, change nsslapd-changelogdir to
-    '/var/lib/dirsrv/slapd-master1/changelog' and
-    set cn=Retro Changelog Plugin,cn=plugins,cn=config to 'on'
+            '/var/lib/dirsrv/slapd-master1/changelog' and
+            set cn=Retro Changelog Plugin,cn=plugins,cn=config to 'on'
     :steps:
         1. Set nsslapd-changelogtrim-interval in cn=changelog5,cn=config to values -
            '12345','10s','30M','12h','2D','4w'
@@ -603,13 +628,14 @@ def test_ticket47669_changelog_triminterval(topo, changelog_init):
 
 
 @pytest.mark.ds47669
+@pytest.mark.skipif(ds_supports_new_changelog(), reason="changelog compaction is done by the backend itself, with id2entry as well, nsslapd-changelogcompactdb-interval is no longer supported")
 def test_changelog_compactdbinterval(topo, changelog_init):
     """Check nsslapd-changelog compactdbinterval values
 
     :id: 0f4b3118-9dfa-4c2a-945c-72847b42a48c
     :setup: Replication with two master, change nsslapd-changelogdir to
-    '/var/lib/dirsrv/slapd-master1/changelog' and
-    set cn=Retro Changelog Plugin,cn=plugins,cn=config to 'on'
+            '/var/lib/dirsrv/slapd-master1/changelog' and
+            set cn=Retro Changelog Plugin,cn=plugins,cn=config to 'on'
     :steps:
         1. Set nsslapd-changelogcompactdb-interval in cn=changelog5,cn=config to values -
            '12345','10s','30M','12h','2D','4w'
@@ -642,8 +668,8 @@ def test_retrochangelog_maxage(topo, changelog_init):
 
     :id: 0cb84d81-3e86-4dbf-84a2-66aefd8281db
     :setup: Replication with two master, change nsslapd-changelogdir to
-    '/var/lib/dirsrv/slapd-master1/changelog' and
-    set cn=Retro Changelog Plugin,cn=plugins,cn=config to 'on'
+            '/var/lib/dirsrv/slapd-master1/changelog' and
+            set cn=Retro Changelog Plugin,cn=plugins,cn=config to 'on'
     :steps:
         1. Set nsslapd-changelogmaxage in cn=Retro Changelog Plugin,cn=plugins,cn=config to values -
            '12345','10s','30M','12h','2D','4w'
@@ -678,8 +704,8 @@ def test_retrochangelog_trimming_crash(topo, changelog_init):
 
     :id: 5d9bd7ca-e9bf-4be9-8fc8-902aa5513052
     :setup: Replication with two master, change nsslapd-changelogdir to
-    '/var/lib/dirsrv/slapd-master1/changelog' and
-    set cn=Retro Changelog Plugin,cn=plugins,cn=config to 'on'
+            '/var/lib/dirsrv/slapd-master1/changelog' and
+            set cn=Retro Changelog Plugin,cn=plugins,cn=config to 'on'
     :steps:
         1. Set nsslapd-changelogmaxage in cn=Retro Changelog Plugin,cn=plugins,cn=config to value '-1'
            This value is invalid. To disable retroCL trimming it should be set to 0
