@@ -14,7 +14,8 @@ else:
 
 log = logging.getLogger(__name__)
 # Skip on older versions
-pytestmark = pytest.mark.skipif(ds_is_older('1.3.6'), reason="Not implemented")
+pytestmark = [pytest.mark.tier2,
+              pytest.mark.skipif(ds_is_older('1.3.6'), reason="Not implemented")]
 
 
 USER1 = 'user1'
