@@ -12,7 +12,8 @@ else:
 
 log = logging.getLogger(__name__)
 # Skip on older versions
-pytestmark = pytest.mark.skipif(ds_is_older('1.3.5'), reason="Not implemented")
+pytestmark = [pytest.mark.tier2,
+              pytest.mark.skipif(ds_is_older('1.3.5'), reason="Not implemented")]
 
 
 
