@@ -49,7 +49,7 @@ int referint_postop_del(Slapi_PBlock *pb);
 int referint_postop_modrdn(Slapi_PBlock *pb);
 int referint_postop_start(Slapi_PBlock *pb);
 int referint_postop_close(Slapi_PBlock *pb);
-int update_integrity(Slapi_DN *sDN, char *newrDN, Slapi_DN *newsuperior);
+int update_integrity(Slapi_DN *sDN, char *newrDN, Slapi_DN *newsuperior, Slapi_PBlock *pb);
 int GetNextLine(char *dest, int size_dest, PRFileDesc *stream);
 int my_fgetc(PRFileDesc *stream);
 void referint_thread_func(void *arg);
@@ -71,8 +71,9 @@ void referint_get_config(int *delay, char **logfile);
 /* global thread control stuff */
 static PRLock *referint_mutex = NULL;
 static PRThread *referint_tid = NULL;
-static PRLock *keeprunning_mutex = NULL;
-static PRCondVar *keeprunning_cv = NULL;
+static pthread_mutex_t keeprunning_mutex;
+static pthread_cond_t keeprunning_cv;
+
 static int keeprunning = 0;
 static referint_config *config = NULL;
 static Slapi_DN *_ConfigAreaDN = NULL;
@@ -611,7 +612,7 @@ referint_postop_del(Slapi_PBlock *pb)
     } else if (delay == 0) { /* no delay */
         /* call function to update references to entry */
         if (referint_sdn_in_entry_scope(sdn)) {
-            rc = update_integrity(sdn, NULL, NULL);
+            rc = update_integrity(sdn, NULL, NULL, pb);
         }
     } else {
         /* write the entry to integrity log */
@@ -663,7 +664,7 @@ referint_postop_modrdn(Slapi_PBlock *pb)
         /* call function to update references to entry */
         if (!plugin_EntryScope && !plugin_ExcludeEntryScope) {
             /* no scope defined, default always process referint */
-            rc = update_integrity(sdn, newrdn, newsuperior);
+            rc = update_integrity(sdn, newrdn, newsuperior, pb);
         } else {
             const char *newsuperiordn = slapi_sdn_get_dn(newsuperior);
             if ((newsuperiordn == NULL && referint_sdn_in_entry_scope(sdn)) ||
@@ -672,10 +673,10 @@ referint_postop_modrdn(Slapi_PBlock *pb)
                  * It is a modrdn inside the scope or into the scope,
                  * process normal modrdn
                  */
-                rc = update_integrity(sdn, newrdn, newsuperior);
+                rc = update_integrity(sdn, newrdn, newsuperior, pb);
             } else if (referint_sdn_in_entry_scope(sdn)) {
                 /* the entry is moved out of scope, treat as delete */
-                rc = update_integrity(sdn, NULL, NULL);
+                rc = update_integrity(sdn, NULL, NULL, pb);
             }
         }
     } else {
@@ -1067,7 +1068,8 @@ bail:
 int
 update_integrity(Slapi_DN *origSDN,
                  char *newrDN,
-                 Slapi_DN *newsuperior)
+                 Slapi_DN *newsuperior,
+                 Slapi_PBlock *pb)
 {
     Slapi_PBlock *search_result_pb = NULL;
     Slapi_PBlock *mod_pb = slapi_pblock_new();
@@ -1181,6 +1183,10 @@ update_integrity(Slapi_DN *origSDN,
                                          * We're using backend transactions,
                                          * so we need to stop on failure.
                                          */
+                                        if (pb) {
+                                            /* Set the error code of the failure */
+                                            slapi_pblock_set(pb, SLAPI_RESULT_CODE, &rc);
+                                        }
                                         rc = SLAPI_PLUGIN_FAILURE;
                                         goto free_and_return;
                                     } else {
@@ -1196,8 +1202,11 @@ update_integrity(Slapi_DN *origSDN,
                                       "update_integrity - Search (base=%s filter=%s) returned "
                                       "error %d\n",
                                       search_base, filter, search_result);
-                        rc = SLAPI_PLUGIN_FAILURE;
                         slapi_free_search_results_internal(search_result_pb);
+                        if (pb) {
+                            slapi_pblock_set(pb, SLAPI_RESULT_CODE, &search_result);
+                        }
+                        rc = SLAPI_PLUGIN_FAILURE;
                         goto free_and_return;
                     }
                 }
@@ -1294,12 +1303,38 @@ referint_postop_start(Slapi_PBlock *pb)
      *     -1 = integrity off
      */
     if (referint_get_delay() > 0) {
+        pthread_condattr_t condAttr;
+
         /* initialize the cv and lock */
         if (!use_txn && (NULL == referint_mutex)) {
             referint_mutex = PR_NewLock();
         }
-        keeprunning_mutex = PR_NewLock();
-        keeprunning_cv = PR_NewCondVar(keeprunning_mutex);
+        if ((rc = pthread_mutex_init(&keeprunning_mutex, NULL)) != 0) {
+            slapi_log_err(SLAPI_LOG_ERR, "referint_postop_start",
+                          "cannot create new lock.  error %d (%s)\n",
+                          rc, strerror(rc));
+            exit(1);
+        }
+        if ((rc = pthread_condattr_init(&condAttr)) != 0) {
+            slapi_log_err(SLAPI_LOG_ERR, "referint_postop_start",
+                          "cannot create new condition attribute variable.  error %d (%s)\n",
+                          rc, strerror(rc));
+            exit(1);
+        }
+        if ((rc = pthread_condattr_setclock(&condAttr, CLOCK_MONOTONIC)) != 0) {
+            slapi_log_err(SLAPI_LOG_ERR, "referint_postop_start",
+                          "cannot set condition attr clock.  error %d (%s)\n",
+                          rc, strerror(rc));
+            exit(1);
+        }
+        if ((rc = pthread_cond_init(&keeprunning_cv, &condAttr)) != 0) {
+            slapi_log_err(SLAPI_LOG_ERR, "referint_postop_start",
+                          "cannot create new condition variable.  error %d (%s)\n",
+                          rc, strerror(rc));
+            exit(1);
+        }
+        pthread_condattr_destroy(&condAttr); /* no longer needed */
+
         keeprunning = 1;
 
         referint_tid = PR_CreateThread(PR_USER_THREAD,
@@ -1329,13 +1364,11 @@ int
 referint_postop_close(Slapi_PBlock *pb __attribute__((unused)))
 {
     /* signal the thread to exit */
-    if (NULL != keeprunning_mutex) {
-        PR_Lock(keeprunning_mutex);
+    if (referint_get_delay() > 0) {
+        pthread_mutex_lock(&keeprunning_mutex);
         keeprunning = 0;
-        if (NULL != keeprunning_cv) {
-            PR_NotifyCondVar(keeprunning_cv);
-        }
-        PR_Unlock(keeprunning_mutex);
+        pthread_cond_signal(&keeprunning_cv);
+        pthread_mutex_unlock(&keeprunning_mutex);
     }
 
     slapi_destroy_rwlock(config_rwlock);
@@ -1361,6 +1394,7 @@ referint_thread_func(void *arg __attribute__((unused)))
     char *iter = NULL;
     Slapi_DN *sdn = NULL;
     Slapi_DN *tmpsuperior = NULL;
+    struct timespec current_time = {0};
     int delay;
     int no_changes;
 
@@ -1375,20 +1409,22 @@ referint_thread_func(void *arg __attribute__((unused)))
         no_changes = 1;
         while (no_changes) {
 
-            PR_Lock(keeprunning_mutex);
+            pthread_mutex_lock(&keeprunning_mutex);
             if (keeprunning == 0) {
-                PR_Unlock(keeprunning_mutex);
+                pthread_mutex_unlock(&keeprunning_mutex);
                 break;
             }
-            PR_Unlock(keeprunning_mutex);
+            pthread_mutex_unlock(&keeprunning_mutex);
 
             referint_lock();
             if ((prfd = PR_Open(logfilename, PR_RDONLY, REFERINT_DEFAULT_FILE_MODE)) == NULL) {
                 referint_unlock();
                 /* go back to sleep and wait for this file */
-                PR_Lock(keeprunning_mutex);
-                PR_WaitCondVar(keeprunning_cv, PR_SecondsToInterval(delay));
-                PR_Unlock(keeprunning_mutex);
+                pthread_mutex_lock(&keeprunning_mutex);
+                clock_gettime(CLOCK_MONOTONIC, &current_time);
+                current_time.tv_sec += delay;
+                pthread_cond_timedwait(&keeprunning_cv, &keeprunning_mutex, &current_time);
+                pthread_mutex_unlock(&keeprunning_mutex);
             } else {
                 no_changes = 0;
             }
@@ -1399,12 +1435,12 @@ referint_thread_func(void *arg __attribute__((unused)))
          *  loop before trying to do the changes. The server
          *  will pick them up on next startup as file still exists
          */
-        PR_Lock(keeprunning_mutex);
+        pthread_mutex_lock(&keeprunning_mutex);
         if (keeprunning == 0) {
-            PR_Unlock(keeprunning_mutex);
+            pthread_mutex_unlock(&keeprunning_mutex);
             break;
         }
-        PR_Unlock(keeprunning_mutex);
+        pthread_mutex_unlock(&keeprunning_mutex);
 
         while (GetNextLine(thisline, MAX_LINE, prfd)) {
             ptoken = ldap_utf8strtok_r(thisline, delimiter, &iter);
@@ -1432,7 +1468,7 @@ referint_thread_func(void *arg __attribute__((unused)))
                 }
             }
 
-            update_integrity(sdn, tmprdn, tmpsuperior);
+            update_integrity(sdn, tmprdn, tmpsuperior, NULL);
 
             slapi_sdn_free(&sdn);
             slapi_ch_free_string(&tmprdn);
@@ -1451,21 +1487,16 @@ referint_thread_func(void *arg __attribute__((unused)))
         referint_unlock();
 
         /* wait on condition here */
-        PR_Lock(keeprunning_mutex);
-        PR_WaitCondVar(keeprunning_cv, PR_SecondsToInterval(delay));
-        PR_Unlock(keeprunning_mutex);
+        pthread_mutex_lock(&keeprunning_mutex);
+        clock_gettime(CLOCK_MONOTONIC, &current_time);
+        current_time.tv_sec += delay;
+        pthread_cond_timedwait(&keeprunning_cv, &keeprunning_mutex, &current_time);
+        pthread_mutex_unlock(&keeprunning_mutex);
     }
 
     /* cleanup resources allocated in start  */
-    if (NULL != keeprunning_mutex) {
-        PR_DestroyLock(keeprunning_mutex);
-    }
-    if (NULL != referint_mutex) {
-        PR_DestroyLock(referint_mutex);
-    }
-    if (NULL != keeprunning_cv) {
-        PR_DestroyCondVar(keeprunning_cv);
-    }
+    pthread_mutex_destroy(&keeprunning_mutex);
+    pthread_cond_destroy(&keeprunning_cv);
     slapi_ch_free_string(&logfilename);
 }
 
