@@ -1,6 +1,6 @@
 /** BEGIN COPYRIGHT BLOCK
  * Copyright (C) 2001 Sun Microsystems, Inc. Used by permission.
- * Copyright (C) 2010 Red Hat, Inc.
+ * Copyright (C) 2020 Red Hat, Inc.
  * Copyright (C) 2009 Hewlett-Packard Development Company, L.P.
  * All rights reserved.
  *
@@ -28,6 +28,7 @@
 #include "llist.h"
 #include "repl5_ruv.h"
 #include "plstr.h"
+#include <pthread.h>
 
 #define START_UPDATE_DELAY                   2 /* 2 second */
 #define REPLICA_TYPE_WINDOWS                 1
@@ -157,6 +158,10 @@ extern const char *type_replicaBackoffMin;
 extern const char *type_replicaBackoffMax;
 extern const char *type_replicaPrecisePurge;
 extern const char *type_replicaIgnoreMissingChange;
+extern const char *type_nsds5ReplicaBootstrapBindDN;
+extern const char *type_nsds5ReplicaBootstrapCredentials;
+extern const char *type_nsds5ReplicaBootstrapBindMethod;
+extern const char *type_nsds5ReplicaBootstrapTransportInfo;
 
 /* Attribute names for windows replication agreements */
 extern const char *type_nsds7WindowsReplicaArea;
@@ -385,9 +390,13 @@ int agmt_replicate_now(Repl_Agmt *ra);
 char *agmt_get_hostname(const Repl_Agmt *ra);
 int agmt_get_port(const Repl_Agmt *ra);
 uint32_t agmt_get_transport_flags(const Repl_Agmt *ra);
+uint32_t agmt_get_bootstrap_transport_flags(const Repl_Agmt *ra);
 char *agmt_get_binddn(const Repl_Agmt *ra);
+char *agmt_get_bootstrap_binddn(const Repl_Agmt *ra);
 struct berval *agmt_get_credentials(const Repl_Agmt *ra);
+struct berval *agmt_get_bootstrap_credentials(const Repl_Agmt *ra);
 int agmt_get_bindmethod(const Repl_Agmt *ra);
+int64_t agmt_get_bootstrap_bindmethod(const Repl_Agmt *ra);
 Slapi_DN *agmt_get_replarea(const Repl_Agmt *ra);
 int agmt_is_fractional(const Repl_Agmt *ra);
 int agmt_is_fractional_attr(const Repl_Agmt *ra, const char *attrname);
@@ -404,9 +413,11 @@ int agmt_set_ignoremissing_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
 int agmt_set_busywaittime_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
 int agmt_set_pausetime_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
 int agmt_set_credentials_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
+int32_t agmt_set_bootstrap_credentials_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
 int agmt_set_binddn_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
-int agmt_set_bind_method_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
-int agmt_set_transportinfo_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
+int32_t agmt_set_bootstrap_binddn_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
+int agmt_set_bind_method_from_entry(Repl_Agmt *ra, const Slapi_Entry *e, PRBool bootstrap);
+int agmt_set_transportinfo_from_entry(Repl_Agmt *ra, const Slapi_Entry *e, PRBool bootstrap);
 int agmt_set_port_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
 int agmt_set_host_from_entry(Repl_Agmt *ra, const Slapi_Entry *e);
 const char *agmt_get_long_name(const Repl_Agmt *ra);
@@ -698,6 +709,7 @@ void replica_dump(Replica *r);
 void replica_set_enabled(Replica *r, PRBool enable);
 Replica *replica_get_replica_from_dn(const Slapi_DN *dn);
 Replica *replica_get_replica_from_root(const char *repl_root);
+int replica_check_generation(Replica *r, const RUV *remote_ruv);
 int replica_update_ruv(Replica *replica, const CSN *csn, const char *replica_purl);
 Replica *replica_get_replica_for_op(Slapi_PBlock *pb);
 /* the functions below manipulate replica hash */
@@ -752,6 +764,8 @@ PRBool ignore_error_and_keep_going(int error);
 void replica_check_release_timeout(Replica *r, Slapi_PBlock *pb);
 void replica_lock_replica(Replica *r);
 void replica_unlock_replica(Replica *r);
+void *replica_get_cl_info(Replica *r);
+int replica_set_cl_info(Replica *r, void *cl);
 
 /* The functions below handles the state flag */
 /* Current internal state flags */
@@ -807,8 +821,7 @@ typedef struct _cleanruv_purge_data
 {
     int cleaned_rid;
     const Slapi_DN *suffix_sdn;
-    char *replName;
-    char *replGen;
+    Replica *replica;
 } cleanruv_purge_data;
 
 typedef struct _csngen_test_data
