@@ -93,8 +93,10 @@ attr_syntax_get_global_at()
 void
 attr_syntax_read_lock(void)
 {
-    if (0 != attr_syntax_init())
+    if (0 != attr_syntax_init()) {
+        PR_ASSERT(0);
         return;
+    }
 
     AS_LOCK_READ(oid2asi_lock);
     AS_LOCK_READ(name2asi_lock);
@@ -103,8 +105,10 @@ attr_syntax_read_lock(void)
 void
 attr_syntax_write_lock(void)
 {
-    if (0 != attr_syntax_init())
+    if (0 != attr_syntax_init()) {
+        PR_ASSERT(0);
         return;
+    }
 
     AS_LOCK_WRITE(oid2asi_lock);
     AS_LOCK_WRITE(name2asi_lock);
@@ -124,82 +128,6 @@ attr_syntax_unlock_write(void)
     AS_UNLOCK_WRITE(oid2asi_lock);
 }
 
-
-#if 0
-static int
-check_oid( const char *oid ) {
-
-  int i = 0, length_oid = 0, rc = 0;
-
-  if ( oid == NULL) {
-    /* this is bad */
-    slapi_log_err(SLAPI_LOG_ERR, "check_oid", "NULL passed to check_oid\n");
-    return 0;
-  }
-
-  length_oid = strlen(oid);
-  if (length_oid < 4) {
-    /* this is probably bad */
-    slapi_log_err(SLAPI_LOG_ERR, "check_oid", "Bad oid %s passed to check_oid\n",oid);
-    return 0;
-  }
-
-  rc = strcasecmp(oid+(length_oid-4), "-oid");
-
-  if ( 0 == rc ) {
-    return 1;
-  }
-
-  /* If not, the OID must begin and end with a digit, and contain only
-     digits and dots */
-
-  if ( !isdigit(oid[0]) ||
-       !isdigit(oid[length_oid-1]) ) {
-    slapi_log_err(SLAPI_LOG_ERR, "check_oid", "Non numeric oid %s passed to check_oid\n",oid);
-    return 0;
-  }
-
-  /* check to see that it contains only digits and dots */
-  for ( i = 0; i < length_oid; i++ ) {
-    if ( !isdigit(oid[i]) && oid[i] != '.'  ){
-      slapi_log_err(SLAPI_LOG_ERR, "check_oid", "Non numeric oid %s passed to check_oid\n",oid);
-      return 0;
-    }
-  }
-
-  /* The oid is OK if we're here */
-  return 1;
-
-
-}
-#endif
-
-#define NBUCKETS(ht) (1 << (PL_HASH_BITS - (ht)->shift))
-
-#if 0
-static int
-attr_syntax_check_oids()
-{
-    int ii = 0;
-    int nbad = 0;
-    AS_LOCK_READ(oid2asi_lock);
-    ii = NBUCKETS(oid2asi);
-    for (;ii;--ii) {
-        PLHashEntry *he = oid2asi->buckets[ii-1];
-        for (; he; he = he->next) {
-            if (!check_oid(he->key)) {
-                slapi_log_err(SLAPI_LOG_ERR, "attr_syntax_check_oids", "bad oid %s in bucket %d\n",
-                          he->key, ii-1);
-                nbad++;
-            }
-        }
-    }
-
-    AS_UNLOCK_READ(oid2asi_lock);
-    return nbad;
-}
-#endif
-
 void
 attr_syntax_free(struct asyntaxinfo *a)
 {
@@ -383,6 +311,46 @@ attr_syntax_get_by_name_locking_optional(const char *name, PRBool use_lock, PRUi
     return asi;
 }
 
+/*
+ * This assumes you have taken the attr_syntax read lock. Assert an attribute type
+ * exists by name. 0 is false, 1 is true.
+ *
+ * The main reason to use this over attr_syntax_get_by_name_locking_optional is to
+ * avoid the reference count increment/decrement cycle when we only need a boolean
+ * of existance, rather than retriving the reference to the attribute itself.
+ *
+ * But we do need to strip subtypes
+ */
+int32_t
+attr_syntax_exist_by_name_nolock(char *name) {
+    struct asyntaxinfo *asi = NULL;
+    char *check_name = NULL;
+    char *p = NULL;
+    int free_attr = 0;
+
+    /* Ignore any attribute subtypes. */
+    if ((p = strchr(name, ';'))) {
+        int check_len = p - name + 1;
+
+        check_name = (char *)slapi_ch_malloc(check_len);
+        PR_snprintf(check_name, check_len, "%s", name);
+        free_attr = 1;
+    } else {
+        check_name = name;
+    }
+
+    asi = (struct asyntaxinfo *)PL_HashTableLookup_const(name2asi, check_name);
+
+    if (free_attr) {
+        slapi_ch_free_string(&check_name);
+    }
+
+    if (asi != NULL) {
+        return 1;
+    }
+    return 0;
+}
+
 
 /*
  * Give up a reference to an asi.
