@@ -111,6 +111,8 @@ typedef unsigned short u_int16_t;
  * newidl format.
  * Starting from DS7.2
  */
+#define BE_CHANGELOG_FILE     "replication_changelog"
+
 #define BDB_IMPL              "bdb"
 #define BDB_BACKEND           "libback-ldbm" /* This backend plugin */
 #define BDB_NEWIDL            "newidl"       /* new idl format */
@@ -118,6 +120,9 @@ typedef unsigned short u_int16_t;
 #define BDB_RDNFORMAT_VERSION "3"            /* rdn-format version (by default, 0) */
 #define BDB_DNFORMAT          "dn-4514"      /* DN format RFC 4514 compliant */
 #define BDB_DNFORMAT_VERSION  "1"            /* DN format version */
+#define BDB_CL_FILENAME       "replication_changelog.db"
+
+#define LMDB_IMPL             "lmdb"
 
 #define DBVERSION_NEWIDL 0x1
 #define DBVERSION_RDNFORMAT 0x2
@@ -645,6 +650,10 @@ struct ldbminfo
  */
 /* allow conf w/o CONFIG_FLAG_ALLOW_RUNNING_CHANGE to be updated */
 #define LI_FORCE_MOD_CONFIG 0x10
+#define LI_BDB_IMPL         0x20
+#define LI_LMDB_IMPL        0x40
+
+#define LI_DEFAULT_IMPL_FLAG  LI_BDB_IMPL /* the default is BDB for now */
 
 /* Structure used to hold stuff for the lifetime of an LDAP transaction */
 /* If we do clever stuff like LDAP transactions, we'll need a stack of TXN ID's */
@@ -734,6 +743,7 @@ typedef struct ldbm_instance
     PRLock *inst_handle_list_mutex;
 
     DB *inst_id2entry; /* id2entry for this instance. */
+    DB *inst_changelog; /* changelog for this instance. */
 
     perfctrs_private inst_perf_private; /* Private data for the performance counters specific to this instance */
     attrcrypt_state_private *inst_attrcrypt_state_private;
@@ -755,6 +765,7 @@ typedef struct ldbm_instance
     char *inst_dataversion;          /* The user data version tag.  Used by replication. */
     void *inst_db;                   /* implementation specific instance data */
     int require_index;               /* set to 1 to require an index be used in search */
+    int require_internalop_index;    /* set to 1 to require an index be used in an internal search */
     struct cache inst_dncache;       /* The dn cache for this instance. */
 } ldbm_instance;
 
@@ -801,14 +812,6 @@ typedef struct _back_search_result_set
 /* Name of attribute type used for binder-based look through simple paged limit */
 #define LDBM_PAGEDALLIDSLIMIT_AT "nsPagedIDListScanLimit"
 
-/* OIDs for attribute types used internally */
-#define LDBM_ENTRYDN_OID  "2.16.840.1.113730.3.1.602"
-#define LDBM_DNCOMP_OID   "2.16.840.1.113730.3.1.603"
-#define LDBM_PARENTID_OID "2.16.840.1.113730.3.1.604"
-#define LDBM_ENTRYID_OID  "2.16.840.1.113730.3.1.605"
-#define LDBM_ENTRYUSN_OID "2.16.840.1.113730.3.1.2096"
-/* #define LDBM_ENTRYRDN_OID            "2.16.840.1.113730.3.1.2097" */
-
 #define LDBM_ANCESTORID_STR                "ancestorid"
 #define LDBM_ENTRYDN_STR                   SLAPI_ATTR_ENTRYDN
 #define LDBM_ENTRYRDN_STR                  "entryrdn"
