@@ -1,5 +1,5 @@
 /** BEGIN COPYRIGHT BLOCK
- * Copyright (C) 2019 Red Hat, Inc.
+ * Copyright (C) 2020 Red Hat, Inc.
  * All rights reserved.
  *
  * License: GPL (version 3 or any later version).
@@ -18,10 +18,10 @@ typedef struct bdb_db_env
     Slapi_RWLock *bdb_env_lock;
     int bdb_openflags;
     int bdb_priv_flags;
-    PRLock *bdb_thread_count_lock;      /* lock for thread_count_cv */
-    PRCondVar *bdb_thread_count_cv;     /* condition variable for housekeeping thread shutdown */
-    PRInt32 bdb_thread_count;           /* Tells us how many threads are running,
-                                         * used to figure out when they're all stopped */
+    pthread_mutex_t bdb_thread_count_lock; /* lock for thread_count_cv */
+    pthread_cond_t bdb_thread_count_cv;    /* condition variable for housekeeping thread shutdown */
+    PRInt32 bdb_thread_count;              /* Tells us how many threads are running,
+                                            * used to figure out when they're all stopped */
 } bdb_db_env;
 
 /* structure which holds our stuff */
@@ -150,7 +150,6 @@ int bdb_back_ok_to_dump(const char *dn, char **include, char **exclude);
 int bdb_back_fetch_incl_excl(Slapi_PBlock *pb, char ***include, char ***exclude);
 PRUint64 bdb_get_id2entry_size(ldbm_instance *inst);
 
-
 /* bdb version functions */
 int bdb_version_write(struct ldbminfo *li, const char *directory, const char *dataversion, PRUint32 flags);
 int bdb_version_read(struct ldbminfo *li, const char *directory, char **ldbmversion, char **dataversion);
@@ -162,3 +161,10 @@ int bdb_instance_post_delete_instance_entry_callback(struct ldbminfo *li, struct
 int bdb_instance_add_instance_entry_callback(struct ldbminfo *li, struct ldbm_instance *inst);
 int bdb_instance_postadd_instance_entry_callback(struct ldbminfo *li, struct ldbm_instance *inst);
 void bdb_config_setup_default(struct ldbminfo *li);
+
+/* monitor functions */
+int bdb_monitor_instance_search(Slapi_PBlock *pb, Slapi_Entry *e, Slapi_Entry *entryAfter, int *returncode, char *returntext, void *arg);
+int bdb_monitor_search(Slapi_PBlock *pb, Slapi_Entry *e, Slapi_Entry *entryAfter, int *returncode, char *returntext, void *arg);
+int bdb_dbmonitor_search(Slapi_PBlock *pb, Slapi_Entry *e, Slapi_Entry *entryAfter, int *returncode, char *returntext, void *arg);
+int bdb_instance_register_monitor(ldbm_instance *inst);
+void bdb_instance_unregister_monitor(ldbm_instance *inst);
