@@ -1800,150 +1800,6 @@ index_range_read(
     return index_range_read_ext(pb, be, type, indextype, operator, val, nextval, range, txn, err, 0);
 }
 
-/* DBDB: this function is never actually called */
-#if 0
-static int
-addordel_values(
-    backend *be,
-    DB            *db,
-    char        *type,
-    const char        *indextype,
-    struct berval    **vals,
-    ID            id,
-    int            flags,        /* BE_INDEX_ADD, etc */
-    back_txn        *txn,
-    struct attrinfo    *a,
-    int *idl_disposition,
-    void *buffer_handle
-)
-{
-    int    rc = 0;
-    int  i = 0;
-    DBT    key = {0};
-    DB_TXN    *db_txn = NULL;
-    size_t    plen, vlen, len;
-    char    *tmpbuf = NULL;
-    size_t    tmpbuflen = 0;
-    char    *realbuf;
-    char    *prefix;
-
-    slapi_log_err(SLAPI_LOG_TRACE, "addordel_values", "%s_values\n",
-           (flags & BE_INDEX_ADD) ? "add" : "del");
-
-    prefix = index_index2prefix( indextype );
-
-    if (prefix == NULL) {
-        slapi_log_err(SLAPI_LOG_ERR, "addordel_values", "%s_values: NULL prefix\n",
-            (flags & BE_INDEX_ADD) ? "add" : "del");
-        return( -1 );
-    }
-
-    if ( vals == NULL ) {
-        key.dptr  = prefix;
-        key.dsize = strlen( prefix ) + 1; /* include null terminator */
-        key.flags = DB_DBT_MALLOC;
-        if (NULL != txn) {
-            db_txn = txn->back_txn_txn;
-        }
-
-        if (flags & BE_INDEX_ADD) {
-            rc = idl_insert_key( be, db, &key, id, db_txn, a, idl_disposition );
-        } else {
-            rc = idl_delete_key( be, db, &key, id, db_txn, a );
-            /* check for no such key/id - ok in some cases */
-            if ( rc == DB_NOTFOUND || rc == -666 ) {
-                rc = 0;
-            }
-        }
-
-        if ( rc != 0)
-        {
-            ldbm_nasty("addordel_values", errmsg, 1096, rc);
-        }
-        index_free_prefix (prefix);
-        if (NULL != key.dptr && prefix != key.dptr)
-            slapi_ch_free( (void**)&key.dptr );
-        slapi_log_err(SLAPI_LOG_TRACE, "addordel_values", "%s_values %d\n",
-               (flags & BE_INDEX_ADD) ? "add" : "del", rc);
-        return( rc );
-    }
-
-    plen = strlen( prefix );
-    for ( i = 0; vals[i] != NULL; i++ ) {
-        vlen = vals[i]->bv_len;
-        len = plen + vlen;
-
-        if ( len < tmpbuflen ) {
-            realbuf = tmpbuf;
-        } else {
-            tmpbuf = slapi_ch_realloc( tmpbuf, len + 1 );
-            tmpbuflen = len + 1;
-            realbuf = tmpbuf;
-        }
-
-        memcpy( realbuf, prefix, plen );
-        memcpy( realbuf+plen, vals[i]->bv_val, vlen );
-        realbuf[len] = '\0';
-        key.dptr = realbuf;
-        key.size = plen + vlen + 1;
-                /* should be okay to use USERMEM here because we know what
-                 * the key is and it should never return a different value
-                 * than the one we pass in.
-                 */
-        key.flags = DB_DBT_USERMEM;
-                key.ulen = tmpbuflen;
-        if (slapi_is_loglevel_set(LDAP_DEBUG_TRACE)) {
-            char encbuf[BUFSIZ];
-
-            slapi_log_err(SLAPI_LOG_TRACE, "addordel_values", "%s_value(\"%s\")\n",
-                   (flags & BE_INDEX_ADD) ? "add" : "del",
-                   encoded (&key, encbuf));
-        }
-
-        if (NULL != txn) {
-            db_txn = txn->back_txn_txn;
-        }
-
-        if ( flags & BE_INDEX_ADD ) {
-            if (buffer_handle) {
-                rc = index_buffer_insert(buffer_handle,&key,id,be,db_txn,a);
-                if (rc == -2) {
-                    rc = idl_insert_key( be, db, &key, id, db_txn, a, idl_disposition );
-                }
-            } else {
-                rc = idl_insert_key( be, db, &key, id, db_txn, a, idl_disposition );
-            }
-        } else {
-            rc = idl_delete_key( be, db, &key, id, db_txn, a );
-            /* check for no such key/id - ok in some cases */
-            if ( rc == DB_NOTFOUND || rc == -666 ) {
-                rc = 0;
-            }
-        }
-        if ( rc != 0 ) {
-            ldbm_nasty("addordel_values", errmsg, 1100, rc);
-            break;
-        }
-        if ( NULL != key.dptr && realbuf != key.dptr) {    /* realloc'ed */
-            tmpbuf = key.dptr;
-            tmpbuflen = key.size;
-        }
-    }
-    index_free_prefix (prefix);
-    if ( tmpbuf != NULL ) {
-        slapi_ch_free( (void**)&tmpbuf );
-    }
-
-    if ( rc != 0 )
-    {
-        ldbm_nasty("addordel_values", errmsg, 1110, rc);
-    }
-    slapi_log_err(SLAPI_LOG_TRACE, "addordel_values", "%s_values %d\n",
-        (flags & BE_INDEX_ADD) ? "add" : "del", rc);
-    return( rc );
-}
-#endif
-
 static int
 addordel_values_sv(
     backend *be,
