@@ -19,30 +19,6 @@
 static Slapi_PluginDesc pdesc = {"ldbm-backend", VENDOR,
                                  DS_PACKAGE_VERSION, "high-performance LDAP backend database plugin"};
 
-/* pb: not used */
-int
-ldbm_back_add_schema(Slapi_PBlock *pb __attribute__((unused)))
-{
-    int rc = 0;
-    rc = slapi_add_internal_attr_syntax(LDBM_ENTRYDN_STR,
-                                        LDBM_ENTRYDN_OID, DN_SYNTAX_OID, DNMATCH_NAME,
-                                        SLAPI_ATTR_FLAG_SINGLE | SLAPI_ATTR_FLAG_NOUSERMOD);
-
-    rc |= slapi_add_internal_attr_syntax("dncomp",
-                                         LDBM_DNCOMP_OID, DN_SYNTAX_OID, DNMATCH_NAME,
-                                         SLAPI_ATTR_FLAG_NOUSERMOD);
-
-    rc |= slapi_add_internal_attr_syntax(LDBM_PARENTID_STR,
-                                         LDBM_PARENTID_OID, INTEGER_SYNTAX_OID, INTEGERMATCH_NAME,
-                                         SLAPI_ATTR_FLAG_SINGLE | SLAPI_ATTR_FLAG_NOUSERMOD);
-
-    rc |= slapi_add_internal_attr_syntax("entryid",
-                                         LDBM_ENTRYID_OID, DIRSTRING_SYNTAX_OID, CASEIGNOREMATCH_NAME,
-                                         SLAPI_ATTR_FLAG_SINGLE | SLAPI_ATTR_FLAG_NOUSERMOD);
-
-    return rc;
-}
-
 int
 ldbm_back_init(Slapi_PBlock *pb)
 {
@@ -61,6 +37,9 @@ ldbm_back_init(Slapi_PBlock *pb)
      * identity is used during internal ops. */
     slapi_pblock_get(pb, SLAPI_PLUGIN_IDENTITY, &(li->li_identity));
 
+    /* Set the entry release function */
+    p->plg_entry_release = (void *)ldbm_back_entry_release;
+
     /* keep a pointer back to the plugin */
     li->li_plugin = p;
 
@@ -81,9 +60,6 @@ ldbm_back_init(Slapi_PBlock *pb)
         goto fail;
     }
 
-    /* add some private attributes */
-    rc = ldbm_back_add_schema(pb);
-
     /* set plugin private pointer and initialize locks, etc. */
     rc = slapi_pblock_set(pb, SLAPI_PLUGIN_PRIVATE, (void *)li);
 
@@ -110,12 +86,8 @@ ldbm_back_init(Slapi_PBlock *pb)
                            (void *)ldbm_back_search);
     rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_NEXT_SEARCH_ENTRY_FN,
                            (void *)ldbm_back_next_search_entry);
-    rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_NEXT_SEARCH_ENTRY_EXT_FN,
-                           (void *)ldbm_back_next_search_entry_ext);
     rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_PREV_SEARCH_RESULTS_FN,
                            (void *)ldbm_back_prev_search_results);
-    rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_ENTRY_RELEASE_FN,
-                           (void *)ldbm_back_entry_release);
     rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_SEARCH_RESULTS_RELEASE_FN,
                            (void *)ldbm_back_search_results_release);
     rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_COMPARE_FN,
@@ -162,15 +134,8 @@ ldbm_back_init(Slapi_PBlock *pb)
                            (void *)dblayer_plugin_commit);
     rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_ABORT_FN,
                            (void *)dblayer_plugin_abort);
-    rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_SIZE_FN,
-                           (void *)ldbm_db_size);
-    rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_INIT_INSTANCE_FN,
-                           (void *)ldbm_back_init); /* register itself so that the secon instance
-                                          can be initialized */
     rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_WIRE_IMPORT_FN,
                            (void *)ldbm_back_wire_import);
-    rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_ADD_SCHEMA_FN,
-                           (void *)ldbm_back_add_schema);
     rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_GET_INFO_FN,
                            (void *)ldbm_back_get_info);
     rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DB_SET_INFO_FN,
