@@ -404,6 +404,9 @@ replace_entry:
                 delete_tombstone_entry = operation_is_flag_set(operation, OP_FLAG_TOMBSTONE_ENTRY);
             }
 
+            /* Save away a copy of the entry, before modifications */
+            slapi_pblock_set(pb, SLAPI_ENTRY_PRE_OP, slapi_entry_dup(e->ep_entry));
+
             /* call the transaction pre delete plugins just after the 
              * to-be-deleted entry is prepared. */
             /* these should not need to modify the entry to be deleted -
@@ -500,8 +503,6 @@ replace_entry:
                     "entry: %s  - flags: delete %d is_tombstone_entry %d create %d \n",
                     dn, delete_tombstone_entry, is_tombstone_entry, create_tombstone_entry);
 #endif
-            /* Save away a copy of the entry, before modifications */
-            slapi_pblock_set(pb, SLAPI_ENTRY_PRE_OP, slapi_entry_dup(e->ep_entry));
 
             /*
              * Get the entry's parent. We do this here because index_read
@@ -967,25 +968,7 @@ replace_entry:
                         goto error_return;
                     }
                 }
-#if 0 /* The entryrdn element is already deleted in the index_addordel_entry */
-                retval = entryrdn_index_entry(be, e, BE_INDEX_DEL, &txn);
-                if (DB_LOCK_DEADLOCK == retval) {
-                    slapi_log_err(SLAPI_LOG_BACKLDBM,
-                                "ldbm_back_delete", "(deleting entryrdn) DB_LOCK_DEADLOCK\n");
-                    /* Retry txn */
-                    continue;
-                }
-                if (0 != retval) {
-                    slapi_log_err(SLAPI_LOG_ERR,
-                                "ldbm_back_delete", "(deleting entryrdn) failed, err=%d %s\n",
-                                retval,
-                                (msg = dblayer_strerror( retval )) ? msg : "" );
-                    if (LDBM_OS_ERR_IS_DISKFULL(retval)) disk_full = 1;
-                    DEL_SET_ERROR(ldap_result_code,
-                                  LDAP_OPERATIONS_ERROR, retry_count);
-                    goto error_return;
-                }
-#endif
+
                 retval = entryrdn_index_entry(be, tombstone, BE_INDEX_ADD, &txn);
                 if (DB_LOCK_DEADLOCK == retval) {
                     slapi_log_err(SLAPI_LOG_BACKLDBM,
