@@ -247,6 +247,14 @@ ldbm_instance_config_require_index_get(void *arg)
     return (void *)((uintptr_t)inst->require_index);
 }
 
+static void *
+ldbm_instance_config_require_internalop_index_get(void *arg)
+{
+    ldbm_instance *inst = (ldbm_instance *)arg;
+
+    return (void *)((uintptr_t)inst->require_internalop_index);
+}
+
 static int
 ldbm_instance_config_readonly_set(void *arg,
                                   void *value,
@@ -299,6 +307,24 @@ ldbm_instance_config_require_index_set(void *arg,
 }
 
 
+static int
+ldbm_instance_config_require_internalop_index_set(void *arg,
+                                                  void *value,
+                                                  char *errorbuf __attribute__((unused)),
+                                                  int phase __attribute__((unused)),
+                                                  int apply)
+{
+    ldbm_instance *inst = (ldbm_instance *)arg;
+
+    if (!apply) {
+        return LDAP_SUCCESS;
+    }
+
+    inst->require_internalop_index = (int)((uintptr_t)value);
+
+    return LDAP_SUCCESS;
+}
+
 /*------------------------------------------------------------------------
  * ldbm instance configuration array
  *----------------------------------------------------------------------*/
@@ -307,6 +333,7 @@ static config_info ldbm_instance_config[] = {
     {CONFIG_INSTANCE_CACHEMEMSIZE, CONFIG_TYPE_UINT64, DEFAULT_CACHE_SIZE_STR, &ldbm_instance_config_cachememsize_get, &ldbm_instance_config_cachememsize_set, CONFIG_FLAG_ALWAYS_SHOW | CONFIG_FLAG_ALLOW_RUNNING_CHANGE},
     {CONFIG_INSTANCE_READONLY, CONFIG_TYPE_ONOFF, "off", &ldbm_instance_config_readonly_get, &ldbm_instance_config_readonly_set, CONFIG_FLAG_ALWAYS_SHOW | CONFIG_FLAG_ALLOW_RUNNING_CHANGE},
     {CONFIG_INSTANCE_REQUIRE_INDEX, CONFIG_TYPE_ONOFF, "off", &ldbm_instance_config_require_index_get, &ldbm_instance_config_require_index_set, CONFIG_FLAG_ALWAYS_SHOW | CONFIG_FLAG_ALLOW_RUNNING_CHANGE},
+	{CONFIG_INSTANCE_REQUIRE_INTERNALOP_INDEX, CONFIG_TYPE_ONOFF, "off", &ldbm_instance_config_require_internalop_index_get, &ldbm_instance_config_require_internalop_index_set, CONFIG_FLAG_ALWAYS_SHOW | CONFIG_FLAG_ALLOW_RUNNING_CHANGE},
     {CONFIG_INSTANCE_DNCACHEMEMSIZE, CONFIG_TYPE_UINT64, DEFAULT_DNCACHE_SIZE_STR, &ldbm_instance_config_dncachememsize_get, &ldbm_instance_config_dncachememsize_set, CONFIG_FLAG_ALWAYS_SHOW | CONFIG_FLAG_ALLOW_RUNNING_CHANGE},
     {NULL, 0, NULL, NULL, NULL, 0}};
 
@@ -528,6 +555,8 @@ parse_ldbm_instance_config_entry(ldbm_instance *inst, Slapi_Entry *e, config_inf
     /* Read the attribute encryption entries */
     read_instance_attrcrypt_entries(inst);
 
+
+
     return 0;
 }
 
@@ -648,32 +677,6 @@ ldbm_instance_config_load_dse_info(ldbm_instance *inst)
                                    LDAP_SCOPE_BASE, "(objectclass=*)",
                                    ldbm_instance_deny_config, (void *)inst);
     /* delete is handled by a callback set in ldbm_config.c */
-
-    slapi_ch_free_string(&dn);
-
-    /* don't forget the monitor! */
-    dn = slapi_create_dn_string("cn=monitor,cn=%s,cn=%s,cn=plugins,cn=config",
-                                inst->inst_name, li->li_plugin->plg_name);
-    if (NULL == dn) {
-        slapi_log_err(SLAPI_LOG_ERR,
-                      "ldbm_instance_config_load_dse_info",
-                      "failed create monitor instance dn for plugin %s, "
-                      "instance %s\n",
-                      inst->inst_li->li_plugin->plg_name, inst->inst_name);
-        rval = 1;
-        goto bail;
-    }
-    /* make callback on search; deny add/modify/delete */
-    slapi_config_register_callback(SLAPI_OPERATION_SEARCH, DSE_FLAG_PREOP, dn,
-                                   LDAP_SCOPE_BASE, "(objectclass=*)", ldbm_back_monitor_instance_search,
-                                   (void *)inst);
-    slapi_config_register_callback(SLAPI_OPERATION_ADD, DSE_FLAG_PREOP, dn,
-                                   LDAP_SCOPE_SUBTREE, "(objectclass=*)", ldbm_instance_deny_config,
-                                   (void *)inst);
-    slapi_config_register_callback(SLAPI_OPERATION_MODIFY, DSE_FLAG_PREOP, dn,
-                                   LDAP_SCOPE_BASE, "(objectclass=*)", ldbm_instance_deny_config,
-                                   (void *)inst);
-    /* delete is okay */
     slapi_ch_free_string(&dn);
 
     /* Callbacks to handle indexes */
@@ -744,26 +747,20 @@ ldbm_instance_search_config_entry_callback(Slapi_PBlock *pb __attribute__((unuse
     struct ldbminfo *li = inst->inst_li;
     dblayer_private *priv = (dblayer_private *)li->li_dblayer_private;
     config_info *config;
-    int x;
     const Slapi_DN *suffix;
 
     vals[0] = &val;
     vals[1] = NULL;
-
     returntext[0] = '\0';
 
     /* show the suffixes */
     attrlist_delete(&e->e_attrs, CONFIG_INSTANCE_SUFFIX);
-    x = 0;
-    do {
-        suffix = slapi_be_getsuffix(inst->inst_be, x);
-        if (suffix != NULL) {
-            val.bv_val = (char *)slapi_sdn_get_dn(suffix);
-            val.bv_len = strlen(val.bv_val);
-            attrlist_merge(&e->e_attrs, CONFIG_INSTANCE_SUFFIX, vals);
-        }
-        x++;
-    } while (suffix != NULL);
+    suffix = slapi_be_getsuffix(inst->inst_be, 0);
+    if (suffix != NULL) {
+        val.bv_val = (char *)slapi_sdn_get_dn(suffix);
+        val.bv_len = strlen(val.bv_val);
+        attrlist_merge(&e->e_attrs, CONFIG_INSTANCE_SUFFIX, vals);
+    }
 
     PR_Lock(inst->inst_config_mutex);
 
@@ -881,6 +878,7 @@ static int
 ldbm_instance_generate(struct ldbminfo *li, char *instance_name, Slapi_Backend **ret_be)
 {
     Slapi_Backend *new_be = NULL;
+    dblayer_private *priv = (dblayer_private *)li->li_dblayer_private;
     int rc = 0;
 
     /* Create a new instance, process config info for it,
@@ -895,6 +893,8 @@ ldbm_instance_generate(struct ldbminfo *li, char *instance_name, Slapi_Backend *
     }
 
     ldbm_instance_config_load_dse_info(new_be->be_instance_info);
+    priv->instance_register_monitor_fn(new_be->be_instance_info);
+
     ldbm_instance_create_default_indexes(new_be);
 
     /* if USN plugin is enabled, set slapi_counter */
@@ -957,24 +957,6 @@ ldbm_instance_unregister_callbacks(ldbm_instance *inst)
                                  ldbm_instance_deny_config);
     slapi_ch_free_string(&dn);
 
-    /* now the cn=monitor entry */
-    dn = slapi_create_dn_string("cn=monitor,cn=%s,cn=%s,cn=plugins,cn=config",
-                                inst->inst_name, li->li_plugin->plg_name);
-    if (NULL == dn) {
-        slapi_log_err(SLAPI_LOG_ERR,
-                      "ldbm_instance_unregister_callbacks",
-                      "Failed create monitor instance dn for plugin %s, "
-                      "instance %s\n",
-                      inst->inst_li->li_plugin->plg_name, inst->inst_name);
-        goto bail;
-    }
-    slapi_config_remove_callback(SLAPI_OPERATION_SEARCH, DSE_FLAG_PREOP, dn,
-                                 LDAP_SCOPE_BASE, "(objectclass=*)", ldbm_back_monitor_instance_search);
-    slapi_config_remove_callback(SLAPI_OPERATION_ADD, DSE_FLAG_PREOP, dn,
-                                 LDAP_SCOPE_SUBTREE, "(objectclass=*)", ldbm_instance_deny_config);
-    slapi_config_remove_callback(SLAPI_OPERATION_MODIFY, DSE_FLAG_PREOP, dn,
-                                 LDAP_SCOPE_BASE, "(objectclass=*)", ldbm_instance_deny_config);
-    slapi_ch_free_string(&dn);
 
     /* now the cn=index entries */
     dn = slapi_create_dn_string("cn=index,cn=%s,cn=%s,cn=plugins,cn=config",
