@@ -834,27 +834,64 @@ ldbm_back_search(Slapi_PBlock *pb)
     if (NULL != candidates && ALLIDS(candidates)) {
         unsigned int opnote;
         int ri = 0;
+        int rii = 0;
         int pr_idx = -1;
         Connection *pb_conn = NULL;
         Operation *pb_op = NULL;
+        struct slapdplugin *plugin = NULL;
+        struct slapi_componentid *cid = NULL;
+        char *filter_str;
+        char *plugin_dn;
+        char *base_dn;
+        int32_t internal_op = operation_is_flag_set(operation, OP_FLAG_INTERNAL);
+        uint64_t connid;
+        int32_t op_id;
+        int32_t op_internal_id;
+        int32_t op_nested_count;
 
         /*
-         * Return error if nsslapd-require-index is set and
-         * this is not an internal operation.
-         * We hope the plugins know what they are doing!
+         * Return error if require index is set
          */
-        if (!operation_is_flag_set(operation, OP_FLAG_INTERNAL)) {
+        PR_Lock(inst->inst_config_mutex);
+        ri = inst->require_index;
+        rii = inst->require_internalop_index;
+        PR_Unlock(inst->inst_config_mutex);
 
-            PR_Lock(inst->inst_config_mutex);
-            ri = inst->require_index;
-            PR_Unlock(inst->inst_config_mutex);
+        if ((internal_op && rii) || (!internal_op && ri)) {
+            idl_free(&candidates);
+            candidates = idl_alloc(0);
+            tmp_err = LDAP_UNWILLING_TO_PERFORM;
+            tmp_desc = "Search is not indexed";
+        }
 
-            if (ri) {
-                idl_free(&candidates);
-                candidates = idl_alloc(0);
-                tmp_err = LDAP_UNWILLING_TO_PERFORM;
-                tmp_desc = "Search is not indexed";
+        /*
+         * When an search is fully unindexed we need to log the
+         * details as these kinds of searches can cause issues with bdb db
+         * locks being exhausted.  This will help expose what indexing is
+         * missing.
+         */
+        slapi_pblock_get(pb, SLAPI_OPERATION, &pb_op);
+        slapi_pblock_get(pb, SLAPI_SEARCH_STRFILTER, &filter_str);
+        slapi_pblock_get(pb, SLAPI_TARGET_DN, &base_dn);
+
+        if (internal_op) {
+            /* Get the plugin that triggered this internal search */
+            slapi_pblock_get(pb, SLAPI_PLUGIN_IDENTITY, &cid);
+            if (cid) {
+                plugin = (struct slapdplugin *)cid->sci_plugin;
+            } else {
+                slapi_pblock_get(pb, SLAPI_PLUGIN, &plugin);
             }
+            plugin_dn = plugin_get_dn(plugin);
+            get_internal_conn_op(&connid, &op_id, &op_internal_id, &op_nested_count);
+            slapi_log_err(SLAPI_LOG_NOTICE, "ldbm_back_search",
+                    "Internal unindexed search: source (%s) search base=\"%s\" scope=%d filter=\"%s\" conn=%" PRIu64 " op=%d (internal op=%d count=%d)\n",
+                    plugin_dn, base_dn, scope, filter_str, connid, op_id, op_internal_id, op_nested_count);
+            slapi_ch_free_string(&plugin_dn);
+        } else {
+            slapi_log_err(SLAPI_LOG_NOTICE, "ldbm_back_search",
+                    "Unindexed search: search base=\"%s\" scope=%d filter=\"%s\" conn=%" PRIu64 " op=%d\n",
+                    base_dn, scope, filter_str, pb_op->o_connid, pb_op->o_opid);
         }
 
         opnote = slapi_pblock_get_operation_notes(pb);
@@ -862,7 +899,6 @@ ldbm_back_search(Slapi_PBlock *pb)
         opnote &= ~SLAPI_OP_NOTE_UNINDEXED;     /* this note is useless because FULL_UNINDEXED includes UNINDEXED */
         slapi_pblock_set_operation_notes(pb, opnote);
         slapi_pblock_get(pb, SLAPI_PAGED_RESULTS_INDEX, &pr_idx);
-        slapi_pblock_get(pb, SLAPI_OPERATION, &pb_op);
         slapi_pblock_get(pb, SLAPI_CONNECTION, &pb_conn);
         pagedresults_set_unindexed(pb_conn, pb_op, pr_idx);
     }
@@ -1212,22 +1248,6 @@ subtree_candidates(
 }
 
 static int grok_filter(struct slapi_filter *f);
-#if 0
-/* Helper for grok_filter() */
-static int
-grok_filter_list(struct slapi_filter    *flist)
-{
-    struct slapi_filter    *f;
-
-    /* Scan the clauses of the AND filter, if any of them fails the grok, then we fail */
-    for ( f = flist; f != NULL; f = f->f_next ) {
-        if ( !grok_filter(f) ) {
-                return( 0 );
-        }
-    }
-    return( 1 );
-}
-#endif
 
 /* Helper function for can_skip_filter_test() */
 static int
@@ -1346,22 +1366,6 @@ can_skip_filter_test(
     return rc;
 }
 
-
-/*
- * Return the next entry in the result set.  The entry is returned
- * in the pblock.
- * Returns 0 normally.  If -1 is returned, it means that some
- * exceptional condition, e.g. timelimit exceeded has occurred,
- * and this routine has sent a result to the client.  If zero
- * is returned and no entry is available in the PBlock, then
- * we've iterated through all the entries.
- */
-int
-ldbm_back_next_search_entry(Slapi_PBlock *pb)
-{
-    return ldbm_back_next_search_entry_ext(pb, 0);
-}
-
 /* The reference on the target_entry (base search) is stored in the operation
  * This is to prevent additional cache find/return that require cache lock.
  *
@@ -1383,8 +1387,17 @@ non_target_cache_return(Slapi_Operation *op, struct cache *cache, struct backent
     }
 }
 
+/*
+ * Return the next entry in the result set.  The entry is returned
+ * in the pblock.
+ * Returns 0 normally.  If -1 is returned, it means that some
+ * exceptional condition, e.g. timelimit exceeded has occurred,
+ * and this routine has sent a result to the client.  If zero
+ * is returned and no entry is available in the PBlock, then
+ * we've iterated through all the entries.
+ */
 int
-ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
+ldbm_back_next_search_entry(Slapi_PBlock *pb)
 {
     backend *be;
     ldbm_instance *inst;
@@ -1484,15 +1497,15 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
     /* Return to the cache the entry we handed out last time */
     /* If we are using the extension, the front end will tell
      * us when to do this so we don't do it now */
-    if (sr->sr_entry && !use_extension) {
+    if (sr->sr_entry) {
         non_target_cache_return(op, &inst->inst_cache, &(sr->sr_entry));
         sr->sr_entry = NULL;
     }
 
-    if (sr->sr_vlventry != NULL && !use_extension) {
-        /* This empty entry was handed out last time because the ACL check failed on a VLV Search. */
-        /* The empty entry has a pointer to the cache entry dn... make sure we don't free the dn */
-        /* which belongs to the cache entry. */
+    if (sr->sr_vlventry != NULL) {
+        /* This empty entry was handed out last time because the ACL check failed on a VLV Search.
+         * The empty entry has a pointer to the cache entry dn... make sure we don't free the dn
+         * which belongs to the cache entry. */
         slapi_entry_free(sr->sr_vlventry);
         sr->sr_vlventry = NULL;
     }
@@ -1506,9 +1519,6 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
         /* check for abandon */
         if (slapi_op_abandoned(pb) || (NULL == sr)) {
             slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_SET_SIZE_ESTIMATE, &estimate);
-            if (use_extension) {
-                slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY_EXT, NULL);
-            }
             slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY, NULL);
             delete_search_result_set(pb, &sr);
             rc = SLAPI_FAIL_GENERAL;
@@ -1516,15 +1526,11 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
         }
 
         /*
-         * Check this only every few iters to prevent smashing the clock api?
+         * Check time limit, Check this only every few iters to prevent smashing the clock api?
          */
-        /* check time limit */
         if (slapi_timespec_expire_check(&expire_time) == TIMER_EXPIRED) {
-            slapi_log_err(SLAPI_LOG_TRACE, "ldbm_back_next_search_entry_ext", "LDAP_TIMELIMIT_EXCEEDED\n");
+            slapi_log_err(SLAPI_LOG_TRACE, "ldbm_back_next_search_entry", "LDAP_TIMELIMIT_EXCEEDED\n");
             slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_SET_SIZE_ESTIMATE, &estimate);
-            if (use_extension) {
-                slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY_EXT, NULL);
-            }
             slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY, NULL);
             delete_search_result_set(pb, &sr);
             rc = SLAPI_FAIL_GENERAL;
@@ -1534,9 +1540,6 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
         /* check lookthrough limit */
         if (llimit != -1 && sr->sr_lookthroughcount >= llimit) {
             slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_SET_SIZE_ESTIMATE, &estimate);
-            if (use_extension) {
-                slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY_EXT, NULL);
-            }
             slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY, NULL);
             delete_search_result_set(pb, &sr);
             rc = SLAPI_FAIL_GENERAL;
@@ -1574,9 +1577,6 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
             /* No more entries */
             /* destroy back_search_result_set */
             slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_SET_SIZE_ESTIMATE, &estimate);
-            if (use_extension) {
-                slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY_EXT, NULL);
-            }
             slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY, NULL);
             delete_search_result_set(pb, &sr);
             op->o_reverse_search_state = 0;
@@ -1606,18 +1606,17 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
         }
         if (e == NULL) {
             if (err != 0 && err != DB_NOTFOUND) {
-                slapi_log_err(SLAPI_LOG_ERR, "ldbm_back_next_search_entry_ext", "next_search_entry db err %d\n",
-                              err);
+                slapi_log_err(SLAPI_LOG_ERR, "ldbm_back_next_search_entry",
+                        "next_search_entry db err %d\n", err);
                 if (LDBM_OS_ERR_IS_DISKFULL(err)) {
                     /* disk full in the middle of returning search results
-                     * is gonna be traumatic.  unavoidable.
-                     */
+                     * is gonna be traumatic.  unavoidable. */
                     slapi_send_ldap_result(pb, LDAP_OPERATIONS_ERROR, NULL, NULL, 0, NULL);
                     rc = return_on_disk_full(li);
                     goto bail;
                 }
             }
-            slapi_log_err(SLAPI_LOG_ARGS, "ldbm_back_next_search_entry_ext", "candidate %lu not found\n",
+            slapi_log_err(SLAPI_LOG_ARGS, "ldbm_back_next_search_entry", "candidate %lu not found\n",
                           (u_long)id);
             if (err == DB_NOTFOUND) {
                 /* Since we didn't really look at this entry, we should
@@ -1625,8 +1624,7 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
                  * If we didn't do this, it would be possible to go over the
                  * lookthrough limit when there are fewer entries in the database
                  * than the lookthrough limit.  This could happen on an ALLIDS
-                 * search after adding a bunch of entries and then deleting
-                 * them. */
+                 * search after adding a bunch of entries and then deleting them. */
                 --sr->sr_lookthroughcount;
             }
             continue;
@@ -1642,23 +1640,20 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
         if (!managedsait && slapi_entry_attr_find(e->ep_entry, "ref", &attr) == 0) {
             Slapi_Value **refs = attr_get_present_values(attr);
             if (refs == NULL || refs[0] == NULL) {
-                slapi_log_err(SLAPI_LOG_ERR, "ldbm_back_next_search_entry_ext", "null ref in (%s)\n",
+                slapi_log_err(SLAPI_LOG_ERR, "ldbm_back_next_search_entry", "null ref in (%s)\n",
                               backentry_get_ndn(e));
             } else if (slapi_sdn_scope_test(backentry_get_sdn(e), basesdn, scope)) {
-                if (use_extension) {
-                    slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY_EXT, e);
-                }
                 slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY, e->ep_entry);
                 rc = 0;
                 goto bail;
             }
         } else {
             /*
-           * As per slapi_filter_test:
-           * 0  filter matched
-           * -1 filter did not match
-           * >0 an ldap error code
-           */
+             * As per slapi_filter_test:
+             * 0  filter matched
+             * -1 filter did not match
+             * >0 an ldap error code
+             */
             int filter_test = -1;
             int is_bulk_import = operation_is_flag_set(op, OP_FLAG_BULK_IMPORT);
 
@@ -1670,25 +1665,26 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
                         !filter_flag_is_set(filter, SLAPI_FILTER_LDAPSUBENTRY)) ||
                        (slapi_entry_flag_is_set(e->ep_entry, SLAPI_ENTRY_FLAG_TOMBSTONE) &&
                         ((!isroot && !filter_flag_is_set(filter, SLAPI_FILTER_RUV)) ||
-                         !filter_flag_is_set(filter, SLAPI_FILTER_TOMBSTONE)))) {
+                         !filter_flag_is_set(filter, SLAPI_FILTER_TOMBSTONE))))
+            {
                 /* If the entry is an LDAP subentry and filter don't filter subentries OR
-             * the entry is a TombStone and filter don't filter Tombstone
-             * don't return the entry.  We make a special case to allow a non-root user
-             * to search for the RUV entry using a filter of:
-             *
-             *     "(&(objectclass=nstombstone)(nsuniqueid=ffffffff-ffffffff-ffffffff-ffffffff))"
-             *
-             * For this RUV case, we let the ACL check apply.
-             */
+                 * the entry is a TombStone and filter don't filter Tombstone
+                 * don't return the entry.  We make a special case to allow a non-root user
+                 * to search for the RUV entry using a filter of:
+                 *
+                 *     "(&(objectclass=nstombstone)(nsuniqueid=ffffffff-ffffffff-ffffffff-ffffffff))"
+                 *
+                 * For this RUV case, we let the ACL check apply.
+                 */
                 /* ugaston - we don't want to mistake this filter failure with the one below due to ACL,
-             * because whereas the former should be read as 'no entry must be returned', the latter
-             * might still lead to return an empty entry. */
+                 * because whereas the former should be read as 'no entry must be returned', the latter
+                 * might still lead to return an empty entry. */
                 filter_test = -1;
             } else {
                 /* it's a regular entry, check if it matches the filter, and passes the ACL check */
                 if (0 != (sr->sr_flags & SR_FLAG_CAN_SKIP_FILTER_TEST)) {
                     /* Since we do access control checking in the filter test (?Why?) we need to check access now */
-                    slapi_log_err(SLAPI_LOG_FILTER, "ldbm_back_next_search_entry_ext",
+                    slapi_log_err(SLAPI_LOG_FILTER, "ldbm_back_next_search_entry",
                                   "Bypassing filter test\n");
                     if (ACL_CHECK_FLAG) {
                         filter_test = slapi_vattr_filter_test_ext(pb, e->ep_entry, filter, ACL_CHECK_FLAG, 1 /* Only perform access checking, thank you */);
@@ -1698,12 +1694,12 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
                     if (li->li_filter_bypass_check) {
                         int ft_rc;
 
-                        slapi_log_err(SLAPI_LOG_FILTER, "ldbm_back_next_search_entry_ext", "Checking bypass\n");
+                        slapi_log_err(SLAPI_LOG_FILTER, "ldbm_back_next_search_entry", "Checking bypass\n");
                         ft_rc = slapi_vattr_filter_test(pb, e->ep_entry, filter,
                                                         ACL_CHECK_FLAG);
                         if (filter_test != ft_rc) {
                             /* Oops ! This means that we thought we could bypass the filter test, but noooo... */
-                            slapi_log_err(SLAPI_LOG_ERR, "ldbm_back_next_search_entry_ext",
+                            slapi_log_err(SLAPI_LOG_ERR, "ldbm_back_next_search_entry",
                                           "Filter bypass ERROR on entry %s\n", backentry_get_ndn(e));
                             filter_test = ft_rc; /* Fix the error */
                         }
@@ -1733,29 +1729,23 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
                         slapi_pblock_set(pb, SLAPI_SEARCH_SIZELIMIT, &slimit);
                         if (op_is_pagedresults(op)) {
                             /*
-                          * On Simple Paged Results search,
-                          * sizelimit is appied to each page.
-                          */
+                             * On Simple Paged Results search,
+                             * sizelimit is appied to each page.
+                             */
                             pagedresults_set_sizelimit(conn, op, slimit, pr_idx);
                         }
                         sr->sr_current_sizelimit = slimit;
                     }
                     if ((filter_test != 0) && sr->sr_virtuallistview) {
                         /* Slapi Filter Test failed.
-                      * Must be that the ACL check failed.
-                      * Send back an empty entry.
-                      */
+                         * Must be that the ACL check failed.
+                         * Send back an empty entry.
+                         */
                         sr->sr_vlventry = slapi_entry_alloc();
                         slapi_entry_init(sr->sr_vlventry, slapi_ch_strdup(slapi_entry_get_dn_const(e->ep_entry)), NULL);
                         e->ep_vlventry = sr->sr_vlventry;
-                        if (use_extension) {
-                            slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY_EXT, e);
-                        }
                         slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY, sr->sr_vlventry);
                     } else {
-                        if (use_extension) {
-                            slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY_EXT, e);
-                        }
                         slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY, e->ep_entry);
                     }
                     rc = 0;
@@ -1785,9 +1775,6 @@ ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension)
     /* check for the final abandon */
     if (slapi_op_abandoned(pb)) {
         slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_SET_SIZE_ESTIMATE, &estimate);
-        if (use_extension) {
-            slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY_EXT, NULL);
-        }
         slapi_pblock_set(pb, SLAPI_SEARCH_RESULT_ENTRY, NULL);
         delete_search_result_set(pb, &sr);
         rc = SLAPI_FAIL_GENERAL;
@@ -1901,18 +1888,20 @@ ldbm_back_entry_release(Slapi_PBlock *pb, void *backend_info_ptr)
     backend *be;
     ldbm_instance *inst;
 
-    if (backend_info_ptr == NULL)
+    if (backend_info_ptr == NULL) {
         return 1;
+    }
 
     slapi_pblock_get(pb, SLAPI_BACKEND, &be);
     inst = (ldbm_instance *)be->be_instance_info;
 
     if (((struct backentry *)backend_info_ptr)->ep_vlventry != NULL) {
-        /* This entry was created during a vlv search whose acl check failed.  It needs to be
-         * freed here */
+        /* This entry was created during a vlv search whose acl check failed.
+         * It needs to be freed here */
         slapi_entry_free(((struct backentry *)backend_info_ptr)->ep_vlventry);
         ((struct backentry *)backend_info_ptr)->ep_vlventry = NULL;
     }
+
     CACHE_RETURN(&inst->inst_cache, (struct backentry **)&backend_info_ptr);
 
     return 0;
