@@ -21,6 +21,7 @@
  */
 struct attrinfo *attrinfo_new(void);
 void attrinfo_delete(struct attrinfo **pp);
+void attrinfo_delete_from_tree(backend *be, struct attrinfo *ai);
 void ainfo_get(backend *be, char *type, struct attrinfo **at);
 void attr_masks(backend *be, char *type, int *indexmask, int *syntaxmask);
 void attr_masks_ex(backend *be, char *type, int *indexmask, int *syntaxmask, struct attrinfo **at);
@@ -81,6 +82,7 @@ int dblayer_get_index_file(backend *be, struct attrinfo *a, DB **ppDB, int creat
 int dblayer_release_index_file(backend *be, struct attrinfo *a, DB *pDB);
 int dblayer_erase_index_file(backend *be, struct attrinfo *a, PRBool use_lock, int no_force_chkpt);
 int dblayer_get_id2entry(backend *be, DB **ppDB);
+int dblayer_get_changelog(backend *be, DB** ppDB, int create);
 int dblayer_release_id2entry(backend *be, DB *pDB);
 int dblayer_txn_init(struct ldbminfo *li, back_txn *txn);
 int dblayer_txn_begin(backend *be, back_txnid parent_txn, back_txn *txn);
@@ -125,7 +127,7 @@ void *bdb_get_batch_transactions(void *arg);
 void *bdb_get_batch_txn_min_sleep(void *arg);
 void *bdb_get_batch_txn_max_sleep(void *arg);
 int dblayer_in_import(ldbm_instance *inst);
-
+int ldbm_back_entry_release(Slapi_PBlock *pb, void *backend_info_ptr);
 int dblayer_update_db_ext(ldbm_instance *inst, char *oldext, char *newext);
 
 char *dblayer_get_full_inst_dir(struct ldbminfo *li, ldbm_instance *inst, char *buf, int buflen);
@@ -323,6 +325,7 @@ int get_parent_rdn(DB *db, ID parentid, Slapi_RDN *srdn);
 /*
  * modify.c
  */
+int32_t entry_get_rdn_mods(Slapi_PBlock *pb, Slapi_Entry *entry, CSN *csn, int repl_op, Slapi_Mods **smods_ret);
 int modify_update_all(backend *be, Slapi_PBlock *pb, modify_context *mc, back_txn *txn);
 void modify_init(modify_context *mc, struct backentry *old_entry);
 int modify_apply_mods(modify_context *mc, Slapi_Mods *smods);
@@ -470,21 +473,11 @@ int ldbm_back_ldbm2archive(Slapi_PBlock *pb);
 int ldbm_back_upgradedb(Slapi_PBlock *pb);
 int ldbm_back_dbverify(Slapi_PBlock *pb);
 int ldbm_back_next_search_entry(Slapi_PBlock *pb);
-int ldbm_back_next_search_entry_ext(Slapi_PBlock *pb, int use_extension);
-int ldbm_back_entry_release(Slapi_PBlock *pb, void *backend_info_ptr);
 void ldbm_back_search_results_release(void **search_results);
 int ldbm_back_init(Slapi_PBlock *pb);
 void ldbm_back_prev_search_results(Slapi_PBlock *pb);
 int ldbm_back_isinitialized(void);
 
-/*
- * monitor.c
- */
-
-int ldbm_back_monitor_search(Slapi_PBlock *pb, Slapi_Entry *e, Slapi_Entry *entryAfter, int *returncode, char *returntext, void *arg);
-int ldbm_back_monitor_instance_search(Slapi_PBlock *pb, Slapi_Entry *e, Slapi_Entry *entryAfter, int *returncode, char *returntext, void *arg);
-int ldbm_back_dbmonitor_search(Slapi_PBlock *pb, Slapi_Entry *e, Slapi_Entry *entryAfter, int *returncode, char *returntext, void *arg);
-
 /*
  * vlv.c
  */
@@ -536,17 +529,6 @@ int vlv_isvlv(char *filename);
 int indexfile_delete_all_keys(backend *be, char *type, back_txn *txn);
 int indexfile_primary_modifyall(backend *be, LDAPMod **mods_to_perform, char **indexes_to_update, back_txn *txn);
 
-/*
- * bedse.c
- */
-#if 0
-int bedse_init(void);
-int bedse_search(Slapi_PBlock *pb);
-struct dse_callback *bedse_register_callback(int operation, const Slapi_DN *base, int scope, const char *filter, int (*fn)(Slapi_PBlock *,Slapi_Entry *,Slapi_Entry *,int*,char*,void *), void *fn_arg);
-void bedse_remove_callback(int operation, const Slapi_DN *base, int scope, const char *filter, int (*fn)(Slapi_PBlock *,Slapi_Entry *,Slapi_Entry *,int*,char*,void *));
-int bedse_add_index_entry(int argc, char **argv);
-#endif
-
 /*
  * ldbm_search.c
  */
