@@ -180,6 +180,7 @@ void be_done(Slapi_Backend *be);
 void be_addsuffix(Slapi_Backend *be, const Slapi_DN *suffix);
 Slapi_DN *be_getconfigdn(Slapi_Backend *be, Slapi_DN *dn);
 Slapi_DN *be_getmonitordn(Slapi_Backend *be, Slapi_DN *dn);
+Slapi_DN *be_getbasedn(Slapi_Backend *be, Slapi_DN *dn);
 int be_writeconfig(Slapi_Backend *be);
 void global_backend_lock_init(void);
 int global_backend_lock_requested(void);
@@ -251,6 +252,7 @@ int config_set_ldapi_map_entries(const char *attrname, char *value, char *errorb
 int config_set_ldapi_uidnumber_type(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_ldapi_gidnumber_type(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_ldapi_search_base_dn(const char *attrname, char *value, char *errorbuf, int apply);
+int config_set_ldapi_mapping_base_dn(const char *attrname, char *value, char *errorbuf, int apply);
 #if defined(ENABLE_AUTO_DN_SUFFIX)
 int config_set_ldapi_auto_dn_suffix(const char *attrname, char *value, char *errorbuf, int apply);
 #endif
@@ -384,6 +386,7 @@ int config_set_disk_grace_period(const char *attrname, char *value, char *errorb
 int config_set_disk_logging_critical(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_auditlog_unhashed_pw(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_auditfaillog_unhashed_pw(const char *attrname, char *value, char *errorbuf, int apply);
+int config_set_external_libs_debug_enabled(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_ndn_cache_enabled(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_ndn_cache_max_size(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_unhashed_pw_switch(const char *attrname, char *value, char *errorbuf, int apply);
@@ -402,6 +405,7 @@ int config_set_localuser(const char *attrname, char *value, char *errorbuf, int
 
 int config_set_maxsimplepaged_per_conn(const char *attrname, char *value, char *errorbuf, int apply);
 
+int log_external_libs_debug_set_log_fn(void);
 int log_set_backend(const char *attrname, char *value, int logtype, char *errorbuf, int apply);
 
 #ifdef HAVE_CLOCK_GETTIME
@@ -425,6 +429,7 @@ int config_get_ldapi_map_entries(void);
 char *config_get_ldapi_uidnumber_type(void);
 char *config_get_ldapi_gidnumber_type(void);
 char *config_get_ldapi_search_base_dn(void);
+char *config_get_ldapi_mapping_base_dn(void);
 #if defined(ENABLE_AUTO_DN_SUFFIX)
 char *config_get_ldapi_auto_dn_suffix(void);
 #endif
@@ -543,9 +548,10 @@ void config_set_accesslog_enabled(int value);
 void config_set_auditlog_enabled(int value);
 void config_set_auditfaillog_enabled(int value);
 int config_get_accesslog_logging_enabled(void);
+int config_get_external_libs_debug_enabled(void);
 int config_get_disk_monitoring(void);
 int config_get_disk_threshold_readonly(void);
-PRInt64 config_get_disk_threshold(void);
+uint64_t config_get_disk_threshold(void);
 int config_get_disk_grace_period(void);
 int config_get_disk_logging_critical(void);
 int config_get_ndn_cache_count(void);
@@ -1322,7 +1328,6 @@ void factory_destroy_extension(int type, void *object, void *parent, void **exte
 /*
  * auditlog.c
  */
-
 void write_audit_log_entry(Slapi_PBlock *pb);
 void auditlog_hide_unhashed_pw(void);
 void auditlog_expose_unhashed_pw(void);
@@ -1334,10 +1339,15 @@ void auditfaillog_expose_unhashed_pw(void);
 /*
  * eventq.c
  */
+void eq_init_rel(void);
+void eq_start_rel(void);
+void eq_stop_rel(void);
+/* Deprecated eventq that uses REALTIME clock instead of MONOTONIC */
 void eq_init(void);
 void eq_start(void);
 void eq_stop(void);
 
+
 /*
  * uniqueidgen.c
  */
@@ -1549,10 +1559,6 @@ int pagedresults_set_timelimit(Connection *conn, Operation *op, time_t timelimit
 int pagedresults_get_sizelimit(Connection *conn, Operation *op, int index);
 int pagedresults_set_sizelimit(Connection *conn, Operation *op, int sizelimit, int index);
 int pagedresults_cleanup(Connection *conn, int needlock);
-#if 0 /* Stopped using it (#47347) */
-int pagedresults_check_or_set_processing(Connection *conn, int index);
-int pagedresults_reset_processing(Connection *conn, int index);
-#endif
 int pagedresults_is_timedout_nolock(Connection *conn);
 int pagedresults_reset_timedout_nolock(Connection *conn);
 int pagedresults_in_use_nolock(Connection *conn);
