@@ -34,9 +34,8 @@ check_must_change_pw(Slapi_PBlock *pb, Slapi_Entry *e)
     time_t pw_exp_date;
     char *passwordExpirationTime = NULL;
 
-    if ((passwordExpirationTime = slapi_entry_attr_get_charptr(e, "passwordExpirationTime"))) {
+    if ((passwordExpirationTime = (char *)slapi_entry_attr_get_ref(e, "passwordExpirationTime"))) {
         pw_exp_date = parse_genTime(passwordExpirationTime);
-        slapi_ch_free_string(&passwordExpirationTime);
 
         /* Check if password has been reset */
         if (pw_exp_date == NO_TIME) {
@@ -97,7 +96,7 @@ need_new_pw(Slapi_PBlock *pb, Slapi_Entry *e, int pwresponse_req)
     cur_time = slapi_current_utc_time();
 
     /* get passwordExpirationTime attribute */
-    passwordExpirationTime = slapi_entry_attr_get_charptr(e, "passwordExpirationTime");
+    passwordExpirationTime = (char *)slapi_entry_attr_get_ref(e, "passwordExpirationTime");
 
     if (passwordExpirationTime == NULL) {
         /* password expiration date is not set.
@@ -122,8 +121,6 @@ need_new_pw(Slapi_PBlock *pb, Slapi_Entry *e, int pwresponse_req)
 
     pw_exp_date = parse_genTime(passwordExpirationTime);
 
-    slapi_ch_free_string(&passwordExpirationTime);
-
     slapi_pblock_get(pb, SLAPI_CONNECTION, &pb_conn);
     if (pb_conn) {
         needpw = pb_conn->c_needpw;
@@ -207,10 +204,10 @@ skip:
 
         /* password expired and user exceeded limit of grace attemps.
          * Send result and also the control */
-        slapi_add_pwd_control(pb, LDAP_CONTROL_PWEXPIRED, 0);
         if (pwresponse_req) {
             slapi_pwpolicy_make_response_control(pb, -1, -1, LDAP_PWPOLICY_PWDEXPIRED);
         }
+        slapi_add_pwd_control(pb, LDAP_CONTROL_PWEXPIRED, 0);
         slapi_send_ldap_result(pb, LDAP_INVALID_CREDENTIALS, NULL,
                                "password expired!", 0, NULL);
 
