@@ -26,6 +26,10 @@
 #include "slap.h"
 #include "fe.h"
 
+#ifdef RUST_ENABLE
+#include <rust-nsslapd-private.h>
+#endif
+
 int
 pw_verify_root_dn(const char *dn, const Slapi_Value *cred)
 {
@@ -111,6 +115,7 @@ pw_verify_token_dn(Slapi_PBlock *pb) {
     if (fernet_verify_token(dn, cred->bv_val, key, tok_ttl) != 0) {
         rc = SLAPI_BIND_SUCCESS;
     }
+    slapi_ch_free_string(&key);
 #endif
     return rc;
 }
