@@ -1,12 +1,15 @@
 /** BEGIN COPYRIGHT BLOCK
  * Copyright (C) 2001 Sun Microsystems, Inc. Used by permission.
  * Copyright (C) 2005 Red Hat, Inc.
+ * Copyright (C) 2020 William Brown <william@blackhats.net.au>
  * All rights reserved.
  *
  * License: GPL (version 3 or any later version).
  * See LICENSE for details.
  * END COPYRIGHT BLOCK **/
 
+#pragma once
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -459,7 +462,6 @@ LDAPMod **copy_mods(LDAPMod **orig_mods);
  */
 #define LDAP_MOD_IGNORE 0x100
 
-
 /* dl.c */
 typedef struct datalist DataList;
 
@@ -909,16 +911,12 @@ int proxyauth_get_dn(Slapi_PBlock *pb, char **proxydnp, char **errtextp);
 #define SLAPI_PLUGIN_DB_DB2ARCHIVE_FN             223
 #define SLAPI_PLUGIN_DB_NEXT_SEARCH_ENTRY_FN      224
 #define SLAPI_PLUGIN_DB_FREE_RESULT_SET_FN        225
-#define SLAPI_PLUGIN_DB_SIZE_FN                   226
 #define SLAPI_PLUGIN_DB_TEST_FN                   227
 #define SLAPI_PLUGIN_DB_DB2INDEX_FN               228
 #define SLAPI_PLUGIN_DB_NEXT_SEARCH_ENTRY_EXT_FN  229
-#define SLAPI_PLUGIN_DB_ENTRY_RELEASE_FN          230
-#define SLAPI_PLUGIN_DB_INIT_INSTANCE_FN          231
 #define SLAPI_PLUGIN_DB_WIRE_IMPORT_FN            234
 #define SLAPI_PLUGIN_DB_UPGRADEDB_FN              235
 #define SLAPI_PLUGIN_DB_DBVERIFY_FN               236
-#define SLAPI_PLUGIN_DB_ADD_SCHEMA_FN             237
 #define SLAPI_PLUGIN_DB_SEARCH_RESULTS_RELEASE_FN 238
 #define SLAPI_PLUGIN_DB_PREV_SEARCH_RESULTS_FN    239
 #define SLAPI_PLUGIN_DB_UPGRADEDNFORMAT_FN        240
@@ -1465,6 +1463,11 @@ void slapi_pblock_set_operation_notes(Slapi_PBlock *pb, uint32_t opnotes);
 void slapi_pblock_set_flag_operation_notes(Slapi_PBlock *pb, uint32_t opflag);
 void slapi_pblock_set_result_text_if_empty(Slapi_PBlock *pb, char *text);
 
+int32_t slapi_pblock_get_task_warning(Slapi_PBlock *pb);
+void slapi_pblock_set_task_warning(Slapi_PBlock *pb, task_warning warn);
+
+int slapi_exists_or_add_internal(Slapi_DN *dn, const char *filter, const char *entry, const char *modifier_name);
+
 #ifdef __cplusplus
 }
 #endif
