@@ -507,6 +507,7 @@ void
 print_changelog(unsigned char *data, int len __attribute__((unused)))
 {
     uint8_t version;
+    uint8_t encrypted;
     unsigned long operation_type;
     char *pos = (char *)data;
     uint32_t thetime32;
@@ -515,12 +516,18 @@ print_changelog(unsigned char *data, int len __attribute__((unused)))
 
     /* read byte of version */
     version = *((uint8_t *)pos);
-    if (version != 5) {
-        db_printf("Invalid changelog db version %i\nWorks for version 5 only.\n", version);
+    if (version != 5 && version != 6) {
+        db_printf("Invalid changelog db version %i\nWorks for version 5 and 6 only.\n", version);
         exit(1);
     }
     pos += sizeof(version);
 
+    if (version == 6) {
+        /* process the encrypted flag */
+        db_printf("\tencrypted: %s\n", *pos ? "yes" : "no");
+        pos += sizeof(encrypted);
+    }
+
     /* read change type */
     operation_type = (unsigned long)(*(uint8_t *)pos);
     pos++;
@@ -1047,6 +1054,9 @@ is_changelog(char *filename)
     } else {
         ptr++;
     }
+
+    if (0 == strcmp(ptr, "replication_changelog.db")) return 1;
+
     for (; ptr && *ptr; ptr++) {
         if ('.' == *ptr) {
             if (0 == strncmp(ptr, ".db", 3)) {
@@ -1133,7 +1143,7 @@ main(int argc, char **argv)
     DBC *cursor = NULL;
     char *filename = NULL;
     DBT key = {0}, data = {0};
-    int ret;
+    int ret = 0;
     char *find_key = NULL;
     uint32_t entry_id = 0xffffffff;
     int c;
@@ -1210,23 +1220,27 @@ main(int argc, char **argv)
     ret = db_env_create(&env, 0);
     if (ret != 0) {
         printf("Can't create dbenv: %s\n", db_strerror(ret));
-        exit(1);
+        ret = 1;
+        goto done;
     }
     ret = env->open(env, NULL, DB_CREATE | DB_INIT_MPOOL | DB_PRIVATE, 0);
     if (ret != 0) {
         printf("Can't open dbenv: %s\n", db_strerror(ret));
-        exit(1);
+        ret = 1;
+        goto done;
     }
 
     ret = db_create(&db, env, 0);
     if (ret != 0) {
         printf("Can't create db handle: %d\n", ret);
-        exit(1);
+        ret = 1;
+        goto done;
     }
     ret = db->open(db, NULL, filename, NULL, DB_UNKNOWN, DB_RDONLY, 0);
     if (ret != 0) {
         printf("Can't open db file '%s': %s\n", filename, db_strerror(ret));
-        exit(1);
+        ret = 1;
+        goto done;
     }
 
     /* cursor through the db */
@@ -1234,16 +1248,19 @@ main(int argc, char **argv)
     ret = db->cursor(db, NULL, &cursor, 0);
     if (ret != 0) {
         printf("Can't create db cursor: %s\n", db_strerror(ret));
-        exit(1);
+        ret = 1;
+        goto done;
     }
     ret = cursor->c_get(cursor, &key, &data, DB_FIRST);
     if (ret == DB_NOTFOUND) {
         printf("Empty database!\n");
-        exit(0);
+        ret = 0;
+        goto done;
     }
     if (ret != 0) {
         printf("Can't get first cursor: %s\n", db_strerror(ret));
-        exit(1);
+        ret = 1;
+        goto done;
     }
 
     if (find_key) {
@@ -1256,7 +1273,8 @@ main(int argc, char **argv)
             ret = db->get(db, NULL, &key, &data, 0);
             if (ret != 0) {
                 printf("Can't find key '%s'\n", find_key);
-                exit(1);
+                ret = 1;
+                goto done;
             }
         }
         if (file_type & ENTRYRDNINDEXTYPE) {
@@ -1266,7 +1284,8 @@ main(int argc, char **argv)
             if (ret != 0) {
                 printf("Can't set cursor to returned item: %s\n",
                        db_strerror(ret));
-                exit(1);
+                ret = 1;
+                goto done;
             }
             do {
                 display_item(cursor, &key, &data);
@@ -1282,7 +1301,8 @@ main(int argc, char **argv)
         if (ret != 0) {
             printf("Can't set cursor to returned item: %s\n",
                    db_strerror(ret));
-            exit(1);
+            ret = 1;
+            goto done;
         }
         display_item(cursor, &key, &data);
         key.size = 0;
@@ -1299,31 +1319,15 @@ main(int argc, char **argv)
                 ret = cursor->c_get(cursor, &key, &data, DB_NEXT);
                 if ((ret != 0) && (ret != DB_NOTFOUND)) {
                     printf("Bizarre error: %s\n", db_strerror(ret));
-                    exit(1);
+                    ret = 1;
+                    goto done;
                 }
             }
+            /* Success! Setting the return code to 0 */
+            ret = 0;
         }
     }
 
-    if (key.data) {
-        free(key.data);
-    }
-    if (data.data) {
-        free(data.data);
-    }
-
-    ret = cursor->c_close(cursor);
-    if (ret != 0) {
-        printf("Can't close the cursor (?!): %s\n", db_strerror(ret));
-        exit(1);
-    }
-
-    ret = db->close(db, 0);
-    if (ret != 0) {
-        printf("Unable to close db file: %s\n", db_strerror(ret));
-        exit(1);
-    }
-
     if (display_mode & SHOWSUMMARY) {
 
         if (allids_cnt > 0) {
@@ -1359,11 +1363,30 @@ main(int argc, char **argv)
         }
     }
 
-    ret = env->close(env, 0);
-    if (ret != 0) {
-        printf("Unable to shutdown libdb: %s\n", db_strerror(ret));
-        exit(1);
+done:
+    if (key.data) {
+        free(key.data);
     }
-
-    return 0;
+    if (data.data) {
+        free(data.data);
+    }
+    if (cursor) {
+        if (cursor->c_close(cursor) != 0) {
+            printf("Can't close the cursor (?!): %s\n", db_strerror(1));
+            return 1;
+        }
+    }
+    if (db) {
+        if (db->close(db, 0) != 0) {
+            printf("Unable to close db file: %s\n", db_strerror(1));
+            return 1;
+        }
+    }
+    if (env) {
+        if (env->close(env, 0) != 0) {
+            printf("Unable to shutdown libdb: %s\n", db_strerror(1));
+            return 1;
+        }
+    }
+    return ret;
 }
