@@ -26,6 +26,7 @@
 #include "snmp_collator.h"
 #include <sys/time.h>
 #include <sys/resource.h>
+#include <errno.h>
 
 #define UTIL_ESCAPE_NONE 0
 #define UTIL_ESCAPE_HEX 1
@@ -1487,49 +1488,39 @@ util_is_cachesize_sane(slapi_pal_meminfo *mi, uint64_t *cachesize)
 long
 util_get_hardware_threads(void)
 {
+    long threads = MIN_THREADS;
 #ifdef LINUX
     long hw_threads = sysconf(_SC_NPROCESSORS_ONLN);
-    long threads = 0;
-    slapi_log_err(SLAPI_LOG_TRACE, "util_get_hardware_threads", "Detected %lu hardware threads\n", threads);
-    /*
-     * Now we determine the number to run with based on threads. Initially, for
-     * low processor counts we ramp up quickly, we plateau a little, then, we
-     * at high numbers start to plateau and increase slowly.
-     * Should be
-     * 1 -> 16
-     * 2 -> 16
-     * 4 -> 24
-     * 8 -> 32
-     * 16 -> 48
-     * 32 -> 64
-     * 64 -> 96
-     * 128 -> 192
-     * 256 -> 384
-     * 512 -> 512
-     * 1024 -> 512
-     * 2048 -> 512
-     */
 
-    if (hw_threads >= 0 && hw_threads < 4) {
-        threads = 16;
-    } else if (hw_threads >= 4 && hw_threads < 32) {
-        threads = 16 + (hw_threads * 2);
-    } else if (hw_threads >= 32 && hw_threads < 64) {
-        threads = (hw_threads * 2);
-    } else if (hw_threads >= 64 && hw_threads < 512) {
-        /* Same as *1.5 */
-        threads = (hw_threads * 2) - (hw_threads / 2);
-    } else {
-        /* Cap at 512 for now ... */
-        threads = 512;
+    slapi_log_err(SLAPI_LOG_TRACE, "util_get_hardware_threads",
+             "Detected %ld hardware threads\n", hw_threads);
+
+    if (hw_threads == -1) {
+        /* sysconf failed, use MIN_THREADS */
+        slapi_log_err(SLAPI_LOG_ERR, "util_get_hardware_threads",
+                "Failed to get hardware threads.  Error (%d) %s\n",
+                errno, slapd_system_strerror(errno));
+    } else if (hw_threads == 0) {
+        /* sysconf failed to find any processors, use MIN_THREADS */
+        slapi_log_err(SLAPI_LOG_ERR, "util_get_hardware_threads",
+                "Cannot detect any hardware threads.\n");
+    } else if (hw_threads > MIN_THREADS) {
+        if (hw_threads < MAX_THREADS) {
+            threads = hw_threads;
+        } else {
+            /* Cap at 512 for now ... */
+            threads = MAX_THREADS;
+        }
     }
-    slapi_log_err(SLAPI_LOG_INFO, "util_get_hardware_threads", "Automatically configuring %lu threads\n", threads);
+
+    slapi_log_err(SLAPI_LOG_INFO, "util_get_hardware_threads", "Automatically configuring %ld threads\n", threads);
 
     return threads;
 #else
-    slapi_log_err(SLAPI_LOG_ERR, "util_get_hardware_threads", "ERROR: Cannot detect hardware threads on this platform. This is probably a bug!\n");
-    /* Can't detect threads on this platform! */
-    return -1;
+    slapi_log_err(SLAPI_LOG_ERR, "util_get_hardware_threads",
+            "ERROR: Cannot detect hardware threads on this platform. This is probably a bug!\n");
+    /* Can't detect threads on this platform!  Return the default thread number */
+    return threads;
 #endif
 }
 
