@@ -4,11 +4,11 @@
  * All rights reserved.
  *
  * License: GPL (version 3 or any later version).
- * See LICENSE for details. 
+ * See LICENSE for details.
  * END COPYRIGHT BLOCK **/
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 /*
@@ -27,33 +27,34 @@
 
 /* Be sure to edit libadmin.h and add new #define types for these headers. */
 char *error_headers[MAX_ERROR] =
-  {"File System Error",
-   "Memory Error",
-   "System Error",
-   "Incorrect Usage",
-   "Form Element Missing",
-   "Registry Database Error",
-   "Network Error",
-   "Unexpected Failure",
-   "Warning"};
+    {"File System Error",
+     "Memory Error",
+     "System Error",
+     "Incorrect Usage",
+     "Form Element Missing",
+     "Registry Database Error",
+     "Network Error",
+     "Unexpected Failure",
+     "Warning"};
 
 #define get_error() errno
 #define verbose_error() system_errmsg()
 
 
-void _report_error(int type, char *info, char *details, int shouldexit)
+void
+_report_error(int type, char *info, char *details, int shouldexit)
 {
     /* Be sure headers are terminated. */
     fputs("\n", stdout);
 
     fprintf(stdout, "<SCRIPT LANGUAGE=\"JavaScript\">");
     output_alert(type, info, details, 0);
-    if(shouldexit)  {
-        fprintf(stdout, "if(history.length>1) history.back();"); 
+    if (shouldexit) {
+        fprintf(stdout, "if(history.length>1) history.back();");
     }
     fprintf(stdout, "</SCRIPT>\n");
 
-    if(shouldexit)  {
+    if (shouldexit) {
         exit(0);
     }
 }
@@ -62,26 +63,29 @@ void _report_error(int type, char *info, char *details, int shouldexit)
  * Format and output a call to the JavaScript alert() function.
  * The caller must ensure a JavaScript context.
  */
-NSAPI_PUBLIC void output_alert(int type, char *info, char *details, int wait)
+NSAPI_PUBLIC void
+output_alert(int type, char *info, char *details, int wait)
 {
-    char *wrapped=NULL;
+    char *wrapped = NULL;
     int err;
 
-    if(type >= MAX_ERROR)
-        type=DEFAULT_ERROR;
+    if (type >= MAX_ERROR)
+        type = DEFAULT_ERROR;
 
-    wrapped=alert_word_wrap(details, WORD_WRAP_WIDTH, "\\n");
+    wrapped = alert_word_wrap(details, WORD_WRAP_WIDTH, "\\n");
 
-    if(!info) info="";
+    if (!info)
+        info = "";
     fprintf(stdout, (wait) ? "confirm(\"" : "alert(\"");
     fprintf(stdout, "%s:%s\\n%s", error_headers[type], info, wrapped);
-    if(type==FILE_ERROR || type==SYSTEM_ERROR)  {
+    if (type == FILE_ERROR || type == SYSTEM_ERROR) {
         err = get_error();
-        if(err != 0){
+        if (err != 0) {
             const char *err_str = verbose_error();
             fprintf(stdout,
-                        "\\n\\nThe system returned error number %d, "
-                        "which is %s.", err, err_str);
+                    "\\n\\nThe system returned error number %d, "
+                    "which is %s.",
+                    err, err_str);
             FREE(err_str);
         }
     }
@@ -90,13 +94,14 @@ NSAPI_PUBLIC void output_alert(int type, char *info, char *details, int wait)
     FREE(wrapped);
 }
 
-NSAPI_PUBLIC void report_error(int type, char *info, char *details)
+NSAPI_PUBLIC void
+report_error(int type, char *info, char *details)
 {
     _report_error(type, info, details, 1);
 }
 
-NSAPI_PUBLIC void report_warning(int type, char *info, char *details)
+NSAPI_PUBLIC void
+report_warning(int type, char *info, char *details)
 {
     _report_error(type, info, details, 0);
 }
-
