@@ -20,7 +20,6 @@ import {
 } from "patternfly-react";
 import PropTypes from "prop-types";
 import { Typeahead } from "react-bootstrap-typeahead";
-import "../../css/ds.css";
 
 export class SuffixIndexes extends React.Component {
     constructor (props) {
@@ -71,7 +70,7 @@ export class SuffixIndexes extends React.Component {
         this.closeReindexModal = this.closeReindexModal.bind(this);
     }
 
-    componentWillMount () {
+    componentDidMount () {
         this.loadIndexes();
     }
 
