@@ -17,12 +17,11 @@ import { Typeahead } from "react-bootstrap-typeahead";
 import PropTypes from "prop-types";
 import PluginBasicConfig from "./pluginBasicConfig.jsx";
 import { log_cmd } from "../tools.jsx";
-import "../../css/ds.css";
 
 // Use default aacount policy name
 
 class AccountPolicy extends React.Component {
-    componentWillMount(prevProps) {
+    componentDidMount() {
         this.updateFields();
     }
 
