@@ -20,7 +20,6 @@ import { DoubleConfirmModal } from "../notifications.jsx";
 import PluginBasicConfig from "./pluginBasicConfig.jsx";
 import PropTypes from "prop-types";
 import { log_cmd } from "../tools.jsx";
-import "../../css/ds.css";
 
 class AttributeUniqueness extends React.Component {
     componentDidMount() {
@@ -96,7 +95,12 @@ class AttributeUniqueness extends React.Component {
         // instead of string.  Grab the "label" in this case
         let new_values = [];
         for (let val of values) {
-            new_values.push(val.label);
+            if (val != "") {
+                if (typeof val === 'object') {
+                    val = val.label;
+                }
+                new_values.push(val);
+            }
         }
         this.setState({
             subtrees: new_values
