@@ -10,7 +10,6 @@ import {
 } from "patternfly-react";
 import { DSTable } from "../dsTable.jsx";
 import PropTypes from "prop-types";
-import "../../css/ds.css";
 
 class PluginTable extends React.Component {
     constructor(props) {
@@ -107,7 +106,7 @@ class PluginTable extends React.Component {
                                                 this.props.loadModalHandler(rowData);
                                             }}
                                         >
-                                            Edit Plugin
+                                            View Plugin
                                         </Button>
                                     </td>
                                 ];
