@@ -16,10 +16,9 @@ import { Typeahead } from "react-bootstrap-typeahead";
 import PropTypes from "prop-types";
 import PluginBasicConfig from "./pluginBasicConfig.jsx";
 import { log_cmd } from "../tools.jsx";
-import "../../css/ds.css";
 
 class ReferentialIntegrity extends React.Component {
-    componentWillMount(prevProps) {
+    componentDidMount(prevProps) {
         if (this.props.wasActiveList.includes(5)) {
             if (this.state.firstLoad) {
                 this.getAttributes();
