@@ -16,10 +16,9 @@ import {
 import PropTypes from "prop-types";
 import PluginBasicConfig from "./pluginBasicConfig.jsx";
 import { log_cmd } from "../tools.jsx";
-import "../../css/ds.css";
 
 class WinSync extends React.Component {
-    componentWillMount(prevProps) {
+    componentDidMount(prevProps) {
         this.updateFields();
     }
 
