@@ -10,12 +10,12 @@ import {
     Icon,
     Modal,
     noop,
+    Radio,
     Spinner,
 } from "patternfly-react";
 import PropTypes from "prop-types";
 import CustomCollapse from "../customCollapse.jsx";
 import { Typeahead } from "react-bootstrap-typeahead";
-import "../../css/ds.css";
 
 export class WinsyncAgmtModal extends React.Component {
     handleNavSelect(key) {
@@ -548,6 +548,12 @@ export class ReplAgmtModal extends React.Component {
             agmtBindDN,
             agmtBindPW,
             agmtBindPWConfirm,
+            agmtBootstrap,
+            agmtBootstrapBindDN,
+            agmtBootstrapBindPW,
+            agmtBootstrapBindPWConfirm,
+            agmtBootstrapProtocol,
+            agmtBootstrapBindMethod,
             agmtStripAttrs,
             agmtFracAttrs,
             agmtFracInitAttrs,
@@ -573,6 +579,10 @@ export class ReplAgmtModal extends React.Component {
         let errMsgClass = "ds-center ds-modal-error";
         let errMsg = errorMsg;
         let name = "agmt-modal";
+        let bootstrapTitle = "If you are using Bind Group's on the consumer " +
+            "replica you can configure bootstrap credentials that can be used " +
+            "to do online initializations, or bootstrap a session if the bind " +
+            "groups get out of synchronization";
 
         if (this.props.edit) {
             title = "Edit";
@@ -609,6 +619,91 @@ export class ReplAgmtModal extends React.Component {
                 </Row>;
         }
 
+        let bootstrapRow =
+            <div className="ds-left-indent-md">
+                <Row className="ds-margin-top-lg" title="The Bind DN the agreement can use to bootstrap initialization">
+                    <Col componentClass={ControlLabel} sm={4}>
+                        Bind DN
+                    </Col>
+                    <Col sm={8}>
+                        <FormControl
+                            id="agmtBootstrapBindDN"
+                            type="text"
+                            name={name}
+                            className={error.agmtBootstrapBindDN ? "ds-input-bad" : ""}
+                            onChange={handleChange}
+                            autoComplete="false"
+                            defaultValue={agmtBootstrapBindDN}
+                        />
+                    </Col>
+                </Row>
+                <Row className="ds-margin-top">
+                    <Col componentClass={ControlLabel} sm={4} title="The Bind DN password for bootstrap initialization">
+                        Password
+                    </Col>
+                    <Col sm={8}>
+                        <FormControl
+                            id="agmtBootstrapBindPW"
+                            type="password"
+                            name={name}
+                            className={error.agmtBootstrapBindPW ? "ds-input-bad" : ""}
+                            onChange={handleChange}
+                            autoComplete="new-password"
+                            defaultValue={agmtBootstrapBindPW}
+                        />
+                    </Col>
+                </Row>
+                <Row className="ds-margin-top">
+                    <Col componentClass={ControlLabel} sm={4} title="Confirm the Bind DN password for bootstrap initialization">
+                        Confirm Password
+                    </Col>
+                    <Col sm={8}>
+                        <FormControl
+                            id="agmtBootstrapBindPWConfirm"
+                            type="password"
+                            name={name}
+                            className={error.agmtBootstrapBindPWConfirm ? "ds-input-bad" : ""}
+                            onChange={handleChange}
+                            autoComplete="new-password"
+                            defaultValue={agmtBootstrapBindPWConfirm}
+                        />
+                    </Col>
+                </Row>
+                <Row className="ds-margin-top">
+                    <Col componentClass={ControlLabel} sm={4} title="The connection protocol for bootstrap initialization">
+                        Connection Protocol
+                    </Col>
+                    <Col sm={8}>
+                        <select className={error.agmtBootstrapProtocol ? "btn btn-default dropdown ds-input-bad" : "btn btn-default dropdown"}
+                            id="agmtBootstrapProtocol"
+                            defaultValue={agmtBootstrapProtocol}
+                            name={name}
+                            onChange={handleChange}
+                        >
+                            <option>LDAP</option>
+                            <option>LDAPS</option>
+                            <option title="Currently not recommended">StartTLS</option>
+                        </select>
+                    </Col>
+                </Row>
+                <Row className="ds-margin-top">
+                    <Col componentClass={ControlLabel} sm={4} title="The authentication method for bootstrap initialization">
+                        Authentication Method
+                    </Col>
+                    <Col sm={8}>
+                        <select className={error.agmtBootstrapBindMethod ? "btn btn-default dropdown ds-input-bad" : "btn btn-default dropdown"}
+                            defaultValue={agmtBootstrapBindMethod}
+                            id="agmtBootstrapBindMethod"
+                            name={name}
+                            onChange={handleChange}
+                        >
+                            <option title="Use a bind DN and password">SIMPLE</option>
+                            <option title="Use a SSL/TLS Client Certificate">SSLCLIENTAUTH</option>
+                        </select>
+                    </Col>
+                </Row>
+            </div>;
+
         let scheduleRow =
             <div className="ds-left-indent-md">
                 <Row className="ds-margin-top-lg">
@@ -732,13 +827,17 @@ export class ReplAgmtModal extends React.Component {
                             className={error.agmtEndTime ? "ds-input-bad" : ""}
                             onChange={handleChange}
                             defaultValue={agmtEndTime}
-                        />                    </Col>
+                        />
+                    </Col>
                 </Row>
             </div>;
 
         if (agmtSync) {
             scheduleRow = "";
         }
+        if (!agmtBootstrap) {
+            bootstrapRow = "";
+        }
         return (
             <Modal show={showModal} onHide={closeHandler}>
                 <div className="ds-no-horizontal-scrollbar">
@@ -861,7 +960,12 @@ export class ReplAgmtModal extends React.Component {
                                     Connection Protocol
                                 </Col>
                                 <Col sm={8}>
-                                    <select className="btn btn-default dropdown" id="agmtProtocol" defaultValue={agmtProtocol} name={name} onChange={handleChange}>
+                                    <select className={error.agmtProtocol ? "btn btn-default dropdown ds-input-bad" : "btn btn-default dropdown"}
+                                        id="agmtProtocol"
+                                        defaultValue={agmtProtocol}
+                                        name={name}
+                                        onChange={handleChange}
+                                    >
                                         <option>LDAP</option>
                                         <option>LDAPS</option>
                                         <option title="Currently not recommended">StartTLS</option>
@@ -873,7 +977,12 @@ export class ReplAgmtModal extends React.Component {
                                     Authentication Method
                                 </Col>
                                 <Col sm={8}>
-                                    <select className="btn btn-default dropdown" defaultValue={agmtBindMethod} id="agmtBindMethod" name={name} onChange={handleChange}>
+                                    <select className={error.agmtBindMethod ? "btn btn-default dropdown ds-input-bad" : "btn btn-default dropdown"}
+                                        defaultValue={agmtBindMethod}
+                                        id="agmtBindMethod"
+                                        name={name}
+                                        onChange={handleChange}
+                                    >
                                         <option title="Use bind DN and password">SIMPLE</option>
                                         <option title="Use SSL Client Certificate">SSLCLIENTAUTH</option>
                                         <option title="Use SASL Digest-MD5">SASL/DIGEST-MD5</option>
@@ -888,7 +997,7 @@ export class ReplAgmtModal extends React.Component {
                                 textClosed="Show Advanced Settings"
                             >
                                 <div className="ds-margin-left">
-                                    <Row className="ds-margin-top" title="Attribute to exclude from replication">
+                                    <Row className="ds-margin-top-lg" title="Attribute to exclude from replication">
                                         <Col componentClass={ControlLabel} sm={4}>
                                             Exclude Attributes
                                         </Col>
@@ -939,6 +1048,22 @@ export class ReplAgmtModal extends React.Component {
                                             />
                                         </Col>
                                     </Row>
+                                    <hr />
+                                    <Row className="ds-margin-top-med">
+                                        <Col sm={8}>
+                                            <Checkbox
+                                                id="agmtBootstrap"
+                                                defaultChecked={agmtBootstrap}
+                                                onChange={handleChange}
+                                                name={name}
+                                                title={bootstrapTitle}
+                                            >
+                                                Configure Bootstrap Settings
+                                            </Checkbox>
+                                        </Col>
+                                    </Row>
+                                    {bootstrapRow}
+                                    <hr />
                                     <Row className="ds-margin-top-med">
                                         <Col sm={8}>
                                             <Checkbox
@@ -1431,10 +1556,10 @@ export class ExportModal extends React.Component {
                                 </Col>
                             </Row>
                             <Row className="ds-margin-top-lg" title="Name of the exported LDIF file">
-                                <Col sm={3}>
+                                <Col componentClass={ControlLabel} sm={3}>
                                     <b>LDIF Name</b>
                                 </Col>
-                                <Col sm={9}>
+                                <Col sm={8}>
                                     <FormControl
                                         type="text"
                                         id="ldifLocation"
@@ -1468,6 +1593,159 @@ export class ExportModal extends React.Component {
     }
 }
 
+export class ExportCLModal extends React.Component {
+    constructor(props) {
+        super(props);
+        this.state = {
+            default: true,
+            debug: false,
+        };
+    }
+
+    render() {
+        const {
+            showModal,
+            closeHandler,
+            handleChange,
+            handleLDIFChange,
+            handleRadioChange,
+            saveHandler,
+            spinning,
+            defaultCL,
+            debugCL,
+            decodeCL,
+            exportCSN,
+            ldifFile,
+            saveOK
+        } = this.props;
+        let spinner = "";
+        let page = "";
+        if (spinning) {
+            spinner =
+                <Row>
+                    <div className="ds-margin-top ds-modal-spinner">
+                        <Spinner loading inline size="lg" />Exporting Replication Change Log... <font size="2">(You can safely close this window)</font>
+                    </div>
+                </Row>;
+        }
+
+        if (defaultCL) {
+            page =
+                <p>
+                    This will export the changelog to the server's LDIF directory.  This
+                    is the only LDIF file that can be imported into the server for enabling
+                    changelog encryption.  Do not edit or rename the file.
+                </p>;
+        } else {
+            page =
+                <div className="ds-margin-left">
+                    <Row className="ds-margin-top-lg">
+                        <Col sm={12}>
+                            <p>
+                                The LDIF file that is generated should <b>not</b> be used
+                                to initialize the Replication Changelog.  It is only
+                                meant for debugging/investigative purposes.
+                            </p>
+                        </Col>
+                    </Row>
+                    <Row className="ds-margin-top-xlg">
+                        <Col componentClass={ControlLabel} sm={2}>
+                            LDIF File
+                        </Col>
+                        <Col sm={10}>
+                            <FormControl
+                                id="ldifFile"
+                                value={ldifFile}
+                                onChange={handleLDIFChange}
+                            />
+                        </Col>
+                    </Row>
+                    <Row className="ds-margin-top-xlg ds-margin-left">
+                        <Checkbox
+                            id="decodeCL"
+                            checked={decodeCL}
+                            onChange={handleChange}
+                        >
+                            Decode base64 changes
+                        </Checkbox>
+                    </Row>
+                    <Row className="ds-margin-top ds-margin-left">
+                        <Checkbox
+                            id="exportCSN"
+                            checked={exportCSN}
+                            onChange={handleChange}
+                        >
+                            Only Export CSN's
+                        </Checkbox>
+                    </Row>
+                </div>;
+        }
+
+        return (
+            <Modal show={showModal} onHide={closeHandler}>
+                <div className="ds-no-horizontal-scrollbar">
+                    <Modal.Header>
+                        <button
+                            className="close"
+                            onClick={closeHandler}
+                            aria-hidden="true"
+                            aria-label="Close"
+                        >
+                            <Icon type="pf" name="close" />
+                        </button>
+                        <Modal.Title>
+                            Create Replication Change Log LDIF File
+                        </Modal.Title>
+                    </Modal.Header>
+                    <Modal.Body>
+                        <Form horizontal autoComplete="off">
+                            <Row className="ds-indent">
+                                <Radio
+                                    name="radioGroup"
+                                    id="defaultCL"
+                                    onChange={handleRadioChange}
+                                    checked={defaultCL} inline
+                                >
+                                    Export to LDIF For Reinitializing The Changelog
+                                </Radio>
+                            </Row>
+                            <Row className="ds-indent">
+                                <Radio
+                                    name="radioGroup"
+                                    id="debugCL"
+                                    onChange={handleRadioChange}
+                                    checked={debugCL} inline
+                                >
+                                    Export to LDIF For Debugging
+                                </Radio>
+                            </Row>
+                            <hr />
+                            {page}
+                            {spinner}
+                        </Form>
+                    </Modal.Body>
+                    <Modal.Footer>
+                        <Button
+                            bsStyle="default"
+                            className="btn-cancel"
+                            onClick={closeHandler}
+                        >
+                            Cancel
+                        </Button>
+                        <Button
+                            bsStyle="primary"
+                            onClick={saveHandler}
+                            disabled={!saveOK}
+                        >
+                            Export Changelog
+                        </Button>
+                    </Modal.Footer>
+                </div>
+            </Modal>
+        );
+    }
+}
+
 EnableReplModal.propTypes = {
     showModal: PropTypes.bool,
     closeHandler: PropTypes.func,
@@ -1544,6 +1822,12 @@ ReplAgmtModal.propTypes = {
     agmtBindDN: PropTypes.string,
     agmtBindPW: PropTypes.string,
     agmtBindPWConfirm: PropTypes.string,
+    agmtBootstrap: PropTypes.bool,
+    agmtBootstrapProtocol: PropTypes.string,
+    agmtBootstrapBindMethod: PropTypes.string,
+    agmtBootstrapBindDN: PropTypes.string,
+    agmtBootstrapBindPW: PropTypes.string,
+    agmtBootstrapBindPWConfirm: PropTypes.string,
     agmtStripAttrs: PropTypes.array,
     agmtFracAttrs: PropTypes.array,
     agmtFracInitAttrs: PropTypes.array,
@@ -1581,6 +1865,12 @@ ReplAgmtModal.defaultProps = {
     agmtBindDN: "",
     agmtBindPW: "",
     agmtBindPWConfirm: "",
+    agmtBootstrap: false,
+    agmtBootstrapProtocol: "LDAP",
+    agmtBootstrapBindMethod: "SIMPLE",
+    agmtBootstrapBindDN: "",
+    agmtBootstrapBindPW: "",
+    agmtBootstrapBindPWConfirm: "",
     agmtStripAttrs: [],
     agmtFracAttrs: [],
     agmtFracInitAttrs: [],
