@@ -10,7 +10,6 @@ import {
 } from "patternfly-react";
 import { DSTable } from "../dsTable.jsx";
 import PropTypes from "prop-types";
-import "../../css/ds.css";
 
 class ObjectClassesTable extends React.Component {
     constructor(props) {
@@ -133,6 +132,7 @@ class ObjectClassesTable extends React.Component {
                                     <td key={rowData.name[0]}>
                                         {rowData.x_origin === null ||
                                         rowData.x_origin === undefined ||
+                                        rowData.x_origin.length == 0 ||
                                         rowData.x_origin[0].toLowerCase() != "user defined" ? (
                                             <Button
                                                 onClick={() => {
