@@ -10,7 +10,6 @@ import {
 } from "patternfly-react";
 import { log_cmd } from "../../lib/tools.jsx";
 import PropTypes from "prop-types";
-import "../../css/ds.css";
 import { Typeahead } from "react-bootstrap-typeahead";
 
 export class Ciphers extends React.Component {
@@ -111,7 +110,11 @@ export class Ciphers extends React.Component {
                 .done(() => {
                     this.props.addNotification(
                         "success",
-                        `Successfully set cipher preferences.  You must restart the Directory Server for these changes to take effect.`
+                        `Successfully set cipher preferences.`
+                    );
+                    this.props.addNotification(
+                        "warning",
+                        `You must restart the Directory Server for these changes to take effect.`
                     );
                     this.setState({
                         saving: false,
@@ -140,7 +143,7 @@ export class Ciphers extends React.Component {
     }
 
     handleCipherChange (type, values) {
-        let availableCiphers = this.props.supportedCiphers.slice(0); // Copy array
+        let availableCiphers = this.state.availableCiphers.slice(0); // Copy array
         for (let i = 0; i < availableCiphers.length; i++) {
             for (let ci = 0; ci < values.length; ci++) {
                 if (availableCiphers[i] === values[ci]) {
