@@ -35,7 +35,7 @@ export class Server extends React.Component {
         this.selectNode = this.selectNode.bind(this);
     }
 
-    componentDidMount() {
+    componentDidUpdate() {
         if (this.props.wasActiveList.includes(1)) {
             if (this.state.firstLoad) {
                 this.loadConfig();
@@ -222,6 +222,7 @@ export class Server extends React.Component {
                     <ServerSettings
                         serverId={this.props.serverId}
                         attrs={this.state.attrs}
+                        version={this.props.version}
                         enableTree={this.enableTree}
                         addNotification={this.props.addNotification}
                     />
