@@ -47,6 +47,9 @@ REPLICATION_BIND_METHOD = RA_METHOD
 REPLICATION_TRANSPORT = RA_TRANSPORT_PROT
 REPLICATION_TIMEOUT = RA_TIMEOUT
 
+BDB_CL_FILENAME = "replication_changelog.db"
+LMDB_CL_FILENAME = "replication_changelog.mdb"
+
 # Attributes that should be masked from logging output
 SENSITIVE_ATTRS = ['userpassword',
                    'nsslapd-rootpw',
@@ -150,6 +153,7 @@ DN_IMPORT_TASK = "cn=import,%s" % DN_TASKS
 DN_BACKUP_TASK = "cn=backup,%s" % DN_TASKS
 DN_RESTORE_TASK = "cn=restore,%s" % DN_TASKS
 DN_MBO_TASK = "cn=memberOf task,%s" % DN_TASKS
+DN_EUUID_TASK = "cn=entryuuid task,%s" % DN_TASKS
 DN_TOMB_FIXUP_TASK = "cn=fixup tombstones,%s" % DN_TASKS
 DN_FIXUP_LINKED_ATTIBUTES = "cn=fixup linked attributes,%s" % DN_TASKS
 DN_AUTOMEMBER_REBUILD_TASK = "cn=automember rebuild membership,%s" % DN_TASKS
@@ -162,6 +166,13 @@ DB2BAK = 'db2bak'
 DB2INDEX = 'db2index'
 DBSCAN = 'dbscan'
 
+# Task warnings
+class TaskWarning(IntEnum):
+    WARN_UPGARDE_DN_FORMAT_ALL      = (1 << 0)
+    WARN_UPGRADE_DN_FORMAT          = (1 << 1)
+    WARN_UPGRADE_DN_FORMAT_SPACE    = (1 << 2)
+    WARN_SKIPPED_IMPORT_ENTRY       = (1 << 3)
+
 RDN_REPLICA = "cn=replica"
 
 RETROCL_SUFFIX = "cn=changelog"
