@@ -9,12 +9,14 @@
 
 import ldap
 import ldap.dn
+from ldap.controls import SimplePagedResultsControl
 from ldap import filter as ldap_filter
 import logging
 import json
 from functools import partial
 from lib389._entry import Entry
 from lib389._constants import DIRSRV_STATE_ONLINE
+from lib389._mapped_object_lint import DSLint, DSLints
 from lib389.utils import (
         ensure_bytes, ensure_str, ensure_int, ensure_list_bytes, ensure_list_str,
         ensure_list_int, display_log_value, display_log_data
@@ -82,7 +84,7 @@ class DSLogging(object):
             self._log.setLevel(logging.INFO)
 
 
-class DSLdapObject(DSLogging):
+class DSLdapObject(DSLogging, DSLint):
     """A single instance of DSLdapObjects
 
     :param instance: An instance
@@ -107,7 +109,6 @@ class DSLdapObject(DSLogging):
         self._must_attributes = None
         # attributes, we don't want to compare
         self._compare_exclude = ['entryid', 'modifytimestamp', 'nsuniqueid']
-        self._lint_functions = None
         self._server_controls = None
         self._client_controls = None
         self._object_filter = '(objectClass=*)'
@@ -985,38 +986,10 @@ class DSLdapObject(DSLogging):
         """
         return self._create(rdn, properties, basedn, ensure=True)
 
-    def lint(self):
-        """Override this to create a linter for a type. This means that we can detect
-        and report common administrative errors in the server from our cli and
-        rest tools.
-
-        The structure of a result is::
-
-          {
-            dsle: '<identifier>'. dsle == ds lint error. Will be a code unique to
-                                this module for the error, IE DSBLE0001.
-            severity: '[HIGH:MEDIUM:LOW]'. severity of the error.
-            items: '(dn,dn,dn)'. List of affected DNs or names.
-            detail: 'msg ...'. An explination of the error.
-            fix: 'msg ...'. Steps to resolve the error.
-          }
-
-        :returns: An array of these dicts, on None if there are no errors.
-        """
-
-        if not self._lint_functions:
-            return None
-        results = []
-        for fn in self._lint_functions:
-            for result in fn():
-                if result is not None:
-                    results.append(result)
-        return results
-
 
 # A challenge of this, is how do we manage indexes? They have two naming attributes....
 
-class DSLdapObjects(DSLogging):
+class DSLdapObjects(DSLogging, DSLints):
     """The object represents the next idea: "Everything is an instance of something
     that exists in this way", i.e. we unite LDAP entries by some
     set of parameters with the object.
@@ -1060,10 +1033,11 @@ class DSLdapObjects(DSLogging):
         # functions with very little work on the behalf of the overloader
         return self._childobject(instance=self._instance, dn=dn)
 
-    def list(self):
+    def list(self, paged_search=None, paged_critical=True):
         """Get a list of children entries (DSLdapObject, Replica, etc.) using a base DN
         and objectClasses of our object (DSLdapObjects, Replicas, etc.)
 
+        :param paged_search: None for no paged search, or an int of page size to use.
         :returns: A list of children entries
         """
 
@@ -1072,20 +1046,64 @@ class DSLdapObjects(DSLogging):
         # This will yield and & filter for objectClass with as many terms as needed.
         filterstr = self._get_objectclass_filter()
         self._log.debug('list filter = %s' % filterstr)
-        try:
-            results = self._instance.search_ext_s(
-                base=self._basedn,
-                scope=self._scope,
-                filterstr=filterstr,
-                attrlist=self._list_attrlist,
-                serverctrls=self._server_controls, clientctrls=self._client_controls,
-                escapehatch='i am sure'
-            )
-            # def __init__(self, instance, dn=None):
+
+        if type(paged_search) == int:
+            self._log.debug('listing with paged search -> %d', paged_search)
+            # If paged_search ->
+            results = []
+            pages = 0
+            pctrls = []
+            req_pr_ctrl = SimplePagedResultsControl(paged_critical, size=paged_search, cookie='')
+            if self._server_controls is not None:
+                controls = [req_pr_ctrl] + self._server_controls
+            else:
+                controls = [req_pr_ctrl]
+            while True:
+                msgid = self._instance.search_ext(
+                        base=self._basedn,
+                        scope=self._scope,
+                        filterstr=filterstr,
+                        attrlist=self._list_attrlist,
+                        serverctrls=controls,
+                        clientctrls=self._client_controls,
+                        escapehatch='i am sure'
+                    )
+                self._log.info('Getting page %d' % (pages,))
+                rtype, rdata, rmsgid, rctrls = self._instance.result3(msgid, escapehatch='i am sure')
+                results.extend(rdata)
+                pages += 1
+                self._log.debug("%s" % rctrls)
+                pctrls = [ c for c in rctrls
+                    if c.controlType == SimplePagedResultsControl.controlType]
+                if pctrls and pctrls[0].cookie:
+                    req_pr_ctrl.cookie = pctrls[0].cookie
+                    if self._server_controls is not None:
+                        controls = [req_pr_ctrl] + self._server_controls
+                    else:
+                        controls = [req_pr_ctrl]
+                else:
+                    break
+                #End while
+            # Result3 doesn't map through Entry, so we have to do it manually.
+            results = [Entry(r) for r in results]
             insts = [self._entry_to_instance(dn=r.dn, entry=r) for r in results]
-        except ldap.NO_SUCH_OBJECT:
-            # There are no objects to select from, se we return an empty array
-            insts = []
+            # End paged search
+        else:
+            # If not paged
+            try:
+                results = self._instance.search_ext_s(
+                    base=self._basedn,
+                    scope=self._scope,
+                    filterstr=filterstr,
+                    attrlist=self._list_attrlist,
+                    serverctrls=self._server_controls, clientctrls=self._client_controls,
+                    escapehatch='i am sure'
+                )
+                # def __init__(self, instance, dn=None):
+                insts = [self._entry_to_instance(dn=r.dn, entry=r) for r in results]
+            except ldap.NO_SUCH_OBJECT:
+                # There are no objects to select from, se we return an empty array
+                insts = []
         return insts
 
     def exists(self, selector=[], dn=None):
@@ -1241,3 +1259,23 @@ class DSLdapObjects(DSLogging):
             # There are no objects to select from, se we return an empty array
             insts = []
         return insts
+
+
+class DSContainer(DSLdapObject):
+    """Just a basic container entry
+
+    :param instance: DirSrv instance
+    :type instance: DirSrv
+    :param dn: The dn of the entry
+    :type dn: str
+    """
+
+    def __init__(self, instance, dn):
+        super(DSContainer, self).__init__(instance, dn)
+        self._rdn_attribute = 'cn'
+        self._must_attributes = ['cn']
+        self._create_objectclasses = [
+            'top',
+            'nsContainer',
+        ]
+        self._protected = True
