@@ -9,7 +9,6 @@
 import ldap
 import re
 import time
-import six
 import json
 import datetime
 from lib389._constants import *
@@ -213,7 +212,6 @@ class Agreement(DSLdapObject):
         :type bindpw: str
         :returns: A status message about the replication agreement
         """
-        status = "Unknown"
         con_maxcsn = "Unknown"
         try:
             agmt_maxcsn = self.get_agmt_maxcsn()
@@ -230,7 +228,7 @@ class Agreement(DSLdapObject):
                                     'con_maxcsn': con_maxcsn,
                                     'state': agmt_status['state'],
                                     'reason': agmt_status['message']
-                                })
+                                }, indent=4)
                             else:
                                 return "In Synchronization"
                 except:
@@ -254,7 +252,7 @@ class Agreement(DSLdapObject):
                     'con_maxcsn': con_maxcsn,
                     'state': agmt_status['state'],
                     'reason': repl_msg
-                })
+                }, indent=4)
             else:
                 return ("Not in Synchronization: supplier " +
                         "(%s) consumer (%s) State (%s) Reason (%s)" %
@@ -338,7 +336,7 @@ class Agreement(DSLdapObject):
                 status = str(e)
             if just_status:
                 if use_json:
-                    return (json.dumps(status))
+                    return (json.dumps(status, indent=4))
                 else:
                     return status
 
@@ -388,7 +386,7 @@ class Agreement(DSLdapObject):
                       'replication-status': [status],
                       'replication-lag-time': [lag_time]
                 }
-            return (json.dumps(result))
+            return (json.dumps(result, indent=4))
         else:
             retstr = (
                 "Status For Agreement: \"%(cn)s\" (%(nsDS5ReplicaHost)s:"
@@ -447,6 +445,13 @@ class Agreement(DSLdapObject):
         """
         return self.get_attr_val_utf8('nsDS5ReplicaWaitForAsyncResults')
 
+    def set_flowcontrolwindow(self, value):
+        """Set nsds5ReplicaFlowControlWindow to value.
+
+        :param value: During total update Number of entries to send without waiting ack
+        :type value: str
+        """
+        self.replace('nsds5ReplicaFlowControlWindow', value)
 
 class WinsyncAgreement(Agreement):
     """A replication agreement from this server instance to
@@ -741,7 +746,7 @@ class AgreementLegacy(object):
             # Build the result from the returned attributes
             for attr in entry.getAttrs():
                 # given an attribute name retrieve the property name
-                props = [k for k, v in six.iteritems(RA_PROPNAME_TO_ATTRNAME)
+                props = [k for k, v in RA_PROPNAME_TO_ATTRNAME.items()
                          if v.lower() == attr.lower()]
 
                 # If this attribute is present in the RA properties, adds it to
@@ -803,7 +808,7 @@ class AgreementLegacy(object):
 
         # TODO
         if suffix:
-            raise NotImplemented
+            raise NotImplementedError
 
         # The caller provides a set of properties to set into a replica entry
         if agmnt_entry:
