@@ -35,7 +35,7 @@ def generic_object_add(dsldap_objects_class, inst, log, args, arg_to_attr, dn=No
     rdn = None
     # Gather the attributes
     attrs = _args_to_attrs(args, arg_to_attr)
-    props.update({attr: value for (attr, value) in attrs.items() if value != ""})
+    props.update({attr: value for (attr, value) in attrs.items() if value != "" and value != [""]})
 
     # Get RDN attribute and Base DN from the DN if Base DN is not specified
     if basedn is None:
@@ -52,8 +52,30 @@ def generic_object_add(dsldap_objects_class, inst, log, args, arg_to_attr, dn=No
     return new_object
 
 
+def generic_object_add_attr(dsldap_object, log, args, arg_to_attr):
+    """Add an attribute to the entry. This differs to 'edit' as edit uses replace,
+    and this allows multivalues to be added.
+
+    dsldap_object should be a single instance of DSLdapObject with a set dn
+    """
+    log = log.getChild('generic_object_add_attr')
+    # Gather the attributes
+    attrs = _args_to_attrs(args, arg_to_attr)
+
+    modlist = []
+    for attr, value in attrs.items():
+        if not isinstance(value, list):
+            value = [value]
+        modlist.append((ldap.MOD_ADD, attr, value))
+    if len(modlist) > 0:
+        dsldap_object.apply_mods(modlist)
+        log.info("Successfully changed the %s", dsldap_object.dn)
+    else:
+        raise ValueError("There is nothing to set in the %s plugin entry" % dsldap_object.dn)
+
+
 def generic_object_edit(dsldap_object, log, args, arg_to_attr):
-    """Create an entry using DSLdapObject interface
+    """Replace or delete an attribute on an entry.
 
     dsldap_object should be a single instance of DSLdapObject with a set dn
     """
@@ -84,33 +106,33 @@ def generic_object_edit(dsldap_object, log, args, arg_to_attr):
 def generic_show(inst, basedn, log, args):
     """Display plugin configuration."""
     plugin = args.plugin_cls(inst)
-    print(plugin.display())
+    log.info(plugin.display())
 
 
 def generic_enable(inst, basedn, log, args):
     plugin = args.plugin_cls(inst)
     if plugin.status():
-        print("Plugin '%s' already enabled", plugin.rdn)
+        log.info("Plugin '%s' already enabled" % plugin.rdn)
     else:
         plugin.enable()
-        print("Enabled plugin '%s'", plugin.rdn)
+        log.info("Enabled plugin '%s'" % plugin.rdn)
 
 
 def generic_disable(inst, basedn, log, args):
     plugin = args.plugin_cls(inst)
     if not plugin.status():
-        print("Plugin '%s' already disabled", plugin.rdn)
+        log.info("Plugin '%s' already disabled" % plugin.rdn)
     else:
         plugin.disable()
-        print("Disabled plugin '%s'", plugin.rdn)
+        log.info("Disabled plugin '%s'" % plugin.rdn)
 
 
 def generic_status(inst, basedn, log, args):
     plugin = args.plugin_cls(inst)
     if plugin.status() is True:
-        print("Plugin '%s' is enabled", plugin.rdn)
+        log.info("Plugin '%s' is enabled" % plugin.rdn)
     else:
-        print("Plugin '%s' is disabled", plugin.rdn)
+        log.info("Plugin '%s' is disabled" % plugin.rdn)
 
 
 def add_generic_plugin_parsers(subparser, plugin_cls):
