@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2019 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # Copyright (C) 2019 William Brown <william@blackhats.net.au>
 # All rights reserved.
 #
@@ -8,21 +8,23 @@
 # --- END COPYRIGHT BLOCK ---
 
 from lib389.backend import Backend, Backends, DatabaseConfig
+from lib389.configurations.sample import (
+    create_base_domain,
+    create_base_org,
+    create_base_orgunit,
+    create_base_cn,
+    create_base_c,
+    )
 from lib389.chaining import (ChainingLinks)
-from lib389.index import Index, VLVIndex, VLVSearches
 from lib389.monitor import MonitorLDBM
+from lib389.replica import Replicas
 from lib389.utils import ensure_str, is_a_dn, is_dn_parent
 from lib389._constants import *
 from lib389.cli_base import (
-    populate_attr_arguments,
-    _generic_list,
+    _format_status,
     _generic_get,
     _generic_get_dn,
-    _generic_create,
-    _generic_delete,
     _get_arg,
-    _get_args,
-    _get_attributes,
     _warn,
     )
 import json
@@ -137,13 +139,13 @@ def backend_list(inst, basedn, log, args):
 
     be_list.sort()
     if args.json:
-        print(json.dumps({"type": "list", "items": be_list}))
+        log.info(json.dumps({"type": "list", "items": be_list}, indent=4))
     else:
         if len(be_list) > 0:
             for be in be_list:
-                print(be)
+                log.info(be)
         else:
-            print("No backends")
+            log.info("No backends")
 
 
 def backend_get(inst, basedn, log, args):
@@ -172,7 +174,34 @@ def backend_create(inst, basedn, log, args):
 
     be = Backend(inst)
     be.create(properties=props)
-    print("The database was sucessfully created")
+    if args.create_suffix and not args.create_entries:
+        # Set basic ACIs (taken from instance/setup.py)
+        c_aci = '(targetattr="c || description || objectClass")(targetfilter="(objectClass=country)")(version 3.0; acl "Enable anyone c read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+        o_aci = '(targetattr="o || description || objectClass")(targetfilter="(objectClass=organization)")(version 3.0; acl "Enable anyone o read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+        dc_aci = '(targetattr="dc || description || objectClass")(targetfilter="(objectClass=domain)")(version 3.0; acl "Enable anyone domain read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+        ou_aci = '(targetattr="ou || description || objectClass")(targetfilter="(objectClass=organizationalUnit)")(version 3.0; acl "Enable anyone ou read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+        cn_aci = '(targetattr="cn || description || objectClass")(targetfilter="(objectClass=nscontainer)")(version 3.0; acl "Enable anyone cn read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+        suffix_rdn_attr = args.suffix.split('=')[0].lower()
+        if suffix_rdn_attr == 'dc':
+            domain = create_base_domain(inst, args.suffix)
+            domain.add('aci', dc_aci)
+        elif suffix_rdn_attr == 'o':
+            org = create_base_org(inst, args.suffix)
+            org.add('aci', o_aci)
+        elif suffix_rdn_attr == 'ou':
+            orgunit = create_base_orgunit(inst, args.suffix)
+            orgunit.add('aci', ou_aci)
+        elif suffix_rdn_attr == 'cn':
+            cn = create_base_cn(inst, args.suffix)
+            cn.add('aci', cn_aci)
+        elif suffix_rdn_attr == 'c':
+            c = create_base_c(inst, args.suffix)
+            c.add('aci', c_aci)
+        else:
+            # Unsupported rdn
+            raise ValueError("Suffix RDN is not supported for creating suffix object.  Only 'dc', 'o', 'ou', and 'cn' are supported.")
+
+    log.info("The database was sucessfully created")
 
 
 def _recursively_del_backends(be):
@@ -199,7 +228,7 @@ def backend_delete(inst, basedn, log, args, warn=True):
     _recursively_del_backends(be)
     be.delete()
 
-    print("The database, and any sub-suffixes, were sucessfully deleted")
+    log.info("The database, and any sub-suffixes, were sucessfully deleted")
 
 
 def backend_import(inst, basedn, log, args):
@@ -212,11 +241,15 @@ def backend_import(inst, basedn, log, args):
     task = mc.import_ldif(ldifs=args.ldifs, chunk_size=args.chunks_size, encrypted=args.encrypted,
                           gen_uniq_id=args.gen_uniq_id, only_core=args.only_core, include_suffixes=args.include_suffixes,
                           exclude_suffixes=args.exclude_suffixes)
-    task.wait()
+    task.wait(timeout=None)
     result = task.get_exit_code()
+    warning = task.get_task_warn()
 
     if task.is_complete() and result == 0:
-        print("The import task has finished successfully")
+        if warning is None or (warning == 0):
+            log.info("The import task has finished successfully")
+        else:
+            log.info("The import task has finished successfully, with warning code {}, check the logs for more detail".format(warning))
     else:
         raise ValueError("Import task failed\n-------------------------\n{}".format(ensure_str(task.get_task_log())))
 
@@ -240,11 +273,11 @@ def backend_export(inst, basedn, log, args):
                           encrypted=args.encrypted, min_base64=args.min_base64, no_dump_uniq_id=args.no_dump_uniq_id,
                           replication=args.replication, not_folded=args.not_folded, no_seq_num=args.no_seq_num,
                           include_suffixes=args.include_suffixes, exclude_suffixes=args.exclude_suffixes)
-    task.wait()
+    task.wait(timeout=None)
     result = task.get_exit_code()
 
     if task.is_complete() and result == 0:
-        print("The export task has finished successfully")
+        log.info("The export task has finished successfully")
     else:
         raise ValueError("Export task failed\n-------------------------\n{}".format(ensure_str(task.get_task_log())))
 
@@ -252,12 +285,21 @@ def backend_export(inst, basedn, log, args):
 def is_db_link(inst, rdn):
     links = ChainingLinks(inst).list()
     for link in links:
-        cn = ensure_str(link.get_attr_val('cn')).lower()
+        cn = link.get_attr_val_utf8('cn').lower()
         if cn == rdn.lower():
             return True
     return False
 
 
+def is_db_replicated(inst, suffix):
+    replicas = Replicas(inst)
+    try:
+        replicas.get(suffix)
+        return True
+    except:
+        return False
+
+
 def backend_get_subsuffixes(inst, basedn, log, args):
     subsuffixes = []
     be_insts = MANY(inst).list()
@@ -292,15 +334,15 @@ def backend_get_subsuffixes(inst, basedn, log, args):
     if len(subsuffixes) > 0:
         subsuffixes.sort()
         if args.json:
-            print(json.dumps({"type": "list", "items": subsuffixes}))
+            log.info(json.dumps({"type": "list", "items": subsuffixes}, indent=4))
         else:
             for sub in subsuffixes:
-                print(sub)
+                log.info(sub)
     else:
         if args.json:
-            print(json.dumps({"type": "list", "items": []}))
+            log.info(json.dumps({"type": "list", "items": []}, indent=4))
         else:
-            print("No sub-suffixes under this backend")
+            log.info("No sub-suffixes under this backend")
 
 
 def build_node(suffix, be_name, subsuf=False, link=False, replicated=False):
@@ -314,8 +356,6 @@ def build_node(suffix, be_name, subsuf=False, link=False, replicated=False):
     if link:
         icon = "glyphicon glyphicon-link"
         suffix_type = "dblink"
-    if replicated:
-        suffix_type = "replicated"
 
     return {
         "text": suffix,
@@ -323,6 +363,7 @@ def build_node(suffix, be_name, subsuf=False, link=False, replicated=False):
         "selectable": True,
         "icon": icon,
         "type": suffix_type,
+        "replicated": replicated,
         "be": be_name,
         "nodes": []
     }
@@ -343,18 +384,20 @@ def backend_build_tree(inst, be_insts, nodes):
             if be_suffix == node_suffix.lower():
                 # We have our parent, now find the children
                 mts = be._mts.list()
+
                 for mt in mts:
-                    sub = mt.get_attr_val_utf8_l('nsslapd-parent-suffix')
+                    sub_parent = mt.get_attr_val_utf8_l('nsslapd-parent-suffix')
                     sub_be = mt.get_attr_val_utf8_l('nsslapd-backend')
-                    if sub == be_suffix:
+                    sub_suffix = mt.get_attr_val_utf8_l('cn')
+                    if sub_parent == be_suffix:
                         # We have a subsuffix (maybe a db link?)
-                        link = False
-                        if is_db_link(inst, sub_be):
-                            link = True
-                        node['nodes'].append(build_node(mt.get_attr_val_utf8_l('cn'),
+                        link = is_db_link(inst, sub_be)
+                        replicated = is_db_replicated(inst, sub_suffix)
+                        node['nodes'].append(build_node(sub_suffix,
                                                         sub_be,
                                                         subsuf=True,
-                                                        link=link))
+                                                        link=link,
+                                                        replicated=replicated))
 
                 # Recurse over the new subsuffixes
                 backend_build_tree(inst, be_insts, node['nodes'])
@@ -386,12 +429,13 @@ def backend_get_tree(inst, basedn, log, args):
         sub = mt.get_attr_val_utf8_l('nsslapd-parent-suffix')
         if sub is not None:
             continue
-        nodes.append(build_node(suffix, be_name))
+        replicated = is_db_replicated(inst, suffix)
+        nodes.append(build_node(suffix, be_name, replicated=replicated))
 
     # No suffixes, return empty list
     if len(nodes) == 0:
         if args.json:
-            log.info(json.dumps(nodes))
+            log.info(json.dumps(nodes, indent=4))
         else:
             log.info("There are no suffixes defined")
     else:
@@ -401,7 +445,7 @@ def backend_get_tree(inst, basedn, log, args):
 
         # Done
         if args.json:
-            log.info(json.dumps(nodes))
+            log.info(json.dumps(nodes, indent=4))
         else:
             print_suffix_tree(nodes, 1, log)
 
@@ -437,15 +481,15 @@ def backend_set(inst, basedn, log, args):
         be.enable()
     if args.disable:
         be.disable()
-    print("The backend configuration was sucessfully updated")
+    log.info("The backend configuration was successfully updated")
 
 
 def db_config_get(inst, basedn, log, args):
     db_cfg = DatabaseConfig(inst)
     if args.json:
-        print(db_cfg.get_all_attrs_json())
+        log.info(json.dumps({"type": "entry", "attrs": db_cfg.get()}, indent=4))
     else:
-        print(db_cfg.display())
+        db_cfg.display()
 
 
 def db_config_set(inst, basedn, log, args):
@@ -459,13 +503,13 @@ def db_config_set(inst, basedn, log, args):
             # We don't support deleting attributes or setting empty values in db
             continue
         else:
-            replace_list.append((attr, value))
+            replace_list.append([attr, value])
     if len(replace_list) > 0:
-        db_cfg.replace_many(*replace_list)
+        db_cfg.set(replace_list)
     elif not did_something:
         raise ValueError("There are no changes to set in the database configuration")
 
-    print("Successfully updated database configuration")
+    log.info("Successfully updated database configuration")
 
 
 def get_monitor(inst, basedn, log, args):
@@ -474,19 +518,19 @@ def get_monitor(inst, basedn, log, args):
         be = _get_backend(inst, args.suffix)
         monitor = be.get_monitor()
         if monitor is not None:
-            monitor.get_status(use_json=args.json)
+            _format_status(log, monitor, args.json)
             return
         raise ValueError("There was no monitor found for suffix '{}'".format(args.suffix))
     else:
         # Get the global database monitor entry
-        db_mon = MonitorLDBM(inst)
-        db_mon.get_status(use_json=args.json)
+        monitor = MonitorLDBM(inst)
+        _format_status(log, monitor, args.json)
 
 
 def backend_add_index(inst, basedn, log, args):
     be = _get_backend(inst, args.be_name)
     be.add_index(args.attr, args.index_type, args.matching_rule, reindex=args.reindex)
-    print("Successfully added index")
+    log.info("Successfully added index")
 
 
 def backend_set_index(inst, basedn, log, args):
@@ -513,7 +557,7 @@ def backend_set_index(inst, basedn, log, args):
 
     if args.reindex:
         be.reindex(attrs=[args.attr])
-    print("Index successfully updated")
+    log.info("Index successfully updated")
 
 
 def backend_get_index(inst, basedn, log, args):
@@ -527,9 +571,9 @@ def backend_get_index(inst, basedn, log, args):
                 # Append decoded json object, because we are going to dump it later
                 results.append(json.loads(entry))
             else:
-                print(index.display())
+                log.info(index.display())
     if args.json:
-        print(json.dumps({"type": "list", "items": results}))
+        log.info(json.dumps({"type": "list", "items": results}, indent=4))
 
 
 def backend_list_index(inst, basedn, log, args):
@@ -544,25 +588,25 @@ def backend_list_index(inst, basedn, log, args):
                 results.append(json.loads(index.get_all_attrs_json()))
         else:
             if args.just_names:
-                print(index.get_attr_val_utf8_l('cn'))
+                log.info(index.get_attr_val_utf8_l('cn'))
             else:
-                print(index.display())
+                log.info(index.display())
 
     if args.json:
-        print(json.dumps({"type": "list", "items": results}))
+        log.info(json.dumps({"type": "list", "items": results}, indent=4))
 
 
 def backend_del_index(inst, basedn, log, args):
     be = _get_backend(inst, args.be_name)
     for attr in args.attr:
         be.del_index(attr)
-        print("Successfully deleted index \"{}\"".format(attr))
+        log.info("Successfully deleted index \"{}\"".format(attr))
 
 
 def backend_reindex(inst, basedn, log, args):
     be = _get_backend(inst, args.be_name)
     be.reindex(attrs=args.attr, wait=args.wait)
-    print("Successfully reindexed database")
+    log.info("Successfully reindexed database")
 
 
 def backend_attr_encrypt(inst, basedn, log, args):
@@ -573,16 +617,16 @@ def backend_attr_encrypt(inst, basedn, log, args):
         for attr in args.add_attr:
             be.add_encrypted_attr(attr)
         if len(args.add_attr) > 1:
-            print("Successfully added encrypted attributes")
+            log.info("Successfully added encrypted attributes")
         else:
-            print("Successfully added encrypted attribute")
+            log.info("Successfully added encrypted attribute")
     if args.del_attr is not None:
         for attr in args.del_attr:
             be.del_encrypted_attr(attr)
         if len(args.del_attr) > 1:
-            print("Successfully deleted encrypted attributes")
+            log.info("Successfully deleted encrypted attributes")
         else:
-            print("Successfully deleted encrypted attribute")
+            log.info("Successfully deleted encrypted attribute")
     if args.list:
         results = be.get_encrypted_attrs(args.just_names)
         if args.json:
@@ -592,17 +636,17 @@ def backend_attr_encrypt(inst, basedn, log, args):
             else:
                 for result in results:
                     json_results.append(json.loads(result.get_all_attrs_json()))
-            print(json.dumps({"type": "list", "items": json_results}))
+            log.info(json.dumps({"type": "list", "items": json_results}, indent=4))
 
         else:
             if len(results) == 0:
-                print("There are no encrypted attributes for this backend")
+                log.info("There are no encrypted attributes for this backend")
             else:
                 for attr in results:
                     if args.just_names:
-                        print(attr)
+                        log.info(attr)
                     else:
-                        print(attr.display())
+                        log.info(attr.display())
 
 
 def backend_list_vlv(inst, basedn, log, args):
@@ -626,24 +670,24 @@ def backend_list_vlv(inst, basedn, log, args):
                 results.append(entry)
         else:
             if args.just_names:
-                print(vlv.get_attr_val_utf8_l('cn'))
+                log.info(vlv.get_attr_val_utf8_l('cn'))
             else:
                 raw_entry = vlv.get_attrs_vals(VLV_SEARCH_ATTRS)
-                print('dn: ' + vlv.dn)
+                log.info('dn: ' + vlv.dn)
                 for k, v in list(raw_entry.items()):
-                    print('{}: {}'.format(ensure_str(k), ensure_str(v[0])))
+                    log.info('{}: {}'.format(ensure_str(k), ensure_str(v[0])))
                 indexes = vlv.get_sorts()
                 sorts = []
-                print("Sorts:")
+                log.info("Sorts:")
                 for idx in indexes:
                     entry = idx.get_attrs_vals(VLV_INDEX_ATTRS)
-                    print(' - dn: ' + idx.dn)
+                    log.info(' - dn: ' + idx.dn)
                     for k, v in list(entry.items()):
-                        print(' - {}: {}'.format(ensure_str(k), ensure_str(v[0])))
-                    print()
+                        log.info(' - {}: {}'.format(ensure_str(k), ensure_str(v[0])))
+                    log.info()
 
     if args.json:
-        print(json.dumps({"type": "list", "items": results}))
+        log.info(json.dumps({"type": "list", "items": results}, indent=4))
 
 
 def backend_get_vlv(inst, basedn, log, args):
@@ -658,9 +702,9 @@ def backend_get_vlv(inst, basedn, log, args):
                 results.append(json.loads(entry))
             else:
                 raw_entry = vlv.get_attrs_vals(VLV_SEARCH_ATTRS)
-                print('dn: ' + vlv._dn)
+                log.info('dn: ' + vlv._dn)
                 for k, v in list(raw_entry.items()):
-                    print('{}: {}'.format(ensure_str(k), ensure_str(v[0])))
+                    log.info('{}: {}'.format(ensure_str(k), ensure_str(v[0])))
             # Print indexes
             indexes = vlv.get_sorts()
             for idx in indexes:
@@ -669,14 +713,14 @@ def backend_get_vlv(inst, basedn, log, args):
                     results.append(json.loads(entry))
                 else:
                     raw_entry = idx.get_attrs_vals(VLV_INDEX_ATTRS)
-                    print('Sorts:')
-                    print(' - dn: ' + idx._dn)
+                    log.info('Sorts:')
+                    log.info(' - dn: ' + idx._dn)
                     for k, v in list(raw_entry.items()):
-                        print(' - {}: {}'.format(ensure_str(k), ensure_str(v[0])))
-                    print()
+                        log.info(' - {}: {}'.format(ensure_str(k), ensure_str(v[0])))
+                    log.info()
 
             if args.json:
-                print(json.dumps({"type": "list", "items": results}))
+                log.info(json.dumps({"type": "list", "items": results}, indent=4))
 
 
 def backend_create_vlv(inst, basedn, log, args):
@@ -686,7 +730,7 @@ def backend_create_vlv(inst, basedn, log, args):
              'vlvscope': args.search_scope,
              'vlvfilter': args.search_filter}
     be.add_vlv_search(args.name, props)
-    print("Successfully created new VLV Search entry, now you can add indexes to it.")
+    log.info("Successfully created new VLV Search entry, now you can add indexes to it.")
 
 
 def backend_edit_vlv(inst, basedn, log, args):
@@ -708,14 +752,14 @@ def backend_edit_vlv(inst, basedn, log, args):
         raise ValueError("There are no changes to set in the VLV search entry")
     if args.reindex:
         vlv_search.reindex()
-    print("Successfully updated VLV search entry")
+    log.info("Successfully updated VLV search entry")
 
 
 def backend_del_vlv(inst, basedn, log, args):
     be = _get_backend(inst, args.be_name)
     vlv_search = be.get_vlv_searches(vlv_name=args.name)
     vlv_search.delete_all()
-    print("Successfully deleted VLV search and its indexes")
+    log.info("Successfully deleted VLV search and its indexes")
 
 
 def backend_create_vlv_index(inst, basedn, log, args):
@@ -724,14 +768,14 @@ def backend_create_vlv_index(inst, basedn, log, args):
     vlv_search.add_sort(args.index_name, args.sort)
     if args.index_it:
         vlv_search.reindex(args.be_name, vlv_index=args.index_name)
-    print("Successfully created new VLV index entry")
+    log.info("Successfully created new VLV index entry")
 
 
 def backend_delete_vlv_index(inst, basedn, log, args):
     be = _get_backend(inst, args.be_name)
     vlv_search = be.get_vlv_searches(vlv_name=args.parent_name)
     vlv_search.delete_sort(args.index_name, args.sort)
-    print("Successfully deleted VLV index entry")
+    log.info("Successfully deleted VLV index entry")
 
 
 def backend_reindex_vlv(inst, basedn, log, args):
@@ -739,7 +783,7 @@ def backend_reindex_vlv(inst, basedn, log, args):
     suffix = be.get_suffix()
     vlv_search = be.get_vlv_searches(vlv_name=args.parent_name)
     vlv_search.reindex(suffix, vlv_index=args.index_name)
-    print("Successfully reindexed VLV indexes")
+    log.info("Successfully reindexed VLV indexes")
 
 
 def create_parser(subparsers):
@@ -1052,6 +1096,8 @@ def create_parser(subparsers):
     create_parser.add_argument('--suffix', required=True, help='The database suffix DN, for example "dc=example,dc=com"')
     create_parser.add_argument('--be-name', required=True, help='The database backend name, for example "userroot"')
     create_parser.add_argument('--create-entries', action='store_true', help='Create sample entries in the database')
+    create_parser.add_argument('--create-suffix', action='store_true',
+        help="Create the suffix object entry in the database.  Only suffixes using the attributes 'dc', 'o', 'ou', or 'cn' are supported in this feature")
 
     #######################################################
     # Delete backend
