@@ -8,7 +8,7 @@
 
 from json import dumps as dump_json
 from lib389.cli_base import _get_arg
-from lib389.schema import Schema
+from lib389.schema import Schema, AttributeUsage, ObjectclassKind
 
 
 def _validate_dual_args(enable_arg, disable_arg):
@@ -21,34 +21,63 @@ def _validate_dual_args(enable_arg, disable_arg):
         return 0
 
 
+def list_all(inst, basedn, log, args):
+    log = log.getChild('list_all')
+    schema = Schema(inst)
+    json = False
+    if args is not None and args.json:
+        json = True
+
+    objectclass_elems = schema.get_objectclasses(json=json)
+    attributetype_elems = schema.get_attributetypes(json=json)
+    matchingrule_elems = schema.get_matchingrules(json=json)
+
+    if json:
+        print(dump_json({'type': 'schema',
+                         'objectclasses': objectclass_elems,
+                         'attributetypes': attributetype_elems,
+                         'matchingrules': matchingrule_elems}, indent=4))
+    else:
+        separator_line = "".join(["-" for _ in range(50)])
+        print("Objectclasses:\n", separator_line)
+        for oc in objectclass_elems:
+            print(oc)
+        print("AttributeTypes:\n", separator_line)
+        for at in attributetype_elems:
+            print(at)
+        print("MathingRules:\n", separator_line)
+        for mr in matchingrule_elems:
+            print(mr)
+
+
 def list_attributetypes(inst, basedn, log, args):
     log = log.getChild('list_attributetypes')
     schema = Schema(inst)
     if args is not None and args.json:
-        print(dump_json(schema.get_attributetypes(json=True)))
+        print(dump_json(schema.get_attributetypes(json=True), indent=4))
     else:
         for attributetype in schema.get_attributetypes():
-            log.info(attributetype)
+            print(attributetype)
 
 
 def list_objectclasses(inst, basedn, log, args):
     log = log.getChild('list_objectclasses')
     schema = Schema(inst)
     if args is not None and args.json:
-        print(dump_json(schema.get_objectclasses(json=True)))
+        print(dump_json(schema.get_objectclasses(json=True), indent=4))
     else:
         for oc in schema.get_objectclasses():
-            log.info(oc)
+            print(oc)
 
 
 def list_matchingrules(inst, basedn, log, args):
     log = log.getChild('list_matchingrules')
     schema = Schema(inst)
     if args is not None and args.json:
-        print(dump_json(schema.get_matchingrules(json=True)))
+        print(dump_json(schema.get_matchingrules(json=True), indent=4))
     else:
         for mr in schema.get_matchingrules():
-            log.info(mr)
+            print(mr)
 
 
 def query_attributetype(inst, basedn, log, args):
@@ -57,18 +86,18 @@ def query_attributetype(inst, basedn, log, args):
     # Need the query type
     attr = _get_arg(args.name, msg="Enter attribute to query")
     if args.json:
-        print(dump_json(schema.query_attributetype(attr, json=args.json)))
+        print(dump_json(schema.query_attributetype(attr, json=args.json), indent=4))
     else:
         attributetype, must, may = schema.query_attributetype(attr, json=args.json)
-        log.info(attributetype)
-        log.info("")
-        log.info("MUST")
+        print(attributetype)
+        print("")
+        print("MUST")
         for oc in must:
-            log.info(oc)
-        log.info("")
-        log.info("MAY")
+            print(oc)
+        print("")
+        print("MAY")
         for oc in may:
-            log.info(oc)
+            print(oc)
 
 
 def query_objectclass(inst, basedn, log, args):
@@ -78,9 +107,9 @@ def query_objectclass(inst, basedn, log, args):
     oc = _get_arg(args.name, msg="Enter objectclass to query")
     result = schema.query_objectclass(oc, json=args.json)
     if args.json:
-        print(dump_json(result))
+        print(dump_json(result, indent=4))
     else:
-        log.info(result)
+        print(result)
 
 
 def query_matchingrule(inst, basedn, log, args):
@@ -90,9 +119,9 @@ def query_matchingrule(inst, basedn, log, args):
     attr = _get_arg(args.name, msg="Enter attribute to query")
     result = schema.query_matchingrule(attr, json=args.json)
     if args.json:
-        print(dump_json(result))
+        print(dump_json(result, indent=4))
     else:
-        log.info(result)
+        print(result)
 
 
 def add_attributetype(inst, basedn, log, args):
@@ -104,7 +133,7 @@ def add_attributetype(inst, basedn, log, args):
         parameters["names"].extend(aliases)
 
     schema.add_attributetype(parameters)
-    log.info("Successfully added the attributeType")
+    print("Successfully added the attributeType")
 
 
 def add_objectclass(inst, basedn, log, args):
@@ -113,7 +142,7 @@ def add_objectclass(inst, basedn, log, args):
 
     parameters = _get_parameters(args, 'objectclasses')
     schema.add_objectclass(parameters)
-    log.info("Successfully added the objectClass")
+    print("Successfully added the objectClass")
 
 
 def edit_attributetype(inst, basedn, log, args):
@@ -125,7 +154,7 @@ def edit_attributetype(inst, basedn, log, args):
         parameters["names"].extend(aliases)
 
     schema.edit_attributetype(args.name, parameters)
-    log.info("Successfully changed the attributetype")
+    print("Successfully changed the attributetype")
 
 
 def remove_attributetype(inst, basedn, log, args):
@@ -133,7 +162,7 @@ def remove_attributetype(inst, basedn, log, args):
     attr = _get_arg(args.name, msg="Enter attribute to remove")
     schema = Schema(inst)
     schema.remove_attributetype(attr)
-    log.info("Successfully removed the attributetype")
+    print("Successfully removed the attributetype")
 
 
 def edit_objectclass(inst, basedn, log, args):
@@ -141,7 +170,7 @@ def edit_objectclass(inst, basedn, log, args):
     schema = Schema(inst)
     parameters = _get_parameters(args, 'objectclasses')
     schema.edit_objectclass(args.name, parameters)
-    log.info("Successfully changed the objectClass")
+    print("Successfully changed the objectClass")
 
 
 def remove_objectclass(inst, basedn, log, args):
@@ -149,24 +178,36 @@ def remove_objectclass(inst, basedn, log, args):
     attr = _get_arg(args.name, msg="Enter objectClass to remove")
     schema = Schema(inst)
     schema.remove_objectclass(attr)
-    log.info("Successfully removed the objectClass")
+    print("Successfully removed the objectClass")
 
 
 def reload_schema(inst, basedn, log, args):
     log = log.getChild('reload_schema')
     schema = Schema(inst)
-    log.info('Attempting to add task entry... This will fail if Schema Reload plug-in is not enabled.')
+    print('Attempting to add task entry... This will fail if Schema Reload plug-in is not enabled.')
     task = schema.reload(args.schemadir)
     if args.wait:
         task.wait()
         rc = task.get_exit_code()
         if rc == 0:
-            log.info("Schema reload task ({}) successfully finished.".format(task.dn))
+            print("Schema reload task ({}) successfully finished.".format(task.dn))
         else:
             raise ValueError("Schema reload task failed, please check the errors log for more information")
     else:
-        log.info('Successfully added task entry {}'.format(task.dn))
-        log.info("To verify that the schema reload operation was successful, please check the error logs.")
+        print('Successfully added task entry {}'.format(task.dn))
+        print("To verify that the schema reload operation was successful, please check the error logs.")
+
+
+def validate_syntax(inst, basedn, log, args):
+    schema = Schema(inst)
+    log.info('Attempting to add task entry...')
+    validate_task = schema.validate_syntax(args.DN, args.filter)
+    validate_task.wait()
+    exitcode = validate_task.get_exit_code()
+    if exitcode != 0:
+        log.error(f'Validate syntax task for {args.DN} has failed. Please, check logs')
+    else:
+        log.info('Successfully added task entry')
 
 
 def get_syntaxes(inst, basedn, log, args):
@@ -174,39 +215,58 @@ def get_syntaxes(inst, basedn, log, args):
     schema = Schema(inst)
     result = schema.get_attr_syntaxes(json=args.json)
     if args.json:
-        print(dump_json(result))
+        print(dump_json(result, indent=4))
     else:
-        for name, id in result.items():
-            log.info("%s (%s)", name, id)
+        for id, name in result.items():
+            print("%s (%s)", name, id)
 
 
 def _get_parameters(args, type):
     if type not in ('attributetypes', 'objectclasses'):
         raise ValueError("Wrong parser type: %s" % type)
 
-    parameters = {'names': [args.name,],
+    parameters = {'names': [args.name],
                   'oid': args.oid,
                   'desc': args.desc,
-                  'obsolete': _validate_dual_args(args.obsolete, args.not_obsolete)}
+                  'x_origin': args.x_origin,
+                  'obsolete': None}
 
     if type == 'attributetypes':
+        if args.usage is not None:
+            usage = args.usage
+            if usage in [item.name for item in AttributeUsage]:
+                usage = AttributeUsage[usage].value
+            else:
+                raise ValueError("Attribute usage should be one of the next: "
+                                 "userApplications, directoryOperation, distributedOperation, dSAOperation")
+        else:
+            usage = None
+
         parameters.update({'single_value': _validate_dual_args(args.single_value, args.multi_value),
                            'aliases': args.aliases,
                            'syntax': args.syntax,
                            'syntax_len': None,  # We need it for
                            'x_ordered': None,   # the correct ldap.schema.models work
-                           'no_user_mod': _validate_dual_args(args.no_user_mod, args.with_user_mod),
+                           'collective': None,
+                           'no_user_mod': _validate_dual_args(args.no_user_mod, args.user_mod),
                            'equality': args.equality,
                            'substr': args.substr,
                            'ordering': args.ordering,
-                           'x_origin': args.x_origin,
-                           'collective': _validate_dual_args(args.collective, args.not_collective),
-                           'usage': args.usage,
+                           'usage': usage,
                            'sup': args.sup})
     elif type == 'objectclasses':
+        if args.kind is not None:
+            kind = args.kind.upper()
+            if kind in [item.name for item in ObjectclassKind]:
+                kind = ObjectclassKind[kind].value
+            else:
+                raise ValueError("ObjectClass kind should be one of the next: STRUCTURAL, ABSTRACT, AUXILIARY")
+        else:
+            kind = None
+
         parameters.update({'must': args.must,
                            'may': args.may,
-                           'kind': args.kind,
+                           'kind': kind,
                            'sup': args.sup})
 
     return parameters
@@ -216,19 +276,12 @@ def _add_parser_args(parser, type):
     if type not in ('attributetypes', 'objectclasses'):
         raise ValueError("Wrong parser type: %s" % type)
 
-    parser.add_argument('name',  help='NAME of the object')
+    parser.add_argument('name', help='NAME of the object')
     parser.add_argument('--oid', help='OID assigned to the object')
     parser.add_argument('--desc', help='Description text(DESC) of the object')
-    parser.add_argument('--obsolete', action='store_true',
-                        help='True if the object is marked as OBSOLETE in the schema.'
-                             'Only one of the flags this or --not-obsolete should be specified')
-    parser.add_argument('--not-obsolete', action='store_true',
-                        help='True if the OBSOLETE mark should be removed'
-                             'object is marked as OBSOLETE in the schema'
-                             'Only one of the flags this or --obsolete should be specified')
+    parser.add_argument('--x-origin',
+                        help='Provides information about where the attribute type is defined')
     if type == 'attributetypes':
-        parser.add_argument('--syntax', required=True,
-                            help='OID of the LDAP syntax assigned to the attribute')
         parser.add_argument('--aliases', nargs='+', help='Additional NAMEs of the object.')
         parser.add_argument('--single-value', action='store_true',
                             help='True if the matching rule must have only one value'
@@ -238,8 +291,8 @@ def _add_parser_args(parser, type):
                                  'Only one of the flags this or --single-value should be specified')
         parser.add_argument('--no-user-mod', action='store_true',
                             help='True if the attribute is not modifiable by a client application'
-                                 'Only one of the flags this or --with-user-mod should be specified')
-        parser.add_argument('--with-user-mod', action='store_true',
+                                 'Only one of the flags this or --user-mod should be specified')
+        parser.add_argument('--user-mod', action='store_true',
                             help='True if the attribute is modifiable by a client application (default)'
                                  'Only one of the flags this or --no-user-mode should be specified')
         parser.add_argument('--equality',
@@ -251,24 +304,15 @@ def _add_parser_args(parser, type):
         parser.add_argument('--ordering',
                             help='NAME or OID of the matching rule used for checking'
                                  'whether attribute values are lesser - equal than')
-        parser.add_argument('--x-origin',
-                            help='Provides information about where the attribute type is defined')
-        parser.add_argument('--collective',
-                            help='True if the attribute is assigned their values by virtue in their membership in some collection'
-                                 'Only one of the flags this or --not-collective should be specified')
-        parser.add_argument('--not-collective',
-                            help='True if the attribute is not assigned their values by virtue in their membership in some collection (default)'
-                                 'Only one of the flags this or --collective should be specified')
         parser.add_argument('--usage',
-                            help='The flag indicates how the attribute type is to be used.'
-                                 'userApplications - user, directoryOperation - directory operational,'
-                                 'distributedOperation - DSA-shared operational, dSAOperation - DSA - specific operational')
-        parser.add_argument('--sup', nargs='?', help='The list of NAMEs or OIDs of attribute types'
+                            help='The flag indicates how the attribute type is to be used. Choose from the list: '
+                                 'userApplications (default), directoryOperation, distributedOperation, dSAOperation')
+        parser.add_argument('--sup', nargs='+', help='The list of NAMEs or OIDs of attribute types'
                                                      'this attribute type is derived from')
     elif type == 'objectclasses':
         parser.add_argument('--must', nargs='+', help='NAMEs or OIDs of all attributes an entry of the object must have')
         parser.add_argument('--may', nargs='+', help='NAMEs or OIDs of additional attributes an entry of the object may have')
-        parser.add_argument('--kind', help='Kind of an object. 0 = STRUCTURAL (default), 1 = ABSTRACT, 2 = AUXILIARY')
+        parser.add_argument('--kind', help='Kind of an object. STRUCTURAL (default), ABSTRACT, AUXILIARY')
         parser.add_argument('--sup', nargs='+', help='NAMEs or OIDs of object classes this object is derived from')
     else:
         raise ValueError("Wrong parser type: %s" % type)
@@ -278,6 +322,8 @@ def create_parser(subparsers):
     schema_parser = subparsers.add_parser('schema', help='Query and manipulate schema')
 
     schema_subcommands = schema_parser.add_subparsers(help='schema')
+    schema_list_parser = schema_subcommands.add_parser('list', help='List all schema objects on this system')
+    schema_list_parser.set_defaults(func=list_all)
 
     attributetypes_parser = schema_subcommands.add_parser('attributetypes', help='Work with attribute types on this system')
     attributetypes_subcommands = attributetypes_parser.add_subparsers(help='schema')
@@ -291,12 +337,14 @@ def create_parser(subparsers):
     at_add_parser = attributetypes_subcommands.add_parser('add', help='Add an attribute type to this system')
     at_add_parser.set_defaults(func=add_attributetype)
     _add_parser_args(at_add_parser, 'attributetypes')
-    at_edit_parser = attributetypes_subcommands.add_parser('edit', help='Edit an attribute type on this system')
+    at_add_parser.add_argument('--syntax', required=True, help='OID of the LDAP syntax assigned to the attribute')
+    at_edit_parser = attributetypes_subcommands.add_parser('replace', help='Replace an attribute type on this system')
     at_edit_parser.set_defaults(func=edit_attributetype)
     _add_parser_args(at_edit_parser, 'attributetypes')
+    at_edit_parser.add_argument('--syntax', help='OID of the LDAP syntax assigned to the attribute')
     at_remove_parser = attributetypes_subcommands.add_parser('remove', help='Remove an attribute type on this system')
     at_remove_parser.set_defaults(func=remove_attributetype)
-    at_remove_parser.add_argument('name',  help='NAME of the object')
+    at_remove_parser.add_argument('name', help='NAME of the object')
 
     objectclasses_parser = schema_subcommands.add_parser('objectclasses', help='Work with objectClasses on this system')
     objectclasses_subcommands = objectclasses_parser.add_subparsers(help='schema')
@@ -308,12 +356,12 @@ def create_parser(subparsers):
     oc_add_parser = objectclasses_subcommands.add_parser('add', help='Add an objectClass to this system')
     oc_add_parser.set_defaults(func=add_objectclass)
     _add_parser_args(oc_add_parser, 'objectclasses')
-    oc_edit_parser = objectclasses_subcommands.add_parser('edit', help='Edit an objectClass on this system')
+    oc_edit_parser = objectclasses_subcommands.add_parser('replace', help='Replace an objectClass on this system')
     oc_edit_parser.set_defaults(func=edit_objectclass)
     _add_parser_args(oc_edit_parser, 'objectclasses')
     oc_remove_parser = objectclasses_subcommands.add_parser('remove', help='Remove an objectClass on this system')
     oc_remove_parser.set_defaults(func=remove_objectclass)
-    oc_remove_parser.add_argument('name',  help='NAME of the object')
+    oc_remove_parser.add_argument('name', help='NAME of the object')
 
     matchingrules_parser = schema_subcommands.add_parser('matchingrules', help='Work with matching rules on this system')
     matchingrules_subcommands = matchingrules_parser.add_subparsers(help='schema')
@@ -328,4 +376,10 @@ def create_parser(subparsers):
     reload_parser.add_argument('-d', '--schemadir', help="directory where schema files are located")
     reload_parser.add_argument('--wait', action='store_true', default=False, help="Wait for the reload task to complete")
 
-
+    validate_parser = schema_subcommands.add_parser('validate-syntax',
+                                                    help='Run a task to check every modification to attributes to make sure '
+                                                         'that the new value has the required syntax for that attribute type')
+    validate_parser.set_defaults(func=validate_syntax)
+    validate_parser.add_argument('DN', help="Base DN that contains entries to validate")
+    validate_parser.add_argument('-f', '--filter', help='Filter for entries to validate.\n'
+                                                        'If omitted, all entries with filter "(objectclass=*)" are validated')
