@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2019 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # Copyright (C) 2017, William Brown <william at blackhats.net.au>
 # All rights reserved.
 #
@@ -12,10 +12,9 @@ import time
 import subprocess
 from enum import Enum
 import ldap
-
 from lib389._mapped_object import DSLdapObject, DSLdapObjects, _gen_or, _gen_filter, _term_gen
 from lib389._constants import SER_ROOT_DN, SER_ROOT_PW
-from lib389.utils import ds_is_older, gentime_to_posix_time, gentime_to_datetime
+from lib389.utils import gentime_to_posix_time, gentime_to_datetime
 from lib389.plugins import AccountPolicyPlugin, AccountPolicyConfig, AccountPolicyEntry
 from lib389.cos import CosTemplates
 from lib389.mappingTree import MappingTrees
@@ -45,9 +44,13 @@ class Account(DSLdapObject):
     :type dn: str
     """
 
+    def __init__(self, instance, dn=None):
+        super(Account, self).__init__(instance, dn)
+        self._protected = False
+
     def _format_status_message(self, message, create_time, modify_time, last_login_time, limit, role_dn=None):
         params = {}
-        now = time.time()
+        now = time.mktime(time.gmtime())
         params["Creation Date"] = gentime_to_datetime(create_time)
         params["Modification Date"] = gentime_to_datetime(modify_time)
         params["Last Login Date"] = None
@@ -106,7 +109,9 @@ class Account(DSLdapObject):
             spec_attr = self._dict_get_with_ignore_indexerror(config_settings, "specattrname")
             limit_attr = self._dict_get_with_ignore_indexerror(config_settings, "limitattrname")
 
-            cos_entries = CosTemplates(inst, self.dn)
+            mapping_trees = MappingTrees(inst)
+            root_suffix = mapping_trees.get_root_suffix_by_entry(self.dn)
+            cos_entries = CosTemplates(inst, root_suffix)
             accpol_entry_dn = ""
             for cos in cos_entries.list():
                 if cos.present(spec_attr):
@@ -158,8 +163,8 @@ class Account(DSLdapObject):
 
         # Locked indirectly through Account Policy plugin
         if process_account_policy and last_login_time:
-            # Now check the Acount Policy Plugin inactivity limits
-            remaining_time = float(limit) - (time.time() - gentime_to_posix_time(last_login_time))
+            # Now check the Account Policy Plugin inactivity limits
+            remaining_time = float(limit) - (time.mktime(time.gmtime()) - gentime_to_posix_time(last_login_time))
             if remaining_time <= 0:
                 return self._format_status_message(AccountState.INACTIVITY_LIMIT_EXCEEDED,
                                                    create_time, modify_time, last_login_time, limit)
