@@ -34,6 +34,7 @@ from lib389.instance.options import General2Base, Slapd2Base, Backend2Base
 from lib389.paths import Paths
 from lib389.saslmap import SaslMappings
 from lib389.instance.remove import remove_ds_instance
+from lib389.index import Indexes
 from lib389.utils import (
     assert_c,
     is_a_dn,
@@ -308,6 +309,9 @@ class SetupDs(object):
 
             val = input('\nEnter the instance name [{}]: '.format(slapd['instance_name'])).rstrip()
             if val != "":
+                if len(val) > 80:
+                    print("Server identifier should not be longer than 80 symbols")
+                    continue
                 if not all(ord(c) < 128 for c in val):
                     print("Server identifier can not contain non ascii characters")
                     continue
@@ -567,6 +571,15 @@ class SetupDs(object):
 
         # We need to know the prefix before we can do the instance checks
         assert_c(slapd['instance_name'] is not None, "Configuration instance_name in section [slapd] not found")
+        assert_c(len(slapd['instance_name']) <= 80, "Server identifier should not be longer than 80 symbols")
+        assert_c(all(ord(c) < 128 for c in slapd['instance_name']), "Server identifier can not contain non ascii characters")
+        assert_c(' ' not in slapd['instance_name'], "Server identifier can not contain a space")
+        assert_c(slapd['instance_name'] != 'admin', "Server identifier \"admin\" is reserved, please choose a different identifier")
+
+        # Check that valid characters are used
+        safe = re.compile(r'^[:\w@_-]+$').search
+        assert_c(bool(safe(slapd['instance_name'])), "Server identifier has invalid characters, please choose a different value")
+
         # Check if the instance exists or not.
         # Should I move this import? I think this prevents some recursion
         from lib389 import DirSrv
@@ -591,7 +604,7 @@ class SetupDs(object):
 
         # Right now, the way that rootpw works on ns-slapd works, it force hashes the pw
         # see https://fedorahosted.org/389/ticket/48859
-        if not re.match('^\{[A-Z0-9]+\}.*$', slapd['root_password']):
+        if not re.match('^([A-Z0-9]+).*$', slapd['root_password']):
             # We need to hash it. Call pwdhash-bin.
             # slapd['root_password'] = password_hash(slapd['root_password'], prefix=slapd['prefix'])
             pass
@@ -661,11 +674,10 @@ class SetupDs(object):
                 self._install_ds(general, slapd, backends)
             except ValueError as e:
                 if DEBUGGING is False:
-                    self.log.fatal("Error: " + str(e) + ", removing incomplete installation...")
                     self._remove_failed_install(slapd['instance_name'])
                 else:
-                    self.log.fatal("Error: " + str(e) + ", preserving incomplete installation for analysis...")
-                raise ValueError("Instance creation failed!")
+                    self.log.fatal(f"Error: {str(e)}, preserving incomplete installation for analysis...")
+                raise ValueError(f"Instance creation failed!  {str(e)}")
 
             # Call the child api to do anything it needs.
             self._install(extra)
@@ -720,6 +732,7 @@ class SetupDs(object):
                 dse += line.replace('%', '{', 1).replace('%', '}', 1)
 
         with open(os.path.join(slapd['config_dir'], 'dse.ldif'), 'w') as file_dse:
+            ldapi_path = os.path.join(slapd['local_state_dir'], "run/slapd-%s.socket" % slapd['instance_name'])
             dse_fmt = dse.format(
                 schema_dir=slapd['schema_dir'],
                 lock_dir=slapd['lock_dir'],
@@ -736,18 +749,21 @@ class SetupDs(object):
                 rootdn=slapd['root_dn'],
                 instance_name=slapd['instance_name'],
                 ds_passwd=self._secure_password,  # We set our own password here, so we can connect and mod.
-                # This is because we never know the users input root password as they can validily give
+                # This is because we never know the users input root password as they can validly give
                 # us a *hashed* input.
                 ds_suffix=ds_suffix,
                 config_dir=slapd['config_dir'],
                 db_dir=slapd['db_dir'],
-                db_home_dir=slapd['db_home_dir']
+                db_home_dir=slapd['db_home_dir'],
+                ldapi_enabled="on",
+                ldapi=ldapi_path,
+                ldapi_autobind="on",
             )
             file_dse.write(dse_fmt)
 
         # Create all the needed paths
         # we should only need to make bak_dir, cert_dir, config_dir, db_dir, ldif_dir, lock_dir, log_dir, run_dir?
-        for path in ('backup_dir', 'cert_dir', 'db_dir', 'db_home_dir', 'ldif_dir', 'lock_dir', 'log_dir', 'run_dir'):
+        for path in ('backup_dir', 'cert_dir', 'db_dir', 'ldif_dir', 'lock_dir', 'log_dir', 'run_dir'):
             self.log.debug("ACTION: creating %s", slapd[path])
             try:
                 os.umask(0o007)  # For parent dirs that get created -> sets 770 for perms
@@ -796,7 +812,9 @@ class SetupDs(object):
             args = ' '.join(ensure_list_str(result.args))
             stdout = ensure_str(result.stdout)
             stderr = ensure_str(result.stderr)
-            self.log.debug(f"CMD: {args} ; STDOUT: {stdout} ; STDERR: {stderr}")
+            # Systemd encodes some odd charecters into it's symlink output on newer versions which
+            # can trip up the logger.
+            self.log.debug(f"CMD: {args} ; STDOUT: {stdout} ; STDERR: {stderr}".encode("utf-8"))
 
             # Setup tmpfiles_d
             tmpfile_d = ds_paths.tmpfiles_d + "/dirsrv-" + slapd['instance_name'] + ".conf"
@@ -823,12 +841,24 @@ class SetupDs(object):
         if self.containerised:
             ds_instance.systemd_override = general['systemd']
 
+        # By default SUSE does something extremely silly - it creates a hostname
+        # that CANT be resolved by DNS. As a result this causes all installs to
+        # fail. We need to guarantee that we only connect to localhost here, as
+        # it's the only stable and guaranteed way to connect to the instance
+        # at this point.
+        #
+        # Use ldapi which would prevent the need
+        # to configure a temp root pw in the setup phase.
         args = {
+            SER_HOST: "localhost",
             SER_PORT: slapd['port'],
             SER_SERVERID_PROP: slapd['instance_name'],
             SER_ROOT_DN: slapd['root_dn'],
             SER_ROOT_PW: self._raw_secure_password,
-            SER_DEPLOYED_DIR: slapd['prefix']
+            SER_DEPLOYED_DIR: slapd['prefix'],
+            SER_LDAPI_ENABLED: 'on',
+            SER_LDAPI_SOCKET: ldapi_path,
+            SER_LDAPI_AUTOBIND: 'on'
         }
 
         ds_instance.allocate(args)
@@ -858,7 +888,7 @@ class SetupDs(object):
                         tlsdb_inst = NssSsl(dbpath=os.path.join(etc_dirsrv_path, dir))
                         tlsdb_inst.import_rsa_crt(ca)
 
-            csr = tlsdb.create_rsa_key_and_csr()
+            csr = tlsdb.create_rsa_key_and_csr(alt_names=[general['full_machine_name']])
             (ca, crt) = ssca.rsa_ca_sign_csr(csr)
             tlsdb.import_rsa_crt(ca, crt)
             if general['selinux']:
@@ -868,7 +898,7 @@ class SetupDs(object):
         # Do selinux fixups
         if general['selinux']:
             selinux_paths = ('backup_dir', 'cert_dir', 'config_dir', 'db_dir',
-                             'db_home_dir', 'ldif_dir', 'lock_dir', 'log_dir',
+                             'ldif_dir', 'lock_dir', 'log_dir',
                              'run_dir', 'schema_dir', 'tmp_dir')
             for path in selinux_paths:
                 selinux_restorecon(slapd[path])
@@ -899,6 +929,19 @@ class SetupDs(object):
         if slapd['self_sign_cert']:
             ds_instance.config.set('nsslapd-security', 'on')
 
+        # Before we create any backends, create any extra default indexes that may be
+        # dynamically provisioned, rather than from template-dse.ldif. Looking at you
+        # entryUUID (requires rust enabled).
+        #
+        # Indexes defaults to default_index_dn
+        indexes = Indexes(ds_instance)
+        if ds_instance.ds_paths.rust_enabled:
+            indexes.create(properties={
+                'cn': 'entryUUID',
+                'nsSystemIndex': 'false',
+                'nsIndexType': ['eq', 'pres'],
+            })
+
         # Create the backends as listed
         # Load example data if needed.
         for backend in backends:
@@ -932,14 +975,6 @@ class SetupDs(object):
                     # Unsupported rdn
                     raise ValueError("Suffix RDN '{}' in '{}' is not supported.  Supported RDN's are: 'c', 'cn', 'dc', 'o', and 'ou'".format(suffix_rdn_attr, backend['nsslapd-suffix']))
 
-        # Initialise ldapi socket information. IPA expects this ....
-        ldapi_path = os.path.join(slapd['local_state_dir'], "run/slapd-%s.socket" % slapd['instance_name'])
-        ds_instance.config.set('nsslapd-ldapifilepath', ldapi_path)
-        ds_instance.config.set('nsslapd-ldapilisten', 'on')
-        ds_instance.config.set('nsslapd-ldapiautobind', 'on')
-        ds_instance.config.set('nsslapd-ldapimaprootdn', slapd['root_dn'])
-
-
         # Create all required sasl maps: if we have a single backend ...
         # our default maps are really really bad, and we should feel bad.
         # they basically only work with a single backend, and they'll break
@@ -978,3 +1013,5 @@ class SetupDs(object):
         else:
             # Just stop the instance now.
             ds_instance.stop()
+
+        self.log.debug(" 🎉 Instance setup complete")
