@@ -38,6 +38,7 @@ class Task(DSLdapObject):
         self._protected = False
         self._exit_code = None
         self._task_log = ""
+        self._task_warn = None
 
     def status(self):
         """Return the decoded status of the task
@@ -49,6 +50,7 @@ class Task(DSLdapObject):
 
         self._exit_code = self.get_attr_val_utf8("nsTaskExitCode")
         self._task_log = self.get_attr_val_utf8("nsTaskLog")
+        self._task_warn = self.get_attr_val_utf8("nsTaskWarning")
         if not self.exists():
             self._log.debug("complete: task has self cleaned ...")
             # The task cleaned it self up.
@@ -77,11 +79,23 @@ class Task(DSLdapObject):
                 return None
         return None
 
+    def get_task_warn(self):
+        """Return task's warning code if task is complete, else None."""
+        if self.is_complete():
+            try:
+                return int(self._task_warn)
+            except TypeError:
+                return None
+        return None
+
     def wait(self, timeout=120):
         """Wait until task is complete."""
 
         count = 0
-        while count < timeout:
+        if timeout is None:
+            self._log.debug("No timeout is set, this may take a long time ...")
+
+        while timeout is None or count < timeout:
             if self.is_complete():
                 break
             count = count + 1
@@ -189,6 +203,33 @@ class USNTombstoneCleanupTask(Task):
         return super(USNTombstoneCleanupTask, self)._validate(rdn, properties, basedn)
 
 
+class csngenTestTask(Task):
+    """A single instance of csn generator test task entry
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    """
+
+    def __init__(self, instance, dn=None):
+        self.cn = 'csngenTest_' + Task._get_task_date()
+        dn = "cn=" + self.cn + ",cn=csngen_test," + DN_TASKS
+        super(csngenTestTask, self).__init__(instance, dn)
+
+
+class EntryUUIDFixupTask(Task):
+    """A single instance of memberOf task entry
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    """
+
+    def __init__(self, instance, dn=None):
+        self.cn = 'entryuuid_fixup_' + Task._get_task_date()
+        dn = "cn=" + self.cn + "," + DN_EUUID_TASK
+        super(EntryUUIDFixupTask, self).__init__(instance, dn)
+        self._must_attributes.extend(['basedn'])
+
+
 class SchemaReloadTask(Task):
     """A single instance of schema reload task entry
 
@@ -387,14 +428,17 @@ class Tasks(object):
         running, true if done - if true, second is the exit code - if dowait
         is True, this function will block until the task is complete'''
         attrlist = ['nsTaskLog', 'nsTaskStatus', 'nsTaskExitCode',
-                    'nsTaskCurrentItem', 'nsTaskTotalItems']
+                    'nsTaskCurrentItem', 'nsTaskTotalItems', 'nsTaskWarning']
         done = False
         exitCode = 0
+        warningCode = 0
         dn = entry.dn
         while not done:
             entry = self.conn.getEntry(dn, attrlist=attrlist)
             self.log.debug("task entry %r", entry)
 
+            if entry.nsTaskWarning:
+                warningCode = int(entry.nsTaskWarning)
             if entry.nsTaskExitCode:
                 exitCode = int(entry.nsTaskExitCode)
                 done = True
@@ -402,7 +446,7 @@ class Tasks(object):
                 time.sleep(1)
             else:
                 break
-        return (done, exitCode)
+        return (done, exitCode, warningCode)
 
     def importLDIF(self, suffix=None, benamebase=None, input_file=None,
                    args=None):
@@ -458,8 +502,9 @@ class Tasks(object):
         self.conn.add_s(entry)
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error("Error: import task %s for file %s exited with %d",
@@ -467,6 +512,8 @@ class Tasks(object):
         else:
             self.log.info("Import task %s for file %s completed successfully",
                           cn, input_file)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
         self.dn = dn
         self.entry = entry
         return exitCode
@@ -527,8 +574,9 @@ class Tasks(object):
         # start the task and possibly wait for task completion
         self.conn.add_s(entry)
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error("Error: export task %s for file %s exited with %d",
@@ -536,6 +584,8 @@ class Tasks(object):
         else:
             self.log.info("Export task %s for file %s completed successfully",
                           cn, output_file)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -579,14 +629,17 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error("Error: backup task %s exited with %d",
                            cn, exitCode)
         else:
             self.log.info("Backup task %s completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -633,14 +686,17 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error("Error: restore task %s exited with %d",
                            cn, exitCode)
         else:
             self.log.info("Restore task %s completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -758,14 +814,17 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args is not None and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error("Error: index task %s exited with %d",
                            cn, exitCode)
         else:
             self.log.info("Index task %s completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -836,8 +895,9 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error(
@@ -847,6 +907,8 @@ class Tasks(object):
             self.log.info(
                 "fixupMemberOf task %s for basedn %s completed successfully",
                 cn, suffix)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -895,8 +957,9 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error(
@@ -908,6 +971,8 @@ class Tasks(object):
                 "tombstone fixup task %s for backend %s completed "
                 "successfully",
                 cn, bename)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -945,8 +1010,9 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error(
@@ -956,6 +1022,8 @@ class Tasks(object):
             self.log.info(
                 "Automember Rebuild Membership task(%s) completed"
                 "successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -998,8 +1066,9 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error(
@@ -1009,6 +1078,8 @@ class Tasks(object):
             self.log.info(
                 "Automember Export Updates task (%s) completed successfully",
                 cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -1046,8 +1117,9 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error(
@@ -1056,6 +1128,8 @@ class Tasks(object):
         else:
             self.log.info(
                 "Automember Map Updates task (%s) completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -1088,8 +1162,9 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error(
@@ -1098,6 +1173,8 @@ class Tasks(object):
         else:
             self.log.info(
                 "Fixup Linked Attributes task (%s) completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -1129,14 +1206,17 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error("Error: Schema Reload task (%s) exited with %d",
                            cn, exitCode)
         else:
             self.log.info("Schema Reload task (%s) completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -1171,8 +1251,9 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error(
@@ -1181,6 +1262,8 @@ class Tasks(object):
         else:
             self.log.info(
                 "'memberuid task' (%s) completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -1215,8 +1298,9 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error("Error: Syntax Validate (%s) exited with %d",
@@ -1224,6 +1308,8 @@ class Tasks(object):
         else:
             self.log.info("Syntax Validate task (%s) completed successfully",
                           cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -1263,8 +1349,9 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error(
@@ -1273,6 +1360,8 @@ class Tasks(object):
         else:
             self.log.info(
                 "USN tombstone cleanup task (%s) completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -1296,7 +1385,7 @@ class Tasks(object):
             raise ValueError("Missing required paramter: configfile")
 
         cn = 'task-' + time.strftime("%m%d%Y_%H%M%S", time.localtime())
-        dn = ('cn=%s,cn=cn=sysconfig reload,cn=tasks,cn=config' % cn)
+        dn = ('cn=%s,cn=sysconfig reload,cn=tasks,cn=config' % cn)
         entry = Entry(dn)
         entry.setValues('objectclass', 'top', 'extensibleObject')
         entry.setValues('cn', cn)
@@ -1311,8 +1400,9 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error("Error: Sysconfig Reload task (%s) exited with %d",
@@ -1320,6 +1410,8 @@ class Tasks(object):
         else:
             self.log.info("Sysconfig Reload task (%s) completed successfully",
                           cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -1360,14 +1452,17 @@ class Tasks(object):
             return (dn, -1)
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error("Error: cleanAllRUV task (%s) exited with %d",
                            cn, exitCode)
         else:
             self.log.info("cleanAllRUV task (%s) completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -1412,8 +1507,9 @@ class Tasks(object):
             return (dn, -1)
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error(
@@ -1422,6 +1518,8 @@ class Tasks(object):
         else:
             self.log.info(
                 "Abort cleanAllRUV task (%s) completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
@@ -1463,16 +1561,32 @@ class Tasks(object):
             return -1
 
         exitCode = 0
+        warningCode = 0
         if args and args.get(TASK_WAIT, False):
-            (done, exitCode) = self.conn.tasks.checkTask(entry, True)
+            (done, exitCode, warningCode) = self.conn.tasks.checkTask(entry, True)
 
         if exitCode:
             self.log.error("Error: upgradedb task (%s) exited with %d",
                            cn, exitCode)
         else:
             self.log.info("Upgradedb task (%s) completed successfully", cn)
+        if warningCode:
+            self.log.info("with warning code %d", warningCode)
 
         self.dn = dn
         self.entry = entry
 
         return exitCode
+
+
+class LDAPIMappingReloadTask(Task):
+    """LDAPI DN Mapping task entry
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    """
+
+    def __init__(self, instance, dn=None):
+        self.cn = 'reload-' + Task._get_task_date()
+        dn = f'cn={self.cn},cn=reload ldapi mappings,cn=tasks,cn=config'
+        super(LDAPIMappingReloadTask, self).__init__(instance, dn)
