@@ -36,7 +36,6 @@ from datetime import datetime
 import sys
 import filecmp
 import pwd
-import six
 import shlex
 import operator
 import subprocess
@@ -83,101 +82,101 @@ searches = {
 
 # Map table for pseudolocalized strings
 _chars = {
-    " ": six.u("\u2003"),
-    "!": six.u("\u00a1"),
-    "\"": six.u("\u2033"),
-    "#": six.u("\u266f"),
-    "$": six.u("\u20ac"),
-    "%": six.u("\u2030"),
-    "&": six.u("\u214b"),
-    "'": six.u("\u00b4"),
-    ")": six.u("}"),
-    "(": six.u("{"),
-    "*": six.u("\u204e"),
-    "+": six.u("\u207a"),
-    ",": six.u("\u060c"),
-    "-": six.u("\u2010"),
-    ".": six.u("\u00b7"),
-    "/": six.u("\u2044"),
-    "0": six.u("\u24ea"),
-    "1": six.u("\u2460"),
-    "2": six.u("\u2461"),
-    "3": six.u("\u2462"),
-    "4": six.u("\u2463"),
-    "5": six.u("\u2464"),
-    "6": six.u("\u2465"),
-    "7": six.u("\u2466"),
-    "8": six.u("\u2467"),
-    "9": six.u("\u2468"),
-    ":": six.u("\u2236"),
-    ";": six.u("\u204f"),
-    "<": six.u("\u2264"),
-    "=": six.u("\u2242"),
-    ">": six.u("\u2265"),
-    "?": six.u("\u00bf"),
-    "@": six.u("\u055e"),
-    "A": six.u("\u00c5"),
-    "B": six.u("\u0181"),
-    "C": six.u("\u00c7"),
-    "D": six.u("\u00d0"),
-    "E": six.u("\u00c9"),
-    "F": six.u("\u0191"),
-    "G": six.u("\u011c"),
-    "H": six.u("\u0124"),
-    "I": six.u("\u00ce"),
-    "J": six.u("\u0134"),
-    "K": six.u("\u0136"),
-    "L": six.u("\u013b"),
-    "M": six.u("\u1e40"),
-    "N": six.u("\u00d1"),
-    "O": six.u("\u00d6"),
-    "P": six.u("\u00de"),
-    "Q": six.u("\u01ea"),
-    "R": six.u("\u0154"),
-    "S": six.u("\u0160"),
-    "T": six.u("\u0162"),
-    "U": six.u("\u00db"),
-    "V": six.u("\u1e7c"),
-    "W": six.u("\u0174"),
-    "X": six.u("\u1e8a"),
-    "Y": six.u("\u00dd"),
-    "Z": six.u("\u017d"),
-    "[": six.u("\u2045"),
-    "\\": six.u("\u2216"),
-    "]": six.u("\u2046"),
-    "^": six.u("\u02c4"),
-    "_": six.u("\u203f"),
-    "`": six.u("\u2035"),
-    "a": six.u("\u00e5"),
-    "b": six.u("\u0180"),
-    "c": six.u("\u00e7"),
-    "d": six.u("\u00f0"),
-    "e": six.u("\u00e9"),
-    "f": six.u("\u0192"),
-    "g": six.u("\u011d"),
-    "h": six.u("\u0125"),
-    "i": six.u("\u00ee"),
-    "j": six.u("\u0135"),
-    "k": six.u("\u0137"),
-    "l": six.u("\u013c"),
-    "m": six.u("\u0271"),
-    "n": six.u("\u00f1"),
-    "o": six.u("\u00f6"),
-    "p": six.u("\u00fe"),
-    "q": six.u("\u01eb"),
-    "r": six.u("\u0155"),
-    "s": six.u("\u0161"),
-    "t": six.u("\u0163"),
-    "u": six.u("\u00fb"),
-    "v": six.u("\u1e7d"),
-    "w": six.u("\u0175"),
-    "x": six.u("\u1e8b"),
-    "y": six.u("\u00fd"),
-    "z": six.u("\u017e"),
-    "{": six.u("("),
-    "}": six.u(")"),
-    "|": six.u("\u00a6"),
-    "~": six.u("\u02de"),
+    " ": u"\u2003",
+    "!": u"\u00a1",
+    "\"": u"\u2033",
+    "#": u"\u266f",
+    "$": u"\u20ac",
+    "%": u"\u2030",
+    "&": u"\u214b",
+    "'": u"\u00b4",
+    ")": u"}",
+    "(": u"{",
+    "*": u"\u204e",
+    "+": u"\u207a",
+    ",": u"\u060c",
+    "-": u"\u2010",
+    ".": u"\u00b7",
+    "/": u"\u2044",
+    "0": u"\u24ea",
+    "1": u"\u2460",
+    "2": u"\u2461",
+    "3": u"\u2462",
+    "4": u"\u2463",
+    "5": u"\u2464",
+    "6": u"\u2465",
+    "7": u"\u2466",
+    "8": u"\u2467",
+    "9": u"\u2468",
+    ":": u"\u2236",
+    ";": u"\u204f",
+    "<": u"\u2264",
+    "=": u"\u2242",
+    ">": u"\u2265",
+    "?": u"\u00bf",
+    "@": u"\u055e",
+    "A": u"\u00c5",
+    "B": u"\u0181",
+    "C": u"\u00c7",
+    "D": u"\u00d0",
+    "E": u"\u00c9",
+    "F": u"\u0191",
+    "G": u"\u011c",
+    "H": u"\u0124",
+    "I": u"\u00ce",
+    "J": u"\u0134",
+    "K": u"\u0136",
+    "L": u"\u013b",
+    "M": u"\u1e40",
+    "N": u"\u00d1",
+    "O": u"\u00d6",
+    "P": u"\u00de",
+    "Q": u"\u01ea",
+    "R": u"\u0154",
+    "S": u"\u0160",
+    "T": u"\u0162",
+    "U": u"\u00db",
+    "V": u"\u1e7c",
+    "W": u"\u0174",
+    "X": u"\u1e8a",
+    "Y": u"\u00dd",
+    "Z": u"\u017d",
+    "[": u"\u2045",
+    "\\": u"\u2216",
+    "]": u"\u2046",
+    "^": u"\u02c4",
+    "_": u"\u203f",
+    "`": u"\u2035",
+    "a": u"\u00e5",
+    "b": u"\u0180",
+    "c": u"\u00e7",
+    "d": u"\u00f0",
+    "e": u"\u00e9",
+    "f": u"\u0192",
+    "g": u"\u011d",
+    "h": u"\u0125",
+    "i": u"\u00ee",
+    "j": u"\u0135",
+    "k": u"\u0137",
+    "l": u"\u013c",
+    "m": u"\u0271",
+    "n": u"\u00f1",
+    "o": u"\u00f6",
+    "p": u"\u00fe",
+    "q": u"\u01eb",
+    "r": u"\u0155",
+    "s": u"\u0161",
+    "t": u"\u0163",
+    "u": u"\u00fb",
+    "v": u"\u1e7d",
+    "w": u"\u0175",
+    "x": u"\u1e8b",
+    "y": u"\u00fd",
+    "z": u"\u017e",
+    "{": u"(",
+    "}": u")",
+    "|": u"\u00a6",
+    "~": u"\u02de",
 }
 
 #
@@ -1108,6 +1107,11 @@ def ds_is_newer(*ver, instance=None):
     """
     return ds_is_related('newer', *ver, instance=instance)
 
+def ds_supports_new_changelog():
+    """
+    Return True if the current version of ns-slapd supports changelogs under cn=changelog,cn=<backend>,cn=ldbm..
+    """
+    return ds_is_newer('1.4.4.3')
 
 def gentime_to_datetime(gentime):
     """Convert Generalized time to datetime object
@@ -1127,9 +1131,15 @@ def gentime_to_posix_time(gentime):
     :type password: str
     :returns: Epoch time int
     """
+    time_tuple = (int(gentime[:4]),
+                  int(gentime[4:6]),
+                  int(gentime[6:8]),
+                  int(gentime[8:10]),
+                  int(gentime[10:12]),
+                  int(gentime[12:14]),
+                  0, 0, 0)
 
-    target_timestamp = gentime_to_datetime(gentime)
-    return datetime.timestamp(target_timestamp)
+    return time.mktime(time_tuple)
 
 
 def getDateTime():
@@ -1143,11 +1153,28 @@ def getDateTime():
 
 
 def socket_check_open(host, port):
-    with closing(socket.socket(socket.AF_INET6, socket.SOCK_STREAM)) as sock:
-        if sock.connect_ex((host, port)) == 0:
-            return True
-        else:
-            return False
+    """
+    Check if a socket can be opened.  Need to handle cases where IPv6 is completely
+    disabled.
+    """
+    try:
+        # Trying IPv6 first ...
+        family = socket.AF_INET6
+        with closing(socket.socket(family, socket.SOCK_STREAM)) as sock:
+            if sock.connect_ex((host, port)) == 0:
+                return True
+            else:
+                return False
+    except OSError:
+        # No IPv6, adjust hostname, and try IPv4 ...
+        family = socket.AF_INET
+        if host == "::1":
+            host = "127.0.0.1"
+        with closing(socket.socket(family, socket.SOCK_STREAM)) as sock:
+            if sock.connect_ex((host, port)) == 0:
+                return True
+            else:
+                return False
 
 
 def ensure_bytes(val):
@@ -1198,7 +1225,7 @@ def ensure_dict_str(val):
 
 
 def pseudolocalize(string):
-    pseudo_string = six.u("")
+    pseudo_string = u""
     for char in string:
         try:
             pseudo_string += _chars[char]
@@ -1380,3 +1407,23 @@ def copy_with_permissions(source, target):
     st = os.stat(source)
     os.chown(target, st[stat.ST_UID], st[stat.ST_GID])
     os.chmod(target, st[stat.ST_MODE])
+
+
+def cmp(self, x, y):
+    """
+    Replacement for built-in function cmp that was removed in Python 3
+
+    Compare the two objects x and y and return an integer according to
+    the outcome. The return value is negative if x < y, zero if x == y
+    and strictly positive if x > y.
+    """
+    return (x > y) - (x < y)
+
+
+def is_valid_hostname(hostname):
+    if len(hostname) > 255:
+        return False
+    if hostname[-1] == ".":
+        hostname = hostname[:-1] # strip exactly one dot from the right, if present
+    allowed = re.compile("(?!-)[A-Z\d-]{1,63}(?<!-)$", re.IGNORECASE)
+    return all(allowed.match(x) for x in hostname.split("."))
